@import "site/header/cart";

.ra-cart-modal .widget_shopping_cart_content {
	padding-bottom: 310px;
}

.widget_shopping_cart_content {
	.woocommerce-mini-cart-item__thumbnail img {
		max-width: 100px;
	}
}

.widget_shopping_cart_content .woocommerce-mini-cart-item__name {
	padding-right: 0;
}