/**
 * Classic editor styling
 */
/**
 * DO NOT CHANGE THIS FILE!
 * To override any of the settings in this section, add your styling code in the custom directory.
 * Loading first in the style.scss & classic-editor.scss
 */
p {
  margin-block-end: 0.75rem;
}

img {
  max-width: 100%;
  height: auto;
  vertical-align: middle;
  border-style: none;
}

pre {
  font-family: monospace;
  font-size: 1em;
  white-space: pre-wrap;
}

code,
kbd,
pre,
samp {
  font-size: 1rem;
}

code,
kbd,
pre,
samp {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, "Helvetica Neue", Arial, "Noto Sans", sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji";
  font-size: 1rem;
}

blockquote {
  font-style: italic;
}