@import "elementor";

@import "shortcode-title";
@import "shortcode-pagination";
@import "checkmark-list";

@import "mixins/mixins-master";
@import "shop/columns";

@import "swiper";
@import "banner-carousel";
@import "newsletter";
@import "countdown";
@import "contact-form";
@import "faq";
@import "testimonial";
@import "instagram";
@import "map";
@import "product-tab";
@import "product-category-tabs";
@import "product-of-category";
@import "product-carousel";
@import "product-showcase";
@import "products-slider";
@import "product-grid";
@import "product-masonry";
@import "product-deal";
@import "product-deal-2";
@import "razzi-product";
@import "deals-carousel";
@import "deals-carousel-2";
@import "banner";
@import "brands";
@import "slides";
@import "isolate-slides";
@import "posts-carousel";
@import "banner-collection";
@import "popular-keywords";
@import "image-content-box";
@import "banner-video";
@import "promo-box";
@import "image-box";
@import "image-button";
@import "product-banner";
@import "products-lookbook";
@import "lookbook-banner";
@import "featured-content";
@import "be-af-images";
@import "pricing-price";
@import "testimonial-grid";
@import "icon-box-carousel";
@import "images-box-carousel-2";
@import "icon-box";
@import "category-box";
@import "recently-viewed";
@import "images-carousel";
@import "heading";
@import "button";
@import "section-parallax";
@import "sale-box";
@import "advanced-tabs";
@import "products-carousel-with-thumbnails";
@import "products-with-banner";
@import "images-carousel-2";
@import "posts-listing";
@import "category-links";
@import "product-category-box";
@import "product-listing";
@import "team";
@import "responsive/responsive";
