.woocommerce-badges {
	position: absolute;
	left: 0;
	top: 20px;
	font-size: 11px;
	font-weight: 500;
	text-transform: uppercase;
	display: inline-block;
	text-align: center;
	
	> span {
		display: block;
		padding: 5px 11px;
		line-height: 1;
		background-color: var(--rz-background-color-dark);
		color: var(--rz-color-lighter);
		
		&:not(:last-child) {
			margin-bottom: 5px;
		}
	}
	
	.sold-out {
		background-color: #a0a0a0;
		color: #fff;
	}
	
	.featured {
		background-color: #ff6f61;
		color: #fff;
	}
	
	.new {
		background-color: var(--rz-background-color-light);
		color: var(--rz-color-darker);
	}
}

ul:not(.product-loop-layout-2) {
	.woocommerce-badges--layout-2 {
		left: initial;
		right: 20px;
	}
}

.woocommerce-badges--layout-2 {
	text-transform: lowercase;
	left: 20px;
	
	> span {
		display: flex;
		flex-direction: column;
		align-items: center;
		justify-content: center;
		width: 70px;
		height: 70px;
		border-radius: 50%;
		line-height: 1.2;
		font-size: 16px;
	}
	
	.onsale {
		.text {
			font-size: 14px;
			margin-bottom: 3px;
		}
		
		.percent {
			font-size: 16px;
		}
	}
}