.razzi-shortcode-title {
    font-weight: 500;
    font-size: 36px;
    line-height: 48px;
    margin-top: 0;
}

.razzi-shortcode-subtitle {
    font-weight: 500;
    font-size: 13px;
    line-height: 19px;
    letter-spacing: 0.02em;
    text-transform: uppercase;
    color: #A0A0A0;
    margin: 0 0 10px 0;
}