.razzi-instagram-grid{
    position: relative;

    .instagram-wrapper{
        list-style: none;
        padding: 0;
        margin: 0;
        display: grid;
        grid-gap: 0;
        grid-template-columns: repeat(auto-fill, minmax(20%, 1fr));
        grid-auto-flow: dense;

        li a:hover{
            opacity: .9;
        }


        img{
            display: block;
        }
    }

    .instagram-text-box{
        position: absolute;
        top: 50%;
        left: 50%;
        transform: translate(-50%,-50%);
        line-height: 1.5;
        padding: 15px 40px
    }
}

.razzi-instagram-grid-2{
    position: relative;
    overflow: hidden;

    .instagram-wrapper{
        list-style: none;
        padding: 0;
        margin: 0;
        display: flex;
        flex-wrap: wrap;

        a{
            display: block;
        }

        li a:hover{
            opacity: .9;
        }

        img{
            display: block;
        }
    }

    .instagram-text-wrapper{
        display: flex;
        flex-direction: column;
        justify-content: center;
        text-align: center;
        padding: 50px;
        width: 100%;
        background-color: #f5f5f5;

        .razzi-icon{
            display: block;
            font-size: 33px;
            margin-bottom: 6px;
        }

        .instagram-title{
            font-size: 36px;
            margin: 0 0 25px;
        }

        .instagram-desc{
            font-size: 18px;
            margin-bottom: 39px;
        }
    }
}