@charset "UTF-8";
/**
 * DO NOT CHANGE THIS FILE!
 * To override any of the settings in this section, add your styling code in the custom directory.
 * Loading first in the style.scss & classic-editor.scss
 */
/**
 * General - https://wordpress.org/documentation/article/css/
 * DO NOT CHANGE THIS FILE
 * to override any of the settings in this section, add your styling code in the custom directory.
 */
.page-content a,
.comments-area a {
  text-decoration: underline;
}

.alignright {
  float: right;
  margin-left: 1rem;
}

.alignleft {
  float: left;
  margin-right: 1rem;
}

.aligncenter {
  clear: both;
  display: block;
  margin-left: auto;
  margin-right: auto;
}

.alignwide {
  margin-left: -80px;
  margin-right: -80px;
}

.alignfull {
  margin-left: calc(50% - 50vw);
  margin-right: calc(50% - 50vw);
  max-width: 100vw;
  width: 100vw;
}
.alignfull img {
  width: 100vw;
}

.wp-caption {
  margin-block-end: 1.25rem;
  max-width: 100%;
}
.wp-caption.alignleft {
  margin: 5px 20px 20px 0;
}
.wp-caption.alignright {
  margin: 5px 0 20px 20px;
}
.wp-caption img {
  display: block;
  margin-left: auto;
  margin-right: auto;
}

.wp-caption-text {
  margin: 0;
}

.gallery-caption {
  display: block;
  font-size: 0.8125rem;
  line-height: 1.5;
  margin: 0;
  padding: 0.75rem;
}

.pagination {
  margin: 20px auto;
}

.sticky {
  position: relative;
  display: block;
}

.bypostauthor {
  font-size: inherit;
}

.hide {
  display: none !important;
}

.post-password-form p {
  width: 100%;
  display: flex;
  align-items: flex-end;
}

.post-password-form [type=submit] {
  margin-inline-start: 3px;
}

/**
 * Utility styles
 */
.screen-reader-text {
  clip: rect(1px, 1px, 1px, 1px);
  height: 1px;
  overflow: hidden;
  position: absolute !important;
  width: 1px;
  word-wrap: normal !important; /* Many screen reader and browser combinations announce broken words as they would appear visually. */
}
.screen-reader-text:focus {
  background-color: #eeeeee;
  clip: auto !important;
  clip-path: none;
  color: #333333;
  display: block;
  font-size: 1rem;
  height: auto;
  left: 5px;
  line-height: normal;
  padding: 15px 23px 14px;
  text-decoration: none;
  top: 5px;
  width: auto;
  z-index: 100000; /* Above WP toolbar. */
}

/**
 * Header styling and layout
 */
.site-header {
  /* Backwards compat for Hello 2.3.0 */
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
  padding-block-start: 1rem;
  padding-block-end: 1rem;
  position: relative;
}
.site-header .site-navigation {
  justify-content: flex-end;
}
.site-header .site-branding {
  display: flex;
  flex-direction: column;
  justify-content: center;
}
.site-header .header-inner {
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
}
.site-header .header-inner .custom-logo-link {
  display: block;
}
.site-header .header-inner .site-branding .site-title,
.site-header .header-inner .site-branding .site-description {
  margin: 0;
}
.site-header .header-inner .site-branding.show-title .site-logo {
  display: none !important;
}
.site-header .header-inner .site-branding.show-logo .site-title {
  display: none !important;
}
.site-header:not(.header-stacked) .header-inner .site-branding {
  max-width: 30%;
}
.site-header:not(.header-stacked) .header-inner .site-navigation {
  max-width: 70%;
}
.site-header.header-inverted .header-inner {
  flex-direction: row-reverse;
}
.site-header.header-inverted .header-inner .site-branding {
  text-align: right;
}
.site-header.header-inverted .header-inner .site-navigation {
  justify-content: start;
}
.site-header.header-stacked .header-inner {
  align-items: center;
  flex-direction: column;
  text-align: center;
}

@media (max-width: 576px) {
  .site-header .header-inner:not(.header-stacked) .site-branding {
    max-width: 80%;
  }
}
/**
 * Footer styling and layout
 */
.site-footer {
  padding-block-start: 1rem;
  padding-block-end: 1rem;
  position: relative;
}
.site-footer .footer-inner {
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
}
.site-footer .footer-inner .custom-logo-link {
  display: block;
}
.site-footer .footer-inner .site-navigation {
  justify-content: flex-end;
}
.site-footer .footer-inner .site-branding {
  display: flex;
  flex-direction: column;
  justify-content: center;
}
.site-footer .footer-inner .site-branding .site-title,
.site-footer .footer-inner .site-branding .site-description {
  margin: 0;
}
.site-footer .footer-inner .site-branding.show-title .site-logo {
  display: none !important;
}
.site-footer .footer-inner .site-branding.show-logo .site-title {
  display: none !important;
}
.site-footer .footer-inner .copyright {
  align-items: center;
  display: flex;
  justify-content: flex-end;
}
.site-footer .footer-inner .copyright p {
  margin: 0;
}
.site-footer.footer-inverted .footer-inner {
  flex-direction: row-reverse;
}
.site-footer.footer-inverted .footer-inner .site-branding {
  text-align: right;
}
.site-footer.footer-inverted .footer-inner .site-navigation {
  justify-content: flex-start;
}
.site-footer.footer-has-copyright .footer-inner .site-navigation {
  justify-content: center;
}
.site-footer.footer-stacked .footer-inner {
  align-items: center;
  flex-direction: column;
  text-align: center;
}
.site-footer.footer-stacked .footer-inner .site-branding h4.site-title {
  text-align: center;
}
.site-footer.footer-stacked .footer-inner .site-navigation .menu {
  padding: 0;
}
.site-footer:not(.footer-stacked) .footer-inner .site-branding {
  max-width: 20%;
}
.site-footer:not(.footer-stacked) .footer-inner .site-navigation {
  max-width: 60%;
}
.site-footer:not(.footer-stacked) .footer-inner .copyright {
  max-width: 20%;
}

@media (max-width: 576px) {
  .site-footer:not(.footer-stacked) .footer-inner .site-branding,
  .site-footer:not(.footer-stacked) .footer-inner .site-navigation,
  .site-footer:not(.footer-stacked) .footer-inner .copyright {
    display: block;
    text-align: center;
    width: 100%;
    max-width: none;
  }
  .site-footer .footer-inner .site-navigation ul.menu {
    justify-content: center;
  }
  .site-footer .footer-inner .site-navigation ul.menu li {
    display: inline-block;
  }
}
/**
 * Post item in archive pages
 */
.post .entry-title a {
  text-decoration: none;
}
.post .wp-post-image {
  width: 100%;
  max-height: 500px;
  object-fit: cover;
}
@media (max-width: 991px) {
  .post .wp-post-image {
    max-height: 400px;
  }
}
@media (max-width: 575px) {
  .post .wp-post-image {
    max-height: 300px;
  }
}

/**
 * Comments
 */
#comments .comment-list {
  margin: 0;
  padding: 0;
  list-style: none;
  font-size: 0.9em;
}
#comments .comment,
#comments .pingback {
  position: relative;
}
#comments .comment .comment-body,
#comments .pingback .comment-body {
  display: flex;
  flex-direction: column;
  padding-block-start: 30px;
  padding-block-end: 30px;
  padding-inline-start: 60px;
  padding-inline-end: 0;
  border-block-end: 1px solid #cccccc;
}
#comments .comment .avatar,
#comments .pingback .avatar {
  position: absolute;
  left: 0;
  border-radius: 50%;
  margin-inline-end: 10px;
}
html[dir=rtl] #comments .comment .avatar, body.rtl #comments .comment .avatar,
html[dir=rtl] #comments .pingback .avatar,
body.rtl #comments .pingback .avatar {
  left: auto;
  right: 0;
}

#comments .comment-meta {
  display: flex;
  justify-content: space-between;
  margin-block-end: 0.9rem;
}
#comments .reply,
#comments .comment-metadata {
  font-size: 11px;
  line-height: 1;
}
#comments .children {
  position: relative;
  list-style: none;
  margin: 0;
  padding-inline-start: 30px;
}
#comments .children li:last-child {
  padding-block-end: 0;
}
#comments ol.comment-list .children:before {
  display: inline-block;
  font-size: 1em;
  font-weight: normal;
  line-height: 100%;
  content: "↪";
  position: absolute;
  top: 45px;
  left: 0;
  width: auto;
}
html[dir=rtl] #comments ol.comment-list .children:before, body.rtl #comments ol.comment-list .children:before {
  content: "↩";
  left: auto;
  right: 0;
}

@media (min-width: 768px) {
  #comments .comment-author,
  #comments .comment-metadata {
    line-height: 1;
  }
}
@media (max-width: 767px) {
  #comments .comment .comment-body {
    padding: 30px 0;
  }
  #comments .children {
    padding-inline-start: 20px;
  }
  #comments .comment .avatar {
    position: inherit;
    float: left;
  }
  html[dir=rtl] #comments .comment .avatar, body.rtl #comments .comment .avatar {
    float: right;
  }
}

/**
 * Navigation Menus
 */
.site-header.header-inverted .site-navigation-toggle-holder {
  justify-content: flex-start;
}
.site-header.header-stacked .site-navigation-toggle-holder {
  justify-content: center;
  max-width: 100%;
}
.site-header.menu-layout-dropdown .site-navigation {
  display: none;
}

.site-navigation-toggle-holder {
  display: flex;
  align-items: center;
  justify-content: flex-end;
  flex-grow: 1;
  max-width: 20%;
  padding: 8px 15px;
}
.site-navigation-toggle-holder .site-navigation-toggle {
  display: flex;
  align-items: center;
  justify-content: center;
  font-size: 22px;
  padding: 0.25em;
  cursor: pointer;
  border: 0 solid;
  border-radius: 3px;
  background-color: rgba(0, 0, 0, 0.05);
  color: #494c4f;
}
.site-navigation-toggle-holder.elementor-active .site-navigation-toggle i:before {
  content: "\e87f";
}

.site-navigation {
  grid-area: nav-menu;
  display: flex;
  align-items: center;
  flex-grow: 1;
}
.site-navigation ul.menu, .site-navigation ul.menu ul {
  list-style-type: none;
  padding: 0;
}
.site-navigation ul.menu {
  display: flex;
  flex-wrap: wrap;
}
.site-navigation ul.menu li {
  position: relative;
  display: flex;
}
.site-navigation ul.menu li a {
  display: block;
  padding: 8px 15px;
}
.site-navigation ul.menu li.menu-item-has-children {
  padding-inline-end: 15px;
}
.site-navigation ul.menu li.menu-item-has-children:after {
  display: block;
  content: "▾";
  font-size: 1.5em;
  align-items: center;
  color: #666666;
  position: absolute;
  right: 0;
  top: 50%;
  transform: translateY(-50%);
  text-decoration: none;
}
.site-navigation ul.menu li.menu-item-has-children:focus-within > ul {
  display: block;
}
.site-navigation ul.menu li ul {
  background: #fff;
  display: none;
  min-width: 150px;
  position: absolute;
  z-index: 2;
  left: 0;
  top: 100%;
}
.site-navigation ul.menu li ul li {
  border-block-end: #eeeeee 1px solid;
}
.site-navigation ul.menu li ul li:last-child {
  border-block-end: none;
}
.site-navigation ul.menu li ul li.menu-item-has-children a {
  flex-grow: 1;
}
.site-navigation ul.menu li ul li.menu-item-has-children:after {
  transform: translateY(-50%) rotate(-90deg);
}
.site-navigation ul.menu li ul ul {
  left: 100%;
  top: 0;
}
.site-navigation ul.menu li:hover > ul {
  display: block;
}

footer .site-navigation ul.menu li ul {
  top: auto;
  bottom: 100%;
}
footer .site-navigation ul.menu li ul ul {
  bottom: 0;
}
footer .site-navigation ul.menu a {
  padding: 5px 15px;
}

.site-navigation-dropdown {
  margin-block-start: 10px;
  transition: max-height 0.3s, transform 0.3s;
  transform-origin: top;
  position: absolute;
  bottom: 0;
  left: 0;
  z-index: 10000;
  width: 100%;
}
.site-navigation-toggle-holder:not(.elementor-active) + .site-navigation-dropdown {
  transform: scaleY(0);
  max-height: 0;
}
.site-navigation-toggle-holder.elementor-active + .site-navigation-dropdown {
  transform: scaleY(1);
  max-height: 100vh;
}
.site-navigation-dropdown ul {
  padding: 0;
}
.site-navigation-dropdown ul.menu {
  position: absolute;
  width: 100%;
  padding: 0;
  margin: 0;
  background: white;
}
.site-navigation-dropdown ul.menu li {
  display: block;
  width: 100%;
  position: relative;
}
.site-navigation-dropdown ul.menu li a {
  display: block;
  padding: 20px;
  background: #ffffff;
  color: #55595c;
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.1019607843);
}
.site-navigation-dropdown ul.menu li.current-menu-item a {
  color: white;
  background: #55595c;
}
.site-navigation-dropdown ul.menu > li li {
  transition: max-height 0.3s, transform 0.3s;
  transform-origin: top;
  transform: scaleY(0);
  max-height: 0;
}
.site-navigation-dropdown ul.menu li.elementor-active > ul > li {
  transform: scaleY(1);
  max-height: 100vh;
}

@media (max-width: 576px) {
  .site-header.menu-dropdown-mobile:not(.menu-layout-dropdown) .site-navigation {
    display: none !important;
  }
}
@media (min-width: 768px) {
  .site-header.menu-dropdown-mobile:not(.menu-layout-dropdown) .site-navigation-toggle-holder {
    display: none !important;
  }
}
@media (min-width: 576px) and (max-width: 767px) {
  .site-header.menu-dropdown-mobile:not(.menu-layout-dropdown) .site-navigation {
    display: none !important;
  }
}
@media (min-width: 992px) {
  .site-header.menu-dropdown-tablet:not(.menu-layout-dropdown) .site-navigation-toggle-holder {
    display: none !important;
  }
}
@media (max-width: 992px) {
  .site-header.menu-dropdown-tablet:not(.menu-layout-dropdown) .site-navigation {
    display: none !important;
  }
}
.site-header.menu-dropdown-none:not(.menu-layout-dropdown) .site-navigation-toggle-holder {
  display: none !important;
}

/**
 * Responsive layouts
 */
.site-header .header-inner, .site-header:not(.dynamic-header), .site-footer .footer-inner, .site-footer:not(.dynamic-footer), body:not([class*=elementor-page-]) .site-main, .page-header .entry-title {
  margin-inline-start: auto;
  margin-inline-end: auto;
  width: 100%;
}

@media (max-width: 575px) {
  .site-header .header-inner, .site-header:not(.dynamic-header), .site-footer .footer-inner, .site-footer:not(.dynamic-footer), body:not([class*=elementor-page-]) .site-main, .page-header .entry-title {
    padding-inline-start: 10px;
    padding-inline-end: 10px;
  }
}
@media (min-width: 576px) {
  .site-header .header-inner, .site-header:not(.dynamic-header), .site-footer .footer-inner, .site-footer:not(.dynamic-footer), body:not([class*=elementor-page-]) .site-main, .page-header .entry-title {
    max-width: 500px;
  }
  .site-header.header-full-width .header-inner {
    max-width: 100%;
  }
  .site-footer.footer-full-width .footer-inner {
    max-width: 100%;
  }
}
@media (min-width: 768px) {
  .site-header .header-inner, .site-header:not(.dynamic-header), .site-footer .footer-inner, .site-footer:not(.dynamic-footer), body:not([class*=elementor-page-]) .site-main, .page-header .entry-title {
    max-width: 600px;
  }
  .site-header.header-full-width {
    max-width: 100%;
  }
  .site-footer.footer-full-width {
    max-width: 100%;
  }
}
@media (min-width: 992px) {
  .site-header .header-inner, .site-header:not(.dynamic-header), .site-footer .footer-inner, .site-footer:not(.dynamic-footer), body:not([class*=elementor-page-]) .site-main, .page-header .entry-title {
    max-width: 800px;
  }
  .site-header.header-full-width {
    max-width: 100%;
  }
  .site-footer.footer-full-width {
    max-width: 100%;
  }
}
@media (min-width: 1200px) {
  .site-header .header-inner, .site-header:not(.dynamic-header), .site-footer .footer-inner, .site-footer:not(.dynamic-footer), body:not([class*=elementor-page-]) .site-main, .page-header .entry-title {
    max-width: 1140px;
  }
  .site-header.header-full-width {
    max-width: 100%;
  }
  .site-footer.footer-full-width {
    max-width: 100%;
  }
}
.site-header + .elementor {
  min-height: calc(100vh - 320px);
}