.razzi-banner-carousel{
    position: relative;
    opacity: 0;

    .banner-item{
        position: relative;
        overflow: hidden;

        &:hover{
            .razzi-icon{
                transform: translateX(3px);
                /*rtl:raw:
	                 transform: translateX(-3px) rotateY(180deg);
                */
            }

            .banner-img:after{
                background-color: rgba($color: #000000, $alpha: 0.2);
            }
        }
    }

    .banner-content,
    .banner-img:after,
    .full-box-button{
        position: absolute;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
    }

    .banner-img{
        &:after{
            content: '';
            display: block;
            transition: ease .3s;
            background-color: rgba($color: #000000, $alpha: 0.3);
        }

        img{
            display: block;
            width: 100%;
        }
    }

    .banner-content{
        padding: 0 30px;
        display: flex;
        flex-direction: column;
        align-items: center;
    }

    .banner-title{
        flex: 0 0 auto;
        font-size: 44px;
        line-height: 1.2;
        margin-top: auto;
        margin-bottom: -114px;
        color: #ffffff;
        width: 100%;
        text-align: center;
        padding-top: 30px;
        padding-bottom: 30px;
    }

    .button-link{
        flex: 0 0 auto;
        margin-top: auto;
        padding-bottom: 40px;
        padding-top: 30px;
        max-width: 100%;
        text-decoration: none;
    }

    .button-text{
        display: block;
        white-space: nowrap;
        text-overflow: ellipsis;
        overflow: hidden;
        color: #1f1f1f;
        background-color: #ffffff;
        line-height: 54px;
        padding: 0 26px;
        min-width: 190px;

        .razzi-icon{
            margin-left: 11px;
        }

    }

    .swiper-pagination{
        position: relative;
        margin-top: 30px;
    }
}

.razzi-banner-carousel__inner{
    display: flex;
}

.razzi-banner-carousel__btn-position-center {
    .banner-content {
        justify-content: center;
    }

    .banner-title {
        margin: 0;
        padding: 0;
    }

    .button-link {
        margin: 0;
    }
}