.razzi-products-slider {
	.product-wrapper {
		display: flex;
	}

	.product-thumbnail {
		max-width: 100px;
		margin-right: 27px;
	}

	.woocommerce-loop-product__title {
		font-size: 18px;
		line-height: 26.64px;
		font-weight: 500;
		margin-top: 0;
		margin-bottom: 3px;
	}

	.meta-cat {
		display: block;
		font-size: 16px;
		font-weight: 400;
		color: #767676;
		margin-bottom: 12px;
	}

	.rating-count {
		display: flex;
		align-items: center;
		margin-bottom: 15px;

		.star-rating {
			margin-top: 0;
			margin-right: 5px;
			margin-left: 0;

			.user-rating .razzi-svg-icon {
				color: #F8B86D;
			}
		}

		.razzi-svg-icon {
			display: inline-block;
		}

		.review-count {
			color: #909090;
			font-size: 13px;
			font-weight: 400;
			line-height: 1;
		}
	}

	.price {
		color: var(--rz-color-dark);
		font-size: 16px;
		font-weight: 500;

		ins {
			color: var(--rz-color-primary);
			background-color: transparent;
			padding-left: 5px;
		}

		del {
			font-size: 14px;
			color: #A0A0A0;
		}
	}

	.rz-loop_atc_button {
		position: relative;
		padding: 11px 24px;
		min-width: 140px;
		background-color: var(--rz-color-dark);
		color: var(--rz-color-lighter);
		display: inline-flex;
		align-items: center;
		font-weight: 500;
		margin-top: 24px;
		transition: 0.35s;

		&:not(.loading) {
			&:before,
			&:after {
				display: none;
			}
		}

		&:before {
			opacity: 1;
			width: 16px;
			height: 16px;
			display: inline-block;
			border-radius: 50%;
			border: 2px solid;
			border-top-color: transparent;
			-webkit-animation: razzi-spin infinite 1s linear;
			animation: razzi-spin infinite 1s linear;
			transition: opacity .2s linear .2s;
			content: "";
		}

		&.loading {
			&:before {
				position: absolute;
				top: 50%;
				left: 50%;
				margin-top: -8px;
				margin-left: -8px;
				color: #ffffff;
			}

			.loop_button-text,
			.razzi-svg-icon {
				opacity: 0.2;
			}
		}

		.loop_button-text {
			order: 1;
			margin-right: 10px;
		}

		.razzi-svg-icon {
			order: 2;
		}
	}

	.added_to_cart {
		display: none;
	}

	.swiper-pagination {
		display: inline-flex;
		flex-direction: column;
		width: auto;
		position: absolute;
		top: 50%;
		right: 24px;
		left: auto;
		bottom: auto;
		transform: translateY(-50%);
		margin: 0;
	}
}

.razzi-products-slider__item {
	position: relative;
}

.razzi-products-slider__content {
	position: absolute;
	top: 50%;
	transform: translateY(-50%);
	display: inline-block;
	background-color: #ffffff;
	padding: 47px 58px 49px 58px;
	width: 470px;
}

.razzi-products-slider__title {
	font-size: 36px;
	font-weight: 500;
	line-height: 48px;
	color: var(--rz-color-dark);
	margin-bottom: 46px;
}

.razzi-products-slider__sale {
	display: inline-flex;
	flex-direction: column;
	align-items: center;
	justify-content: center;
	text-align: center;
	position: absolute;
	right: -48px;
	top: -48px;
	width: 96px;
	height: 96px;
	background-color: #FF6F61;
	border-radius: 100%;

	span {
		color: #FFFFFF;
		font-size: 16px;
		font-weight: 500;
		line-height: 1;
		margin-bottom: 4px;

		&.razzi-products-slider__sale-text {
			font-size: 30px;
			font-weight: 600;
			margin-bottom: 0;
		}
	}
}