.razzi-sale-box {
    display: flex;
    justify-content: center;
    align-items: center;
}

.razzi-sale-box__content {
    min-width: 120px;
    min-height: 120px;
    line-height: 1;
    text-align: center;
    border-radius: 50%;
    padding: 15px;
    background-color: var( --rz-background-color-primary );
    color: var( --rz-color-lighter );
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
}

.razzi-sale-box__count {
    display: flex;
    align-items: center;
    justify-content: center;
    font-size: 36px;
    font-weight: 600;
}

.razzi-sale-box__text {
    font-size: 18px;
    font-weight: 500;
    margin-bottom: 7px;
}