.razzi-products-carousel {
    ul.swiper-wrapper {
        margin: 0;
        box-sizing: border-box;

        li {
            clear: none;
            padding-left: 0;
            padding-right: 0;
            margin-bottom: 0;
        }
    }

    ul.products {
        flex-wrap: nowrap;
        list-style: none;

        &:not(.swiper-wrapper) {
			overflow: hidden;
		}

        li.product {
            padding-left: 0;
            padding-right: 0;
            margin-bottom: 0;

            &:not(.swiper-slide) {
                flex-shrink: 0;
                margin-right: 30px;
            }
        }
    }

    .swiper-container-multirow {
        ul.products {
            flex-wrap: wrap;
        }
    }

    .swiper-scrollbar {
        max-width: 570px;
        background-color: #e5e5e5;
        cursor: pointer;
        height: 4px;
        border-radius: 0;
        position: static;
        width: 100%;
        margin: 5px auto 40px;
    }

    .swiper-scrollbar-drag {
        background-color: var(--rz-background-color-primary);
        cursor: pointer;
    }

    .razzi-grid-button {
        text-align: center;
        margin-top: 20px;

        a {
            line-height: 54px;
            padding: 0 44px;
        }

        .razzi-svg-icon {
            font-size: 13px;
        }
    }

    .product-loop-outsite {
        margin-left: -15px;
        margin-right: -15px;

        .swiper-container {
            padding-left: 15px;
            padding-right: 15px;
        }
    }
}

.elementor-section:not(.elementor-section-full_width) {
    .razzi-swiper-carousel-elementor:not(.razzi-product-category-tabs) {
        ul.product-loop-layout-12,
        ul.product-loop-layout-6,
        ul.product-loop-layout-5 {
            li.product {
                margin-bottom: 15px;
                padding-top: 15px;
            }
        }
    }
}

.razzi-products-carousel__heading--arrows {
    display: flex;
    justify-content: space-between;
    align-items: center;
    .rz-swiper-button {
        position: static;
        transform: none;
        width: auto;
        height: auto;
        line-height: normal;
    }
}