<?php
/**
 * Template file for displaying mobile search
 *
 * @package Razzi
 */
?>

<div class="mobile-search">
	<a href="#" class="search-icon" data-toggle="modal" data-target="search-modal">
		<?php echo \Razzi\Icon::get_svg('search', '', 'shop'); ?>
	</a>
</div>