.woocommerce-cart {
	.woocommrece-cart-content {
		position: relative;

		&:after {
			clear: both;
			content: '';
			display: block;
		}
	}
	.woocommerce-cart-form {
		float: left;
		width: 66%;
		padding-right: 100px;
		position: relative;
	}

	table.shop_table {
		a {
			text-decoration: none;
		}

		tbody {
			td {
				padding: 30px;
			}
		}

		.woocommerce-cart-form__cart-item {
			> td {
				padding-left: 0;
				padding-right: 0;
			}
		}

		td.product-thumbnail {
			padding-right: 30px;
			line-height: 1;

			a {
				display: block;
				max-width: 140px;
			}

			img {
				min-width: 140px;
			}
		}

		button[name="update_cart"].hide {
			display: none;
		}


		.product-top ,
		.product-bottom {
			display: flex;
			justify-content: space-between;
		}

		.product-bottom {
			align-items: center;
			margin-top: 15px;
		}

		.product-content {
			display: flex;
			flex-direction: column;
			justify-content: center;
			min-height: 200px;
		}

		.product-name {
			width: 100%;

			a {
				display: inline-block;
				font-weight: 500;
				font-size: 16px;
				line-height: 23px;
				margin-bottom: 5px;
			}

			.variation {
				color: var( --rz-text-color-gray );
				font-weight: 400;
				font-size: 15px;
				letter-spacing: 0;
				margin: 0 0 10px;

				dt {
					font-weight: 400;
				}

				dd {
					margin: 0 0 5px;
				}

				p {
					margin: 0;
				}
			}
		}

		.product-price {
			font-weight: 500;
			font-size: 16px;
			line-height: 23px;
			color: var( --rz-color-dark );
		}

		.product-remove {
			.remove {
				display: flex;
				align-items: center;
				color: #919191;
				font-size: 14px;
				line-height: 21px;

				.razzi-svg-icon {
					font-size: 14px;
					margin-right: 5px;
					transition: .5s;
				}

				span {
					font-size: 14px;
				}

				&:hover {
					color: var( --rz-color-dark );
				}
			}
		}

		.product-qty {
			.quantity {
				.qty {
					width: 68px;
					height: 34px;
					padding: 0 10px;
				}
			}
		}

		.razzi-quantity-dropdown {

			.current {
				width: 68px;
				height: 34px;

				.razzi-svg-icon {
					margin: 0;
					transform: translateY(-50%);
				}
			}

			.qty-options {
				width: 68px;
				top: 33px;
			}
		}

		.coupon-form {
			td {
				padding-left: 0;
				padding-right: 0;
				padding-bottom: 0;
			}

			.coupon {
				float: left;

				label {
					font-weight: 500;
					font-size: 15px;
					line-height: 22px;
					color: var( --rz-color-dark );
					margin-bottom: 10px;
					display: block;
				}

				input {
					min-width: 265px;
				}
			}

			.actions {
				> button {
					float: right;
					margin-top: 32px;

					&:disabled {
						opacity: 0.3;
					}
				}
			}
		}
	}

	table.woocommerce-cart-form__contents {
		margin-bottom: 0;
	}

	.cart-collaterals {
		float: left;
		width: 34%;
		margin-bottom: 135px;
		position: -webkit-sticky;
		position: sticky;
		top: 50px;

		.cart_totals {
			background-color: var( --rz-background-color-gray );
			padding: 5px 30px;

			h2 {
				display: none;
			}
		}

		.shop_table {
			margin: 0;

			@include razzi-input-radio();

			input[type="radio"] + label {
				display: flex;
				justify-content: space-between;
				width: 100%;
			}

			tr {
				font-size: 15px;
				line-height: 22px;
				color: var( --rz-color-dark );

				th {
					font-size: 16px;
					border: none;
					padding: 20px 15px 20px 0;
				}

				td {
					text-align: right;
					padding: 20px 0;

					ul {
						margin: 0;
						padding: 0;
						list-style-type: none;
					}
				}

				&.order-total {
					font-size: 18px;
					font-weight: 500;

					strong {
						font-weight: 500;
					}

					th {
						font-size: inherit;
						font-weight: inherit;
					}
				}

				&.woocommerce-shipping-totals {
					td {
						text-align: left;
					}

					h3 {
						font-size: 16px;
						font-weight: 400;
						line-height: 24px;
						margin-top: 0;
					}

					p {
						margin-bottom: 13px;
					}

					a {
						text-decoration: underline;
					}

					.select2-container {
						background-color: var( --rz-background-color-light );
					}
				}
			}

			.shipping-calculator-form {
				.form-row-wide {
					input {
						width: 100%;
					}
				}
			}
		}

		.wc-proceed-to-checkout {
			position: absolute;
			left: 0;
			width: 100%;
			margin-top: 30px;

			a.button {
				@include razzi-button();
				text-decoration: none;
				width: inherit;
				line-height: 54px;
			}

			.continue-button {
				padding: 0;

				.razzi-svg-icon {
					transform: rotate(-180deg);
					margin: 0 16px 0 0;
					/*rtl:raw:
					transform: rotate(0);
					*/
				}

				&:hover {
					.razzi-svg-icon {
						transform: translateX(-3px) rotate(-180deg);
						/*rtl:raw:
						transform: translateX(-3px);
						*/
					}
				}
			}
		}
	}

	.cross-sells {
		margin-top: 80px;
		float: left;
		width: 100%;

		> h2 {
			font-size: 28px;
			text-align: center;
			margin: 0 0 60px;
		}

		ul.products {
			flex-wrap: nowrap;
			margin: 0;
			box-sizing: border-box;

			li {
				clear: none;
				padding-left: 0;
				padding-right: 0;
				margin-bottom: 0;
			}
		}

		.swiper-scrollbar {
			max-width: 570px;
			background-color: #e5e5e5;
			cursor: pointer;
			height: 4px;
			border-radius: 0;
			position: static;
			width: 100%;
			margin: 40px auto 0;
		}

		.swiper-scrollbar-drag {
			background-color: var(--rz-background-color-primary);
			cursor: pointer;
		}
	}
}

.return-to-shop {
	.wc-backward {
		@include razzi-button();
	}
}