.single-product {
	div.product {
		section.products {
			margin-top: 70px;

			&:nth-child(2) {
				margin-top: 100px;
			}

			> h2 {
				font-size: 28px;
				text-align: center;
				margin: 0 0 60px;
			}

			.swiper-container-initialized ul.products {
				flex-wrap: nowrap;
				box-sizing: border-box;
				margin: 0;
				width: 100%;

				li {
					clear: none;
					margin-bottom: 0;
					padding-left: 0;
					padding-right: 0;
				}

				&.product-loop-layout-10 {
					li.swiper-slide {
						.product-inner:hover {
							height: 100%;
						}
					}
				}
			}

			.rz-swiper-button {
				width: 42px;
				height: 42px;
				line-height: 42px;
				display: inline-block;
				text-align: center;
				opacity: .5;
				transition: .5s;
				cursor: pointer;
				z-index: 99;
				position: absolute;
				top: 40%;
				left: 0;
				transform: translate(0,-50%);
				font-size: 22px;
				color: var(--rz-color-dark);
				background-color: #fff;

				&:hover {
					opacity: 1;
				}
			}

			.rz-swiper-button-next {
				right: 0;
				left: auto;
			}

			.swiper-scrollbar {
				max-width: 570px;
				background-color: #e5e5e5;
				cursor: pointer;
				height: 4px;
				border-radius: 0;
				position: static;
				width: 100%;
				margin: 40px auto 0;
			}

			.swiper-scrollbar-drag {
				background-color: var(--rz-background-color-primary);
				cursor: pointer;
			}
		}
	}
}

.single-product.razzi-product-card-solid {
	div.product {
		section.products {
			.swiper-container-initialized ul.products {
				li {
					padding-left: 0;
					padding-right: 0;
				}
			}
		}
	}
}