/*!*************************************************************************************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[4].use[1]!./node_modules/postcss-loader/dist/cjs.js??ruleSet[1].rules[4].use[2]!./node_modules/sass-loader/dist/cjs.js??ruleSet[1].rules[4].use[3]!./assets/dev/js/admin/hello-admin.scss ***!
  \*************************************************************************************************************************************************************************************************************************************************************/
#hello-elementor-settings .components-placeholder {
  background: #f1f1f1;
}
#hello-elementor-settings .hello_elementor__header {
  padding: 20px 10px;
  margin-inline-start: -2em;
  background-color: #ffffff;
  box-shadow: 0 1px 0 rgba(213, 213, 213, 0.5), 0 1px 2px #eeeeee;
}
#hello-elementor-settings .hello_elementor__header .hello_elementor__container {
  max-width: 750px;
  margin: 0 auto;
}
#hello-elementor-settings .hello_elementor__header .hello_elementor__container .hello_elementor__title {
  display: flex;
  justify-content: center;
  align-items: center;
}
#hello-elementor-settings .hello_elementor__header .hello_elementor__container .hello_elementor__title .dashicon {
  color: #757575;
}
#hello-elementor-settings .hello_elementor__main {
  max-width: 750px;
  margin-inline-start: auto;
  margin-inline-end: auto;
}
#hello-elementor-settings .hello_elementor__main .components-panel {
  background: none;
  border: none;
}
#hello-elementor-settings .hello_elementor__main .components-panel__body {
  margin: 1rem 0;
  border: 1px solid #e2e4e7;
  background: #ffffff;
}
#hello-elementor-settings .hello_elementor__main .components-notice {
  margin: 0;
  margin-block-end: 20px;
}
#hello-elementor-settings .hello_elementor__main .components-notice .dashicon {
  padding-inline-end: 10px;
  color: #f0b849;
}
#hello-elementor-settings .hello_elementor__main .components-notice button {
  display: none;
}
#hello-elementor-settings .hello_elementor__main .code-example {
  display: inline-block;
  margin-block-end: 1.5rem;
  border-radius: 4px;
  font-size: 10px;
}
#hello-elementor-settings .components-base-control__help {
  margin-block-start: 0.5rem;
}
#hello-elementor-settings .hello_elementor__notices .components-snackbar {
  position: fixed;
  bottom: 0.5rem;
}

/*# sourceMappingURL=hello-admin.css.map*/