.razzi-heading-title {
    padding: 0;
    margin: 0;
    line-height: 1;

    small {
        font-size: 13px;
        display: block;
        color: #A0A0A0;
        text-transform: uppercase;
        margin-bottom: 15px;
    }
}

h2.razzi-heading-title {
    font-size: 36px;
}