.razzi-catalog-page {
	.page-header__title {
		color: var(--rz-color-dark);
	}
}

.page-header--layout-2,
.catalog-page-header--layout-2 {
	position: relative;
	.featured-image {
		display: block;
		position: absolute;
		left: 0;
		top: 0;
		width: 100%;
		height: 100%;
		background-size: cover;
		background-repeat: no-repeat;
		background-position: 50% 50%;
	}

	.page-header__content {
		position: relative;
		text-align: center;
		display: flex;
		flex-direction: column;
	}

	.site-breadcrumb,
	.woocommerce-breadcrumb {
		padding: 0;
		justify-content: center;
		order: 2;
	}

	.page-header__title {
		order: 1;
		padding: 0 0 6px;
	}
}

.catalog-page-header--layout-2 .featured-image::before,
.page-header--layout-2 .featured-image::before {
	content: '';
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
}