<?php
/**
 * Template part for displaying the search icon
 *
 * @package Razzi
 */
?>
<div class="header-hamburger hamburger-menu">
	<span data-toggle="modal" data-target="hamburger-modal">
		<?php echo \Razzi\Icon::get_svg( 'hamburger' ); ?>
	</span>
</div>
