.ra-menu-mobile-modal {
    .menu-mobile-panel-content {
        height: 100%;
        display: flex;
        flex-direction: column;
        overflow-y: auto;
    }

    .modal-header {
        justify-content: flex-start;
    }

    .modal-content {
        display: flex;
        flex-direction: column;
        justify-content: space-between;
        align-items: flex-start;
        padding-top: 60px;
        padding-bottom: 0;
    }

    .content-footer {
        padding: 40px 0;
    }

    ul.nav-menu {
        ul {
            padding-left: 5px;

            li {
                a {
                    font-size: 20px;
                    line-height: 1.5;
                }
            }
        }

        li {
            &.menu-item-has-children {
                .toggle-menu-children {
                    display: block;
                }

                > a {
                    padding-right: 25px;
                }
            }
        }

        > li {
            padding-left: 0;
            width: 100%;
            flex-direction: column;
            align-items: flex-start;

            > a {
                font-size: 24px;
            }
        }

        a {
            line-height: 36px;
        }
    }
}

.razzi-menu-badges {
	--rz-badges-bg-color: #dd3333;
	white-space: nowrap;
    font-weight: 600;
    font-size: 9px;
	line-height: 12px;
	padding: 2px 4px;
	bottom: 15px;
    right: -5px;
	background-color: var(--rz-badges-bg-color);
	color: var(--rz-color-lighter);
	position: relative;

	&:before {
		content: "";
		position: absolute;
		top: 100%;
		left: 0;
		border: 4px solid;
		border-right-color: transparent !important;
		border-bottom-color: transparent !important;
		border-right-width: 7px;
		border-left-width: 0;
		border-color: var(--rz-badges-bg-color);
	}
}