:root {
	--rz-color-primary: #FF6F61;
	--rz-color-lighter: #ffffff;
	--rz-color-dark: #111111;
	--rz-color-darker: #1f1f1f;
	--rz-color-placeholder: #A0A0A0;

	--rz-color-hover-primary: #FF6F61;

	--rz-background-color-primary: #FF6F61;
	--rz-background-color-light: #ffffff;
	--rz-background-color-gray: #f5f5f5;
	--rz-background-color-dark: #1F1F1F;

	--rz-background-text-color-primary: #ffffff;

	--rz-border-color: #cccccc;
	--rz-border-color-primary: #FF6F61;
	--rz-border-color-light: #e2e2e2;
	--rz-border-color-lighter: #ffffff;
	--rz-border-color-gray: #cdcdcd;
	--rz-border-color-dark: #1f1f1f;

	--rz-text-color-gray: #767676;
	--rz-text-color: #525252;

	--rz-font-family-primary: 'Jost', Arial, sans-serif;
	--rz-font-family-code: Monaco, Consolas, "Andale Mono", "DejaVu Sans Mono", monospace;
	--rz-font-family-pre: "Courier 10 Pitch", Courier, monospace;
}