table {
	margin: 0 0 1.5em;
	width: 100%;
	border-collapse: collapse;
	border-spacing: 0;
	border-width: 1px 0 0 1px;
}

caption,
td,
th {
	padding: 0;
	font-weight: normal;
	text-align: left;
}

table,
th,
td {
	border: 1px solid var(--rz-border-color-gray);
}

th {
	border-width: 0 1px 1px 0;
}

td {
	border-width: 0 1px 1px 0;
}

th,
td {
	padding: 10px;
}

thead th{
	font-weight: 500;
}

table.large-padding{
	thead{
		th,td{
			padding: 12px 30px;
		}
	}

	th,
	td {
		padding: 18px 30px;
	}
}