.razzi-history-products{
    margin-bottom: 80px;
    position: relative;

    .recently-header{
        margin: 0 0 40px;
        display: flex;
        align-items: center;
        justify-content: space-between;

        &.no-button {
            justify-content: center;
        }
    }

    .recently-title{
        font-size: 28px;
        margin: 0 25px 0 0;
    }

    &:not(.grid-type){
        ul.products{
            margin: 0;
            flex-wrap: initial;

            li.product{
                padding: 0;
            }
        }
    }

    .product-list{
        list-style: none;
        padding: 0;

        &.no-products{
            li{
                width: 100%;
            }

            .razzi-button{
                margin-top: 35px;
            }
        }

        li{
            display: inline-block;

            .product-infor{
                display: none;
                width:auto;
                min-width: 150px;
                position:absolute;
                top:100px;
                z-index:10002;
                box-shadow: 3px 4px 5px rgba(0,0,0,.3);
                padding: 10px 25px;
                background-color: rgba(255,255,255,.9);
                text-align: center;
            }

            .product-title{
                margin: 0 0 3px;
                white-space: nowrap;
            }

            .product-price{
                color: var(--rz-text-color-gray);
                font-size: 16px;
                font-weight: 500;
                white-space: nowrap;

                del {
                    font-size: 14px;
                    color: #a6a6a6;
                }

                ins {
                    background-color: transparent;
                    color: var(--rz-color-primary);
                    padding-left: 5px;
                }
            }

            .hover-image {
                position: absolute;
                top: 0;
                left: 0;
                opacity: 0;
                transition: opacity .4s;
            }

            &:hover .hover-image {
                opacity: 1;
            }
        }
    }

    .swiper-scrollbar{
        max-width: 570px;
        background-color: #e5e5e5;
        cursor: pointer;
        height: 4px;
        border-radius: 0;
        position: static;
        width: 100%;
        margin: 40px auto 0;
    }

    .swiper-scrollbar-drag{
        background-color: var(--rz-background-color-primary);
        cursor: pointer;
    }

    .razzi-posts__loading{
        display: block;
    }

    &.loaded{
        .razzi-posts__loading{
            display: none;
        }
    }

    &.hide-empty{
        display: none;
    }
}

.single-product{
    .razzi-history-products{
        .recently-header{
            margin-bottom: 60px;
        }
    }
}