.razzi-banner-video{
    position: relative;

    .full-box-button,
	.banner-featured-image{
		position: absolute;
		top: 0;
		left: 0;
		width: 100%;
		height: 100%;
    }

    .full-box-button{
        z-index: 1;
    }
}
.razzi-banner-video__marker .razzi-icon,
.razzi-banner-video__marker{
	position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
}

.razzi-banner-video__marker{
    &:after{
    	content: '';
		display: block;
		width: 68px;
		height: 68px;
		border-radius: 50%;
		background-color: #fff;
    }

    .razzi-icon{
    	line-height: 1;
    	color: #000;
    	font-size: 24px;
    }
}