h1, h2, h3, h4, h5, h6 {
	font-weight: 500;
	color: var(--rz-color-dark);
	line-height: 1.33
}

h1 {
	@include font-size(60/16);
}

h2 {
	@include font-size(40/16);
}

h3 {
	@include font-size(32/16);
}

h4 {
	@include font-size(24/16);
}

h5 {
	@include font-size(20/16);
}

h6 {
	@include font-size(16/16);
}
