.razzi-product-shortcode {
    background-color: var( --rz-background-color-gray );
    padding: 90px 0 100px;

    &.single-product {
        div.product {
            .woocommerce-product-gallery {
                width: 45%;

                .flex-control-thumbs {
                    margin: 15px 0 0 0;

                    li {
                        padding: 0;
                    }
                }
            }

            .summary-price-box .price {
                font-size: 22px;
            }

           .entry-summary {
               width: 55%;
               padding-left: 70px;
               padding-right: 40px;
               padding-top: 35px;

               .product_title {
                   font-size: 32px;
               }
           }

           &.product-type-variable form.variations_form .variations td.value {
                margin-bottom: 20px;
           }
        }
    }

    &.razzi-swiper-carousel-elementor {
        .rz-swiper-button {
            width: 30px;
            height: 50px;
            line-height: 50px;
            font-size: 12px;
        }

        .rz-swiper-button {
            opacity: 0;
        }

        .rz-gallery-button-next {
            right: 0;
        }

        .linked-gallery-carousel {
            &:hover {
                .rz-swiper-button {
                    opacity: 1;
                }
            }
        }
    }

    .rz-product-wrapper {
        background-color: var( --rz-background-color-light );
        padding: 30px;
        display: flex;
        box-shadow: 0px 0.5px 10px 0px rgba(0, 0, 0, 0.07);
    }
}