.page-header__title{
    font-size: 28px;
    padding: 0 0 10px;
    margin: 0;
    line-height: 1.2;
}

.page-header {
    .site-breadcrumb {
        padding-bottom: 5px;
        overflow: auto;
        white-space: nowrap;

        .delimiter {
            margin: 0 5px;
        }

        a {
            color: #909090;
        }
    }
}

.razzi-hide-on__breadcrumb {
    .site-breadcrumb {
        display: none;
    }
}

.razzi-hide-on__title {
    .page-header__title {
        display: none;
    }
}

.razzi-catalog-page-content__no-top-spacing {
    .site-content {
        padding-top: 0;
    }
}

.mobile-catalog-page-header--layout-2 {
	position: relative;
    margin-left: -15px;
    margin-right: -15px;
	.featured-image {
		display: block;
		position: absolute;
		left: 0;
		top: 0;
		width: 100%;
		height: 100%;
		background-size: cover;
		background-repeat: no-repeat;
		background-position: 50% 50%;

        &::before {
            content: '';
            position: absolute;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
        }
	}

	.page-header__content {
		position: relative;
		text-align: center;
		display: flex;
		flex-direction: column;
        padding: 42px 0 19px;
	}

	.woocommerce-breadcrumb {
		padding: 0;
		justify-content: center;
		order: 2;
	}

	.page-title {
		order: 1;
		padding: 0 0 6px;
        font-size: 32px;
        margin: 0;
        text-align: center;
	}
}