<?php
/**
 * Template file for displaying filter mobile
 *
 * @package Razzi
 */

?>

<a href="#" class="rz-navigation-bar__btn-place-order rz-loop_atc_button rz-navigation-bar_icon"><?php echo \Razzi\Icon::get_svg( 'checkout', '', 'mobile' ) . '<span class="checkout-text-button">' . esc_html__( 'Place order', 'razzi' ) . '</span' ?></a>