.wp-block-embed.wp-embed-aspect-1-1 .wp-block-embed__wrapper,
.wp-block-embed.wp-embed-aspect-1-2 .wp-block-embed__wrapper,
.wp-block-embed.wp-embed-aspect-4-3 .wp-block-embed__wrapper,
.wp-block-embed.wp-embed-aspect-9-16 .wp-block-embed__wrapper,
.wp-block-embed.wp-embed-aspect-16-9 .wp-block-embed__wrapper,
.wp-block-embed.wp-embed-aspect-18-9 .wp-block-embed__wrapper,
.wp-block-embed.wp-embed-aspect-21-9 .wp-block-embed__wrapper{
	position: relative;
}

.wp-block-embed.wp-embed-aspect-1-1 .wp-block-embed__wrapper:before,
.wp-block-embed.wp-embed-aspect-1-2 .wp-block-embed__wrapper:before,
.wp-block-embed.wp-embed-aspect-4-3 .wp-block-embed__wrapper:before,
.wp-block-embed.wp-embed-aspect-9-16 .wp-block-embed__wrapper:before,
.wp-block-embed.wp-embed-aspect-16-9 .wp-block-embed__wrapper:before,
.wp-block-embed.wp-embed-aspect-18-9 .wp-block-embed__wrapper:before,
.wp-block-embed.wp-embed-aspect-21-9 .wp-block-embed__wrapper:before{
	content: "";
	display: block;
	padding-top: 50%;
}

.wp-block-embed.wp-embed-aspect-16-9 .wp-block-embed__wrapper:before {
	padding-top: 56.25%;
}

.wp-block-embed.wp-embed-aspect-1-1 .wp-block-embed__wrapper iframe,
.wp-block-embed.wp-embed-aspect-1-2 .wp-block-embed__wrapper iframe,
.wp-block-embed.wp-embed-aspect-4-3 .wp-block-embed__wrapper iframe,
.wp-block-embed.wp-embed-aspect-9-16 .wp-block-embed__wrapper iframe,
.wp-block-embed.wp-embed-aspect-16-9 .wp-block-embed__wrapper iframe,
.wp-block-embed.wp-embed-aspect-18-9 .wp-block-embed__wrapper iframe,
.wp-block-embed.wp-embed-aspect-21-9 .wp-block-embed__wrapper iframe{
	position: absolute;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	width: 100%;
	height: 100%;
}

.blocks-gallery-caption,
.wp-block-embed figcaption,
.wp-block-image figcaption{
	color: #555d66;
	font-size: 13px;
	text-align: center;
}

