/*!
Theme Name: Razzi
Theme URI: http://demo4.drfuri.com/razzi
Author: DrFuri
Author URI: http://demo2.drfuri.com
Description: Woocommerce WordPress Theme
Version: 1.5.2
Requires at least: 5.0
Tested up to: 5.8
Requires PHP: 7.0
License: GNU General Public License v2+
License URI: http://www.gnu.org/licenses/gpl-2.0.html
Text Domain: razzi
Domain Path: /lang/
Tags: one-column, two-columns, left-sidebar, right-sidebar, full-width-template, post-formats, theme-options, threaded-comments, translation-ready

*/

/**
 * WooCommerce color variables
 */
 $woocommerce__color-error: #e2401c;
 $woocommerce__color-success: #0f834d;
 $woocommerce__color-info: #3D9CD2;

/**
 * Imports
 */
 @import "variables-site/variables-sites";
 @import "mixins/mixins-master";
 @import "shop/columns";

 /**
 * Shop tables
 */
@import "shop/tables";

/**
 * WooCommerce widgets
 */
 @import "shop/widgets";

/**
* Products
*/
@import "mobile/shop/products";

 /**
 * Products filter
 */
@import "mobile/shop/products-filter";

/**
 * Single product
 */
 @import "mobile/shop/single-product";

 /**
 * Account
 */
@import "mobile/shop/account";

/**
 * Cart
 */
 @import "mobile/shop/cart";

/**
 * Checkout
 */
 @import "mobile/shop/checkout";

/**
 * General WooCommerce components
 */
@import "shop/components";

@import "shop/recently-viewed";
