.razzi-lookbook-banner{
    .product-item{
        display: inline-flex;
        align-items: center;
        padding: 10px;
        background-color: #ffffff;
        position: absolute;
        width: 290px;
        left: -49px;
        top: 22px;
        opacity: 0;
        pointer-events: none;
        transition: .3s;
        box-shadow: 0px 0px 20px rgba(0, 0, 0, 0.06);

        .product-image{
            margin-right: 24px;

            img{
                display: block;
                max-width: 100px;
            }
        }

        .product-name{
            margin: 0 0 5px;
        }

        .product-price{
            font-size: 15px;
            font-weight: 600;
            color: #767676;

            ins{
                background-color: transparent;
                color: var(--rz-color-primary);
                padding-left: 5px;
            }
        }

        .razzi-slide-button{
            position: absolute;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
        }
    }

    .razzi-lookbook-item {
        position: absolute;
        top: 40%;
        left: 40%;
        cursor: pointer;
        z-index: 2;

	    --rz-lookbook-color-primary: #ffffff;

        &:after{
            content: '';
            display: block;
            width: 16.8px;
            height: 16.8px;
            background-color: var(--rz-lookbook-color-primary);
            border-radius: 50%;
        }

        &:before{
            content: '';
            display: block;
            width: 42px;
            height: 42px;
            background-color: var(--rz-lookbook-color-primary);
            opacity: .15;
            border-radius: 50%;
            position: absolute;
            left: calc(-50% - 4.4px);
            top: calc(-50% - 4.4px);
            animation: anim-ripple 1.5s linear 0s infinite;
        }

        &.active{
            .product-item{
                opacity: 1;
                z-index: 1;
                pointer-events: all;
            }
        }
    }
}