// Main
.footer-main{
    font-size: 14px;
    padding: 22px 0;
    --rz-footer-main-border-color: #2b2b2b;
    --rz-footer-main-top-spacing: 22px;
    --rz-footer-main-bottom-spacing: 22px;

    .site-footer-dark &,
    .site-footer-custom & {
        padding-top: var( --rz-footer-main-top-spacing );
        padding-bottom: var( --rz-footer-main-bottom-spacing );
    }

    .site-footer-light &,
    .site-footer-gray &{
        .footer-container {
            padding-top: var( --rz-footer-main-top-spacing );
            padding-bottom: var( --rz-footer-main-bottom-spacing );
        }
    }

    &.has-divider{
        .footer-container {
            &:before {
                content: '';
                position: absolute;
                top: 0;
                left: 0;
                right: 0;
                width: 100%;
                height: 1px;
                background-color: var( --rz-footer-main-border-color );
            }
        }
    }

    .footer-container{
        display: flex;
        align-items: center;
    }

    .footer-items{
        display: flex;
        align-items: center;
    }
}

.header-v6 .footer-main {font-size: 16px}