<?php
/**
 * Template file for displaying mobile history back
 *
 * @package Razzi
 */
?>
<a href="<?php echo esc_url( home_url( '/' ) ) ?>"
   class="razzi-history-back"><?php echo \Razzi\Icon::get_svg( 'chevron-left' ); ?></a>