/*!
Theme Name: Razzi
Theme URI: http://demo4.drfuri.com/razzi
Author: DrFuri
Author URI: http://demo2.drfuri.com
Description: Woocommerce WordPress Theme
Version: 1.5.2
Requires at least: 5.0
Tested up to: 5.8
Requires PHP: 7.0
License: GNU General Public License v2+
License URI: http://www.gnu.org/licenses/gpl-2.0.html
Text Domain: razzi
Domain Path: /lang/
Tags: one-column, two-columns, left-sidebar, right-sidebar, full-width-template, post-formats, theme-options, threaded-comments, translation-ready

*/
/*--------------------------------------------------------------
>>> TABLE OF CONTENTS:
----------------------------------------------------------------
# Normalize
# Typography
# Elements
# Forms
# Navigation
	## Links
	## Menus
# Accessibility
# Alignments
# Clearings
# Widgets
# Content
	## Posts and pages
	## Comments
# Infinite scroll
# Media
	## Captions
	## Galleries
--------------------------------------------------------------*/
:root {
	--rz-color-primary: #FF6F61;
	--rz-color-lighter: #ffffff;
	--rz-color-dark: #111111;
	--rz-color-darker: #1f1f1f;
	--rz-color-placeholder: #A0A0A0;
	--rz-color-hover-primary: #FF6F61;
	--rz-background-color-primary: #FF6F61;
	--rz-background-color-light: #ffffff;
	--rz-background-color-gray: #f5f5f5;
	--rz-background-color-dark: #1F1F1F;
	--rz-background-text-color-primary: #ffffff;
	--rz-border-color: #cccccc;
	--rz-border-color-primary: #FF6F61;
	--rz-border-color-light: #e2e2e2;
	--rz-border-color-lighter: #ffffff;
	--rz-border-color-gray: #cdcdcd;
	--rz-border-color-dark: #1f1f1f;
	--rz-text-color-gray: #767676;
	--rz-text-color: #525252;
	--rz-font-family-primary: 'Jost', Arial, sans-serif;
	--rz-font-family-code: Monaco, Consolas, "Andale Mono", "DejaVu Sans Mono", monospace;
	--rz-font-family-pre: "Courier 10 Pitch", Courier, monospace;
}

@keyframes razzi-rotate {
	0% {
		transform: rotate(0deg) scale(1);
	}
	50% {
		transform: rotate(-180deg) scale(0.6);
	}
	100% {
		transform: rotate(-360deg) scale(1);
	}
}

@keyframes razzi-scale {
	30% {
		transform: scale(0.3);
	}
	100% {
		transform: scale(1);
	}
}

@keyframes razzi-spin {
	from {
		transform: rotate(0deg);
	}
	to {
		transform: rotate(-360deg);
	}
}

@keyframes razziFadeInUp {
	from {
		opacity: 0;
		transform: translate3d(0, 80px, 0);
	}
	to {
		opacity: 1;
		transform: none;
	}
}

@-webkit-keyframes fadeInDown {
	from {
		opacity: 0;
		-webkit-transform: translate3d(0, -100%, 0);
		transform: translate3d(0, -100%, 0);
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none;
	}
}

@keyframes fadeInDown {
	from {
		opacity: 0;
		-webkit-transform: translate3d(0, -100%, 0);
		transform: translate3d(0, -100%, 0);
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none;
	}
}

@keyframes fadein {
	from {
		opacity: 0;
	}
	to {
		opacity: 1;
	}
}

@keyframes bubble {
	0%, 100% {
		transform: scale(0);
	}
	50% {
		transform: scale(1);
	}
}

@keyframes anim-ripple {
	0% {
		transform: scale(0.8);
		opacity: 0;
	}
	20% {
		transform: scale(1);
		opacity: .4;
	}
	to {
		transform: scale(1.2);
		opacity: 0;
	}
}

/*--------------------------------------------------------------
# Normalize
--------------------------------------------------------------*/
/*! normalize.css v8.0.0 | MIT License | github.com/necolas/normalize.css */
/* Document
	 ========================================================================== */
/**
 * 1. Correct the line height in all browsers.
 * 2. Prevent adjustments of font size after orientation changes in iOS.
 */
html {
	line-height: 1.15;
	/* 1 */
	-webkit-text-size-adjust: 100%;
	/* 2 */
}

/* Sections
	 ========================================================================== */
/**
 * Remove the margin in all browsers.
 */
body {
	margin: 0;
}

/**
 * Correct the font size and margin on `h1` elements within `section` and
 * `article` contexts in Chrome, Firefox, and Safari.
 */
h1 {
	font-size: 2em;
	margin: 0.67em 0;
}

/* Grouping content
	 ========================================================================== */
/**
 * 1. Add the correct box sizing in Firefox.
 * 2. Show the overflow in Edge and IE.
 */
hr {
	box-sizing: content-box;
	/* 1 */
	height: 0;
	/* 1 */
	overflow: visible;
	/* 2 */
}

/**
 * 1. Correct the inheritance and scaling of font size in all browsers.
 * 2. Correct the odd `em` font sizing in all browsers.
 */
pre {
	font-family: monospace, monospace;
	/* 1 */
	font-size: 1em;
	/* 2 */
}

/* Text-level semantics
	 ========================================================================== */
/**
 * Remove the gray background on active links in IE 10.
 */
a {
	background-color: transparent;
}

/**
 * 1. Remove the bottom border in Chrome 57-
 * 2. Add the correct text decoration in Chrome, Edge, IE, Opera, and Safari.
 */
abbr[title] {
	border-bottom: none;
	/* 1 */
	text-decoration: underline;
	/* 2 */
	text-decoration: underline dotted;
	/* 2 */
}

/**
 * Add the correct font weight in Chrome, Edge, and Safari.
 */
b,
strong {
	font-weight: 500;
}

/**
 * 1. Correct the inheritance and scaling of font size in all browsers.
 * 2. Correct the odd `em` font sizing in all browsers.
 */
code,
kbd,
samp {
	font-family: monospace, monospace;
	/* 1 */
	font-size: 1em;
	/* 2 */
}

/**
 * Add the correct font size in all browsers.
 */
small {
	font-size: 80%;
}

/**
 * Prevent `sub` and `sup` elements from affecting the line height in
 * all browsers.
 */
sub,
sup {
	font-size: 75%;
	line-height: 0;
	position: relative;
	vertical-align: baseline;
}

sub {
	bottom: -0.25em;
}

sup {
	top: -0.5em;
}

/* Embedded content
	 ========================================================================== */
/**
 * Remove the border on images inside links in IE 10.
 */
img {
	border-style: none;
}

/* Forms
	 ========================================================================== */
/**
 * 1. Change the font styles in all browsers.
 * 2. Remove the margin in Firefox and Safari.
 */
button,
input,
optgroup,
select,
textarea {
	font-family: inherit;
	/* 1 */
	font-size: 100%;
	/* 1 */
	line-height: 1.15;
	/* 1 */
	margin: 0;
	/* 2 */
}

/**
 * Show the overflow in IE.
 * 1. Show the overflow in Edge.
 */
button,
input {
	/* 1 */
	overflow: visible;
}

/**
 * Remove the inheritance of text transform in Edge, Firefox, and IE.
 * 1. Remove the inheritance of text transform in Firefox.
 */
button,
select {
	/* 1 */
	text-transform: none;
}

/**
 * Correct the inability to style clickable types in iOS and Safari.
 */
button,
[type="button"],
[type="reset"],
[type="submit"] {
	-webkit-appearance: button;
}

/**
 * Remove the inner border and padding in Firefox.
 */
button::-moz-focus-inner,
[type="button"]::-moz-focus-inner,
[type="reset"]::-moz-focus-inner,
[type="submit"]::-moz-focus-inner {
	border-style: none;
	padding: 0;
}

/**
 * Restore the focus styles unset by the previous rule.
 */
button:-moz-focusring,
[type="button"]:-moz-focusring,
[type="reset"]:-moz-focusring,
[type="submit"]:-moz-focusring {
	outline: 1px dotted ButtonText;
}

/**
 * Correct the padding in Firefox.
 */
fieldset {
	padding: 0.35em 0.75em 0.625em;
}

/**
 * 1. Correct the text wrapping in Edge and IE.
 * 2. Correct the color inheritance from `fieldset` elements in IE.
 * 3. Remove the padding so developers are not caught out when they zero out
 *		`fieldset` elements in all browsers.
 */
legend {
	box-sizing: border-box;
	/* 1 */
	color: inherit;
	/* 2 */
	display: table;
	/* 1 */
	max-width: 100%;
	/* 1 */
	padding: 0;
	/* 3 */
	white-space: normal;
	/* 1 */
}

/**
 * Add the correct vertical alignment in Chrome, Firefox, and Opera.
 */
progress {
	vertical-align: baseline;
}

/**
 * Remove the default vertical scrollbar in IE 10+.
 */
textarea {
	overflow: auto;
}

/**
 * 1. Add the correct box sizing in IE 10.
 * 2. Remove the padding in IE 10.
 */
[type="checkbox"],
[type="radio"] {
	box-sizing: border-box;
	/* 1 */
	padding: 0;
	/* 2 */
}

/**
 * Correct the cursor style of increment and decrement buttons in Chrome.
 */
[type="number"]::-webkit-inner-spin-button,
[type="number"]::-webkit-outer-spin-button {
	height: auto;
}

/**
 * 1. Correct the odd appearance in Chrome and Safari.
 * 2. Correct the outline style in Safari.
 */
[type="search"] {
	-webkit-appearance: textfield;
	/* 1 */
	outline-offset: -2px;
	/* 2 */
}

/**
 * Remove the inner padding in Chrome and Safari on macOS.
 */
[type="search"]::-webkit-search-decoration {
	-webkit-appearance: none;
}

/**
 * 1. Correct the inability to style clickable types in iOS and Safari.
 * 2. Change font properties to `inherit` in Safari.
 */
::-webkit-file-upload-button {
	-webkit-appearance: button;
	/* 1 */
	font: inherit;
	/* 2 */
}

/* Interactive
	 ========================================================================== */
/*
 * Add the correct display in Edge, IE 10+, and Firefox.
 */
details {
	display: block;
}

/*
 * Add the correct display in all browsers.
 */
summary {
	display: list-item;
}

/* Misc
	 ========================================================================== */
/**
 * Add the correct display in IE 10+.
 */
template {
	display: none;
}

/**
 * Add the correct display in IE 10.
 */
[hidden] {
	display: none;
}

/*--------------------------------------------------------------
# Typography
--------------------------------------------------------------*/
body,
button,
input,
select,
optgroup,
textarea {
	color: var(--rz-text-color);
	font-family: var(--rz-font-family-primary);
	font-size: 16px;
	line-height: 1.5;
	-ms-word-wrap: break-word;
	word-wrap: break-word;
	box-sizing: border-box;
}

a {
	outline: none;
	transition: .5s;
	color: var(--rz-color-dark);
	text-decoration: none;
}

a:focus, a:hover, a:active {
	outline: 0;
}

h1, h2, h3, h4, h5, h6 {
	font-weight: 500;
	color: var(--rz-color-dark);
	line-height: 1.33;
}

h1 {
	font-size: 60px;
}

h2 {
	font-size: 40px;
}

h3 {
	font-size: 32px;
}

h4 {
	font-size: 24px;
}

h5 {
	font-size: 20px;
}

h6 {
	font-size: 16px;
}

p {
	margin-bottom: 1.5em;
}

dfn, cite, em, i {
	font-style: italic;
}

blockquote {
	font-size: 20px;
	line-height: 1.5;
	color: var(--rz-color-dark);
	padding: 20px 30px;
	border-right: 3px solid var(--rz-color-primary);
	margin-right: 35px;
}

blockquote p {
	margin: 0 0 10px;
}

blockquote cite {
	font-size: 14px;
	display: block;
	color: #838889;
}

blockquote cite a {
	color: inherit;
}

address {
	margin: 0 0 1.5em;
}

pre {
	background-color: #eee;
	font-family: var(--rz-font-family-pre);
	font-size: 13px;
	line-height: 1.6;
	margin-bottom: 1.6em;
	max-width: 100%;
	overflow: auto;
	padding: 1.6em;
}

code, kbd, tt, var {
	font-family: var(--rz-font-family-code);
	font-size: 13px;
}

code {
	padding: 2px 4px;
	color: #c7254e;
	background-color: #f9f2f4;
}

abbr, acronym {
	border-bottom: 1px dotted #666;
	cursor: help;
}

mark, ins {
	background-color: #fff9c0;
	text-decoration: none;
}

big {
	font-size: 125%;
}

pre.wp-block-verse {
	font-family: var(--rz-font-family-pre);
}

/*--------------------------------------------------------------
# Elements
--------------------------------------------------------------*/
html {
	box-sizing: border-box;
}

*,
*:before,
*:after {
	/* Inherit box-sizing to make it easier to change the property for components that leverage other behavior; see https://css-tricks.com/inheriting-box-sizing-probably-slightly-better-best-practice/ */
	box-sizing: border-box;
}

body {
	background: #fff;
	/* Fallback for when there is no custom background color defined. */
}

hr {
	background-color: #cccccc;
	border: 0;
	height: 1px;
	margin-bottom: 1.5em;
}

ul,
ol {
	margin: 0 0 1.5em;
	padding-right: 1.5em;
}

ul {
	list-style: disc;
}

ol {
	list-style: decimal;
}

li > ul,
li > ol {
	margin-bottom: 0;
}

dt {
	font-weight: 700;
}

dd {
	margin: 0 1.5em 1.5em;
}

ol.razzi-custom-padding li:not(:last-child) {
	padding-bottom: 11px;
}

ul.razzi-check-list {
	list-style: none;
	margin: 0;
	padding: 0;
}

ul.razzi-check-list li {
	position: relative;
	padding-right: 19px;
}

ul.razzi-check-list li:not(:last-child) {
	margin-bottom: 8px;
}

ul.razzi-check-list li:before {
	content: "";
	position: absolute;
	bottom: 5px;
	right: 0;
	width: 10px;
	height: 10px;
	background-repeat: no-repeat;
	background-size: 9px;
	background-image: url("data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iOSIgaGVpZ2h0PSI4IiB2aWV3Qm94PSIwIDAgOSA4IiBmaWxsPSJub25lIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgo8cGF0aCBkPSJNOCAxTDMuMTg3NSA3TDEgNC4yNzI3MyIgc3Ryb2tlPSIjNTI1MjUyIiBzdHJva2Utd2lkdGg9IjEuNCIgc3Ryb2tlLWxpbmVjYXA9InJvdW5kIiBzdHJva2UtbGluZWpvaW49InJvdW5kIi8+Cjwvc3ZnPgo=");
}

img {
	height: auto;
	/* Make sure images are scaled correctly. */
	max-width: 100%;
	/* Adhere to container width. */
}

figure {
	margin: 1em 0;
	/* Extra wide images within figure tags don't overflow the content area. */
}

.razzi-loading {
	position: relative;
}

.razzi-loading:before {
	content: '';
	display: block;
	border-radius: 100px;
	position: absolute;
}

.razzi-loading:before {
	background-color: var(--rz-background-color-primary);
	height: 13px;
	width: 13px;
	top: 0;
	right: 0;
	animation: razzi-scale 1s 0s cubic-bezier(0.09, 0.57, 0.49, 0.9) infinite;
}

.razziFadeInUp {
	animation-name: razziFadeInUp;
	animation-duration: 0.8s;
	animation-fill-mode: both;
	animation-timing-function: cubic-bezier(0.65, 0.8, 0.44, 0.99);
}

.razzi-gooey {
	width: 100%;
	height: 100%;
	background-color: var(--rz-background-color-light);
	display: flex;
	align-items: center;
	justify-content: center;
}

.razzi-gooey span {
	display: block;
	float: right;
	width: 10px;
	height: 10px;
	margin: 0 8px;
	background-color: var(--rz-background-color-dark);
	border-radius: 50%;
	animation: bubble 1.2s -0.6s infinite ease-out;
}

.razzi-gooey span:nth-child(2n) {
	animation-delay: -1s;
}

.razzi-gooey span:nth-child(3n) {
	animation-delay: 0s;
}

.razzi-svg-icon {
	display: inline-flex;
}

.razzi-svg-icon svg {
	vertical-align: -0.125em;
	width: 1em;
	height: 1em;
	display: inline-block;
}

.text-center {
	text-align: center;
}

.text-left {
	text-align: right;
}

.text-right {
	text-align: left;
}

.border-color-dark {
	border-color: var(--rz-border-color-dark) !important;
}

.razzi-scrollbar {
	overflow-y: auto;
	scrollbar-color: #1f1f1f #e2e2e278;
	scrollbar-width: thin;
}

.razzi-scrollbar::-webkit-scrollbar {
	width: 2px;
}

.razzi-scrollbar::-webkit-scrollbar-track {
	background-color: #e2e2e2;
}

.razzi-scrollbar::-webkit-scrollbar-thumb {
	background-color: #1f1f1f;
}

.primary-color {
	color: var(--rz-color-primary);
}

.image-zoom {
	overflow: hidden;
}

.image-zoom img {
	transition: transform .3s ease;
	vertical-align: middle;
}

.image-zoom:hover img {
	transform: scale(1.05);
	-ms-transform: scale(1.05);
	/* IE 9 */
	-moz-transform: scale(1.05);
	/* Firefox */
	-webkit-transform: scale(1.05);
	/* Safari and Chrome */
	-o-transform: scale(1.05);
	/* Opera */
}

@-webkit-keyframes fadeIn {
	from {
		opacity: 0;
	}
	to {
		opacity: 1;
	}
}

@-moz-keyframes fadeIn {
	from {
		opacity: 0;
	}
	to {
		opacity: 1;
	}
}

@keyframes fadeIn {
	from {
		opacity: 0;
	}
	to {
		opacity: 1;
	}
}

.razzi-tabs .tabs-nav {
	margin: 0;
	padding: 0;
	overflow: hidden;
	list-style-type: none;
}

.razzi-tabs .tabs-nav li {
	float: right;
}

.razzi-tabs .tabs-nav a {
	display: block;
}

.razzi-tabs .tabs-content {
	position: relative;
}

.razzi-tabs .tabs-panel {
	position: absolute;
	top: 0;
	right: 0;
	z-index: -1;
	width: 100%;
	opacity: 0;
	transition: opacity 0.2s ease;
	transform: translateY(10px);
}

.razzi-tabs .tabs-panel.active {
	position: relative;
	z-index: 2;
	opacity: 1;
	top: 0;
	transform: translateY(0);
	transition: all 0.2s ease;
	transition-delay: 0.1s;
}

.hidden {
	display: none !important;
	visibility: hidden !important;
}

table {
	margin: 0 0 1.5em;
	width: 100%;
	border-collapse: collapse;
	border-spacing: 0;
	border-width: 1px 1px 0 0;
}

caption,
td,
th {
	padding: 0;
	font-weight: normal;
	text-align: right;
}

table,
th,
td {
	border: 1px solid var(--rz-border-color-gray);
}

th {
	border-width: 0 0 1px 1px;
}

td {
	border-width: 0 0 1px 1px;
}

th,
td {
	padding: 10px;
}

thead th {
	font-weight: 500;
}

table.large-padding thead th, table.large-padding thead td {
	padding: 12px 30px;
}

table.large-padding th,
table.large-padding td {
	padding: 18px 30px;
}

/*--------------------------------------------------------------
# Forms
--------------------------------------------------------------*/
button,
input[type="button"],
input[type="reset"],
input[type="submit"] {
	font-weight: 500;
	font-size: 16px;
	line-height: 50px;
	display: inline-block;
	background-color: var(--rz-background-color-dark);
	color: var(--rz-color-lighter);
	padding: 0 37px;
	text-align: center;
	transition: ease .3s;
	white-space: nowrap;
	text-decoration: none;
	cursor: pointer;
	border: none;
}

button:focus,
input[type="button"]:focus,
input[type="reset"]:focus,
input[type="submit"]:focus {
	outline: none;
}

.razzi-button {
	font-weight: 500;
	font-size: 16px;
	line-height: 50px;
	display: inline-block;
	background-color: var(--rz-background-color-dark);
	color: var(--rz-color-lighter);
	padding: 0 37px;
	text-align: center;
	transition: ease .3s;
	white-space: nowrap;
	text-decoration: none;
}

.razzi-button .razzi-svg-icon {
	vertical-align: middle;
	margin-right: 10px;
	font-size: 13px;
	transition: ease .3s;
	display: inline-block;
			transform: rotateY(180deg);
}

.razzi-button.button-smaller {
	font-size: 15px;
	line-height: 42px;
	padding: 0 25px;
}

.razzi-button.button-medium {
	line-height: 46px;
	padding: 0 31px;
}

.razzi-button.button-larger {
	line-height: 54px;
	padding: 0 43px;
}

.razzi-button.button-big {
	line-height: 70px;
	display: block;
}

.razzi-button.button-outline, .razzi-button.button-normal {
	color: var(--rz-color-dark);
	background-color: transparent;
}

.razzi-button.button-outline .razzi-svg-icon, .razzi-button.button-normal .razzi-svg-icon {
	color: inherit;
}

.razzi-button.button-outline {
	border: 1px solid;
}

.razzi-button.button-normal {
	padding: 0;
	line-height: inherit;
}

.razzi-button:not(.button-outline):not(.button-normal).button-light {
	background-color: var(--rz-background-color-light);
	color: var(--rz-color-dark);
}

.razzi-button:not(.button-outline):not(.button-normal).button-light .razzi-svg-icon {
	color: var(--rz-color-dark);
}

.razzi-button:hover .razzi-svg-icon {
	transform: translateX(-3px);
				transform: translateX(-3px) rotateY(180deg);
}

.btn-primary:not(.button-outline):not(.button-normal) {
	background-color: var(--rz-background-color-primary);
	color: var(--rz-background-text-color-primary);
}

.btn-primary.button-outline {
	border-color: var(--rz-border-color-primary);
}

.razzi-button--underlined {
	font-weight: 500;
	font-size: 16px;
	line-height: 1.4375;
	background-color: transparent;
	color: var(--rz-color-dark);
	padding: 0 15px 3px;
	display: inline-block;
	position: relative;
}

.razzi-button--underlined:after {
	content: '';
	position: absolute;
	right: 0;
	bottom: 0;
	left: 0;
	border-bottom: 1px solid;
	transform-origin: right center;
	transition: all .2s ease-in-out;
	transition-property: transform;
}

.razzi-button--underlined:hover {
	color: var(--rz-color-dark);
}

.razzi-button--underlined:hover:after {
	transform-origin: left center;
	transform: scaleX(0);
}

input[type="text"],
input[type="email"],
input[type="url"],
input[type="password"],
input[type="search"],
input[type="number"],
input[type="tel"],
input[type="range"],
input[type="date"],
input[type="month"],
input[type="week"],
input[type="time"],
input[type="datetime"],
input[type="datetime-local"],
input[type="color"],
textarea {
	color: var(--rz-color-dark);
	border: 1px solid var(--rz-border-color);
	box-sizing: border-box;
	padding: 12px 15px;
	font-size: 16px;
	transition: all .1s ease-in-out;
	outline: none;
}

input[type="text"]:focus,
input[type="email"]:focus,
input[type="url"]:focus,
input[type="password"]:focus,
input[type="search"]:focus,
input[type="number"]:focus,
input[type="tel"]:focus,
input[type="range"]:focus,
input[type="date"]:focus,
input[type="month"]:focus,
input[type="week"]:focus,
input[type="time"]:focus,
input[type="datetime"]:focus,
input[type="datetime-local"]:focus,
input[type="color"]:focus,
textarea:focus {
	color: var(--rz-color-dark);
	border-color: var(--rz-color-darker);
	outline: none;
}

select {
	border: 1px solid var(--rz-border-color);
	padding: 12px 25px;
	color: var(--rz-color-dark);
	cursor: pointer;
	-moz-appearance: none;
	/* Firefox */
	-webkit-appearance: none;
	/* Safari and Chrome */
	appearance: none;
	background-image: url(data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMTAiIGhlaWdodD0iNSIgdmlld0JveD0iMCAwIDEwIDUiIGZpbGw9Im5vbmUiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+DQo8cGF0aCBkPSJNNC41MDQ5NSA0LjgyMDExTDAuMjA1MjQxIDEuMDQ4NTZDLTAuMDY4NDEzNyAwLjgwODY0NiAtMC4wNjg0MTM3IDAuNDE5NjYzIDAuMjA1MjQxIDAuMTc5ODY0QzAuNDc4NjUyIC0wLjA1OTk1NDcgMC45MjIwOTggLTAuMDU5OTU0NyAxLjE5NTQ5IDAuMTc5ODY0TDUuMDAwMDcgMy41MTcxTDguODA0NTIgMC4xNzk5NjFDOS4wNzgwNSAtMC4wNTk4NTc3IDkuNTIxNDUgLTAuMDU5ODU3NyA5Ljc5NDg2IDAuMTc5OTYxQzEwLjA2ODQgMC40MTk3OCAxMC4wNjg0IDAuODA4NzQzIDkuNzk0ODYgMS4wNDg2Nkw1LjQ5NTA4IDQuODIwMkM1LjM1ODMxIDQuOTQwMTEgNS4xNzkyNSA1IDUuMDAwMDkgNUM0LjgyMDg1IDUgNC42NDE2NSA0Ljk0IDQuNTA0OTUgNC44MjAxMVoiIGZpbGw9IiM3Njc2NzYiLz4NCjwvc3ZnPg0K);
	background-repeat: no-repeat;
	background-position: calc(100% - (100% - 20px)) 50%;
	transition: .1s;
	padding-left: 40px;
}

select:focus {
	border-color: var(--rz-border-color-darker);
	outline: none;
	background-image: url("data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMTAiIGhlaWdodD0iNSIgdmlld0JveD0iMCAwIDEwIDUiIGZpbGw9Im5vbmUiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+DQo8cGF0aCBkPSJNNC41MDQ5NSA0LjgyMDExTDAuMjA1MjQxIDEuMDQ4NTZDLTAuMDY4NDEzNyAwLjgwODY0NiAtMC4wNjg0MTM3IDAuNDE5NjYzIDAuMjA1MjQxIDAuMTc5ODY0QzAuNDc4NjUyIC0wLjA1OTk1NDcgMC45MjIwOTggLTAuMDU5OTU0NyAxLjE5NTQ5IDAuMTc5ODY0TDUuMDAwMDcgMy41MTcxTDguODA0NTIgMC4xNzk5NjFDOS4wNzgwNSAtMC4wNTk4NTc3IDkuNTIxNDUgLTAuMDU5ODU3NyA5Ljc5NDg2IDAuMTc5OTYxQzEwLjA2ODQgMC40MTk3OCAxMC4wNjg0IDAuODA4NzQzIDkuNzk0ODYgMS4wNDg2Nkw1LjQ5NTA4IDQuODIwMkM1LjM1ODMxIDQuOTQwMTEgNS4xNzkyNSA1IDUuMDAwMDkgNUM0LjgyMDg1IDUgNC42NDE2NSA0Ljk0IDQuNTA0OTUgNC44MjAxMVoiIGZpbGw9IiMxZjFmMWYiLz4NCjwvc3ZnPg0K");
}

textarea {
	padding: 15px;
	height: 150px;
}

/*--------------------------------------------------------------
# Navigation
--------------------------------------------------------------*/
/*--------------------------------------------------------------
## Menus
--------------------------------------------------------------*/
.socials-menu .menu {
	margin: 0;
	padding: 0;
	list-style: none;
}

.socials-menu li {
	display: inline-block;
	padding: 0 12px;
	line-height: 1;
}

.socials-menu li:first-child {
	padding-right: 0;
}

.socials-menu li:last-child {
	padding-left: 0;
}

.socials-menu span:not(.razzi-svg-icon) {
	display: none;
}

.site-breadcrumb {
	padding: 19px 0;
	margin: 0;
	font-size: 14px;
	color: #909090;
		display: flex;
}

.site-breadcrumb li {
	list-style: none;
	display: inline-block;
}

.site-breadcrumb a {
	color: inherit;
}

.site-breadcrumb a:hover {
	color: var(--rz-color-dark);
}

.site-breadcrumb .delimiter {
	margin: 0 5px;
}

.site-breadcrumb .razzi-svg-icon {
	display: inline-block;
			transform: rotateY(180deg);
}

.next-posts-navigation {
	display: block;
	text-align: center;
}

.next-posts-navigation .nav-previous-ajax {
	display: inline-block;
	position: relative;
}

.next-posts-navigation .nav-previous-ajax a {
	display: block;
	font-weight: 600;
	padding: 11px 45px;
	border: 1px solid var(--rz-border-color-dark);
	transition: 0.35s;
}

.next-posts-navigation .nav-previous-ajax a:hover {
	background-color: var(--rz-color-dark);
	color: var(--rz-color-lighter);
}

.next-posts-navigation .razzi-gooey-loading {
	position: absolute;
	width: 100%;
	height: 100%;
	right: 0;
	top: 0;
	opacity: 0;
	z-index: -1;
	transition: cubic-bezier(0.075, 0.82, 0.165, 1);
}

.next-posts-navigation.loading .razzi-gooey-loading {
	opacity: 1;
	z-index: 1;
}

.comment-navigation,
.posts-navigation,
.post-navigation {
	margin: 0 0 1.5em;
	overflow: hidden;
}

.comment-navigation .nav-previous,
.posts-navigation .nav-previous,
.post-navigation .nav-previous {
	float: right;
	width: 50%;
}

.comment-navigation .nav-next,
.posts-navigation .nav-next,
.post-navigation .nav-next {
	float: left;
	text-align: left;
	width: 50%;
}

.razzi-menu-badges {
	--rz-badges-bg-color: #dd3333;
	white-space: nowrap;
	font-weight: 600;
	font-size: 9px;
	line-height: 12px;
	padding: 2px 4px;
	bottom: 15px;
	left: -5px;
	background-color: var(--rz-badges-bg-color);
	color: var(--rz-color-lighter);
	position: relative;
}

.razzi-menu-badges:before {
	content: "";
	position: absolute;
	top: 100%;
	right: 0;
	border: 4px solid;
	border-left-color: transparent !important;
	border-bottom-color: transparent !important;
	border-left-width: 7px;
	border-right-width: 0;
	border-color: var(--rz-badges-bg-color);
}

/*--------------------------------------------------------------
# Accessibility
--------------------------------------------------------------*/
/* Text meant only for screen readers. */
.screen-reader-text, .site-branding .site-title,
.site-branding .site-description {
	border: 0;
	clip: rect(1px, 1px, 1px, 1px);
	clip-path: inset(50%);
	height: 1px;
	margin: -1px;
	overflow: hidden;
	padding: 0;
	position: absolute !important;
	width: 1px;
	word-wrap: normal !important;
	/* Many screen reader and browser combinations announce broken words as they would appear visually. */
}

.screen-reader-text:focus, .site-branding .site-title:focus,
.site-branding .site-description:focus {
	background-color: #f1f1f1;
	border-radius: 3px;
	box-shadow: 0 0 2px 2px rgba(0, 0, 0, 0.6);
	clip: auto !important;
	clip-path: none;
	color: #21759b;
	display: block;
	font-size: 14px;
	font-weight: bold;
	height: auto;
	right: 5px;
	line-height: normal;
	padding: 15px 23px 14px;
	text-decoration: none;
	top: 5px;
	width: auto;
	z-index: 100000;
	/* Above WP toolbar. */
}

/* Do not show the outline on the skip link target. */
#content[tabindex="-1"]:focus {
	outline: 0;
}

/*--------------------------------------------------------------
# Alignments
--------------------------------------------------------------*/
.alignleft {
	display: inline;
	float: right;
	margin-left: 1.5em;
}

.alignright {
	display: inline;
	float: left;
	margin-right: 1.5em;
}

.aligncenter {
	clear: both;
	display: block;
	margin-right: auto;
	margin-left: auto;
}

/*--------------------------------------------------------------
# Clearings
--------------------------------------------------------------*/
.clear:before,
.clear:after,
.clearfix:before,
.clearfix:after {
	content: "";
	display: table;
	table-layout: fixed;
}

.clear:after,
.clearfix:after {
	clear: both;
}

/*--------------------------------------------------------------
# Widgets
--------------------------------------------------------------*/
.widget {
	margin: 0 0 40px;
	padding: 23px;
	border: 1px solid var(--rz-border-color-light);
	/* Make sure select elements fit in widgets. */
}

.widget.filled {
	border-width: 0;
}

.widget select {
	width: 100%;
}

.widget ul,
.widget ol {
	margin-bottom: 0;
}

.widget:not(.widget_block) ul {
	list-style: none;
	padding-right: 0;
}

.widget:not(.widget_block) ul ul {
	padding-right: 15px;
}

.widget ol {
	padding-right: 16px;
}

.widget:not(.widget_block) li {
	padding: 7px 0;
}

.widget > ul > li:first-child {
	padding-top: 0;
}

.widget > ul > li:last-child {
	padding-bottom: 0;
}

.widget .tagcloud {
	margin: -4px -2px;
}

.widget .tagcloud a {
	border: 1px solid var(--rz-border-color-gray);
	display: inline-block;
	padding: 9px 21px;
	font-size: 14px !important;
	color: var(--rz-text-color);
	margin: 4px 2px;
}

.widget .tagcloud a:hover {
	border-color: var(--rz-border-color-dark);
}

.widget .mc4wp-form {
	font-size: 14px;
}

.widget .mc4wp-form .mc4wp-form-fields > :first-child {
	margin-top: 0;
}

.widget .mc4wp-form input,
.widget .mc4wp-form select,
.widget .mc4wp-form textarea,
.widget .mc4wp-form button {
	min-width: 0;
	margin-top: 20px;
}

.widget .mc4wp-form input,
.widget .mc4wp-form select {
	height: 60px;
	margin-left: 0;
}

.widget .mc4wp-form input[type=submit],
.widget .mc4wp-form input[type=reset],
.widget .mc4wp-form button {
	padding: 0 20px;
}

.widget .mc4wp-form input[type=checkbox],
.widget .mc4wp-form input[type=radio] {
	padding: 0;
	width: auto;
	height: auto;
	margin: 0 0 0 5px;
}

.widget .mc4wp-form p:last-of-type {
	margin-bottom: 0;
}

.widget.widget_block > * {
	margin-top: 0;
}

.widget-title,
.widgettitle {
	font-size: 16px;
	font-weight: 600;
	text-transform: uppercase;
	line-height: 1;
	margin: 0 0 20px;
	padding: 0 0 13px;
	border-bottom: 2px solid;
}

.search-form {
	position: relative;
	color: var(--rz-color-darker);
}

.search-form:after {
	content: "";
	background-image: url(data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMTQiIGhlaWdodD0iMTQiIHZpZXdCb3g9IjAgMCAxNCAxNCIgZmlsbD0ibm9uZSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4NCjxwYXRoIGZpbGwtcnVsZT0iZXZlbm9kZCIgY2xpcC1ydWxlPSJldmVub2RkIiBkPSJNMi42MzAzNiA4LjU2OTUyQzEuODM2NTYgNy43Nzc4MiAxLjM5OTc2IDYuNzIyMjIgMS4zOTk3NiA1LjYwMDEyQzEuMzk5NzYgNC40NzgwMiAxLjgzNjU2IDMuNDIzODIgMi42MzAzNiAyLjYzMDcyQzMuNDIzNDYgMS44MzY5MiA0LjQ3ODM2IDEuNDAwMTIgNS41OTk3NiAxLjQwMDEyQzYuNzIxODYgMS40MDAxMiA3Ljc3NjA2IDEuODM2OTIgOC41NjkxNiAyLjYzMTQyQzkuMzYyOTYgMy40MjM4MiA5Ljc5OTc2IDQuNDc4MDIgOS43OTk3NiA1LjYwMDEyQzkuNzk5NzYgNi43MjIyMiA5LjM2Mjk2IDcuNzc3ODIgOC41NjkxNiA4LjU3MDIyQzcuNzc2MDYgOS4zNjMzMiA2LjcyMTg2IDkuODAwMTIgNS41OTk3NiA5LjgwMDEyQzQuNDc4MzYgOS44MDAxMiAzLjQyMzQ2IDkuMzYzMzIgMi42MzAzNiA4LjU2OTUyWk0xMy43NTkgMTIuODA1MkwxMC4wMDQ5IDkuMDUxMTJDMTAuNzc3IDguMDcwNDIgMTEuMTk5OCA2Ljg2ODUyIDExLjE5OTggNS42MDAxMkMxMS4xOTk4IDQuMTA0MjIgMTAuNjE3NCAyLjY5NzkyIDkuNTU4OTYgMS42NDA5MkM4LjUwMTk2IDAuNTgzMjIyIDcuMDk1NjYgMC4wMDAxMjIwNyA1LjU5OTc2IDAuMDAwMTIyMDdDNC4xMDM4NiAwLjAwMDEyMjA3IDIuNjk4MjYgMC41ODMyMjIgMS42NDA1NiAxLjY0MDkyQzAuNTgyODU2IDIuNjk3OTIgLTAuMDAwMjQ0MTQxIDQuMTA0MjIgLTAuMDAwMjQ0MTQxIDUuNjAwMTJDLTAuMDAwMjQ0MTQxIDcuMDk2NzIgMC41ODI4NTYgOC41MDIzMiAxLjY0MDU2IDkuNTYwMDJDMi42OTgyNiAxMC42MTc3IDQuMTAzODYgMTEuMjAwMSA1LjU5OTc2IDExLjIwMDFDNi44NTA2NiAxMS4yMDAxIDguMDM1NzYgMTAuNzg3OCA5LjAxMDE2IDEwLjAzNkwxMi43NjkyIDEzLjc5NUwxMy43NTkgMTIuODA1MloiIGZpbGw9IiMxMTExMTEiLz4NCjwvc3ZnPg0K);
	position: absolute;
	top: 50%;
	left: 17px;
	transform: translateY(-50%);
	font-size: 18px;
	width: 14px;
	height: 14px;
	background-repeat: no-repeat;
}

.search-form label {
	margin-bottom: 0;
}

.search-form .screen-reader-text, .search-form .site-branding .site-title, .site-branding .search-form .site-title,
.search-form .site-branding .site-description, .site-branding .search-form .site-description {
	display: none;
}

.search-form label {
	width: 100%;
}

.search-form .search-field {
	width: 100%;
}

.search-form .search-submit {
	background-color: transparent;
	position: absolute;
	top: 50%;
	left: 0;
	transform: translateY(-50%);
	border: none;
	text-indent: -9999px;
	z-index: 10;
	box-shadow: none;
	outline: 0;
}

.search-form .search-submit:hover, .search-form .search-submit:focus {
	background-color: transparent;
}

.widget_nav_menu li,
.widget_pages li {
	padding: 5px 0;
}

.widget_nav_menu li:last-child,
.widget_pages li:last-child {
	padding-bottom: 0;
}

.widget_archive ul,
.widget_categories ul {
	list-style: none;
	margin: 0;
	padding: 0;
}

.widget_archive ul ul,
.widget_categories ul ul {
	padding-right: 20px;
	margin-top: 10px;
	border-top: 1px solid var(--rz-border-color-light);
}

.widget_archive ul ul li:last-child,
.widget_categories ul ul li:last-child {
	padding-bottom: 0;
}

.widget_archive li,
.widget_categories li {
	padding: 10px 0;
	border-bottom: 1px solid var(--rz-border-color-light);
}

.widget_archive li:last-child,
.widget_categories li:last-child {
	border-bottom: 0;
}

.widget_archive li .posts-count,
.widget_categories li .posts-count {
	font-size: 12px;
	color: #838889;
	float: left;
	margin-top: 5px;
}

.razzi-widget__social-links .social-links {
	margin-right: -7.5px;
	margin-left: -7.5px;
	display: flex;
	align-items: center;
	flex-wrap: wrap;
}

.razzi-widget__social-links .social-links a.social {
	padding: 0 7.5px;
	font-size: 20px;
	color: var(--rz-color-darker);
}

.razzi-widget__social-links .social-links a.social:hover {
	color: var(--rz-color-primary);
}

.razzi-widget__social-links .social-links a.social:first-child {
	padding-right: 0;
}

.razzi-widget__social-links .social-links a.social:last-child {
	padding-left: 0;
}

.razzi-widget__social-links .social-links a.social.facebook {
	margin-top: -3px;
}

.widget_calendar,
.wp-block-calendar {
	background-color: #fafafa;
	border: 1px solid #ccc;
	padding: 21px 19px 12px;
}

.widget_calendar .wp-block-calendar,
.widget_calendar .calendar_wrap,
.wp-block-calendar .wp-block-calendar,
.wp-block-calendar .calendar_wrap {
	position: relative;
}

.widget_calendar .wp-calendar-table,
.wp-block-calendar .wp-calendar-table {
	margin-bottom: 5px;
	border: none;
}

.widget_calendar caption,
.wp-block-calendar caption {
	margin-bottom: 15px;
	font-weight: 600;
	padding: 0 6px;
	text-align: center;
}

.widget_calendar thead, .widget_calendar tbody,
.wp-block-calendar thead,
.wp-block-calendar tbody {
	border: none;
	margin-right: -.25em;
	margin-left: -.25em;
}

.widget_calendar thead th, .widget_calendar thead td, .widget_calendar tbody th, .widget_calendar tbody td,
.wp-block-calendar thead th,
.wp-block-calendar thead td,
.wp-block-calendar tbody th,
.wp-block-calendar tbody td {
	background: transparent;
	border: 0;
	text-align: center;
	line-height: 2;
	vertical-align: middle;
	word-break: normal;
}

.widget_calendar thead th,
.wp-block-calendar thead th {
	visibility: hidden;
	position: relative;
	font-size: 14px;
	color: #999;
}

.widget_calendar thead th:after,
.wp-block-calendar thead th:after {
	content: '';
	visibility: visible;
	display: block;
	position: absolute;
	top: 0;
	right: 50%;
	transform: translateX(50%);
}

.widget_calendar thead th[title="Monday"]:after,
.wp-block-calendar thead th[title="Monday"]:after {
	content: 'Mo';
}

.widget_calendar thead th[title="Tuesday"]:after,
.wp-block-calendar thead th[title="Tuesday"]:after {
	content: 'Tu';
}

.widget_calendar thead th[title="Wednesday"]:after,
.wp-block-calendar thead th[title="Wednesday"]:after {
	content: 'We';
}

.widget_calendar thead th[title="Thursday"]:after,
.wp-block-calendar thead th[title="Thursday"]:after {
	content: 'Th';
}

.widget_calendar thead th[title="Friday"]:after,
.wp-block-calendar thead th[title="Friday"]:after {
	content: 'Fr';
}

.widget_calendar thead th[title="Saturday"]:after,
.wp-block-calendar thead th[title="Saturday"]:after {
	content: 'Sa';
}

.widget_calendar thead th[title="Sunday"]:after,
.wp-block-calendar thead th[title="Sunday"]:after {
	content: 'Su';
}

.widget_calendar tbody td,
.wp-block-calendar tbody td {
	font-size: 14px;
	color: #000;
}

.widget_calendar tbody #today,
.wp-block-calendar tbody #today {
	position: relative;
	z-index: 9;
	color: var(--rz-background-text-color-primary);
}

.widget_calendar tbody #today:after,
.wp-block-calendar tbody #today:after {
	content: '';
	position: absolute;
	top: 50%;
	right: 50%;
	transform: translate(50%, -50%);
	width: 28px;
	height: 28px;
	background-color: var(--rz-background-color-primary);
	border-radius: 50%;
	z-index: -1;
}

.widget_calendar tbody .old,
.wp-block-calendar tbody .old {
	color: #999;
}

.widget_calendar .wp-calendar-nav a,
.wp-block-calendar .wp-calendar-nav a {
	color: #000;
	text-decoration: none;
}

.widget_calendar .wp-calendar-nav a:hover,
.wp-block-calendar .wp-calendar-nav a:hover {
	color: var(--rz-background-color-primary);
}

.single-post .entry-content .wp-block-calendar {
	margin-top: 20px;
}

.wp-block-page-list {
	margin: 0;
	padding: 0;
}

.wp-block-page-list li {
	list-style: none;
	padding: 7px 0;
}

.wp-block-page-list li:last-child {
	padding-bottom: 0;
}

/*--------------------------------------------------------------
# Infinite scroll
--------------------------------------------------------------*/
/* Globally hidden elements when Infinite Scroll is supported and in use. */
.infinite-scroll .posts-navigation,
.infinite-scroll.neverending .site-footer {
	/* Theme Footer (when set to scrolling) */
	display: none;
}

/* When Infinite Scroll has reached its end we need to re-display elements that were hidden (via .neverending) before. */
.infinity-end.neverending .site-footer {
	display: block;
}

/*--------------------------------------------------------------
# Modals
--------------------------------------------------------------*/
.rz-modal {
	position: fixed;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
	z-index: 1600;
	display: none;
	--rz-modal-spacing: 30px;
}

.rz-modal .panel-content {
	position: absolute;
	left: 0;
	top: 0;
	height: 100%;
	width: 470px;
	max-width: 100%;
	margin: 0;
	background-color: var(--rz-background-color-light);
	transform: translateX(-100%);
	transition: transform .5s;
	display: flex;
	flex-direction: column;
}

.rz-modal .modal-header {
	padding: 25px 20px 20px 45px;
	display: flex;
	align-items: center;
	justify-content: center;
	position: relative;
	background-color: var(--rz-background-color-light);
	border-bottom: 1px solid #e5e5e5;
	text-align: center;
}

.rz-modal .modal-header .modal-title {
	font-size: 18px;
	font-weight: 500;
	margin: 0;
	line-height: 1;
}

.rz-modal .mobile-panel-search {
	width: 100%;
	padding: var(--rz-modal-spacing);
}

.rz-modal .mobile-panel-search .search-wrapper {
	position: relative;
	width: 100%;
	display: flex;
}

.rz-modal .mobile-panel-search .search-field {
	flex: auto;
	border: 1px solid var(--rz-border-color-gray);
	padding-left: 42px;
	height: 54px;
	line-height: 54px;
}

.rz-modal .mobile-panel-search .search-submit {
	position: absolute;
	left: 0;
	background-color: transparent;
	color: var(--rz-text-color-gray);
	padding: 0;
	width: 68px;
	height: 54px;
	line-height: 56px;
	display: block;
	text-align: center;
	z-index: 999;
	border: none;
	transition: none;
}

.rz-modal .modal-content {
	position: relative;
	padding: var(--rz-modal-spacing);
	background-color: var(--rz-background-color-light);
}

.rz-modal.open {
	visibility: visible;
}

.rz-modal.open .modal-header {
	opacity: 1;
	display: block;
}

.rz-modal.open .modal-content {
	opacity: 1;
}

.rz-modal.open .panel-content {
	transform: none;
}

.rz-modal.side-left .panel-content {
	right: 0;
	left: auto;
	transform: translateX(100%);
}

.rz-modal.side-left.open .panel-content {
	transform: none;
}

.rz-modal .off-modal-layer {
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
	cursor: pointer;
	background-color: var(--rz-background-color-dark);
	opacity: 0.5;
}

.rz-modal .button-close {
	display: flex;
	line-height: 1;
	position: absolute;
	left: var(--rz-modal-spacing);
	top: 50%;
	transform: translateY(-50%);
	font-size: 24px;
	color: #a6a6a6;
	margin-right: 20px;
}

.rz-modal .button-close:hover {
	color: #767676;
}

.admin-bar .rz-modal {
	top: 32px;
	height: calc( 100% - 32px);
}

body .hotspot-modal {
	color: var(--rz-text-color);
	font-family: var(--rz-font-family-primary);
}

body .hotspot-modal .public-hotspot-info-holder .public-hotspot-info .public-hotspot-info__number {
	display: none;
}

body .hotspot-modal .public-hotspot-info-holder .public-hotspot-info .public-hotspot-info__btn-buy.snpt-cta-btn {
	font-size: 10px;
	letter-spacing: 0;
	font-weight: 400;
	padding: 5px 7px 4px;
	background-color: #111 !important;
	color: #fff !important;
	line-height: 1;
}

body .hotspot-modal .public-hotspot-info-holder .public-hotspot-info .public-hotspot-info__btn-buy.snpt-cta-btn:hover {
	background-color: #111;
	color: #fff;
}

body .hotspot-modal .public-hotspot-info-holder .public-hotspot-info .public-hotspot-info__price {
	color: var(--rz-text-color-gray);
	font-size: 16px;
	font-weight: 500;
	padding-top: 3px;
	display: inline-block;
}

body .hotspot-modal .public-hotspot-info-holder .public-hotspot-info .public-hotspot-info__second-line {
	font-size: 16px;
	margin-top: 5px;
}

body .hotspot-modal .modal-dialog .chevron {
	top: 50%;
	transform: translateY(-50%);
}

.rz-modal {
	--rz-modal-spacing: 20px;
}

.rz-modal .panel-content {
	width: 90%;
}

/*--------------------------------------------------------------
# Media
--------------------------------------------------------------*/
.page-content .wp-smiley,
.entry-content .wp-smiley,
.comment-content .wp-smiley {
	border: none;
	margin-bottom: 0;
	margin-top: 0;
	padding: 0;
}

/* Make sure embeds and iframes fit their containers. */
embed,
iframe,
object {
	max-width: 100%;
}

/* Make sure logo link wraps around logo image. */
.custom-logo-link {
	display: inline-block;
}

/*--------------------------------------------------------------
## Captions
--------------------------------------------------------------*/
.wp-caption {
	margin-bottom: 1.5em;
	max-width: 100%;
}

.wp-caption img[class*="wp-image-"] {
	display: block;
	margin-right: auto;
	margin-left: auto;
}

.wp-caption .wp-caption-text {
	margin: 0.8075em 0;
}

.wp-caption-text {
	text-align: center;
}

/*--------------------------------------------------------------
## Galleries
--------------------------------------------------------------*/
.gallery-caption {
	display: block;
}

.gallery-icon {
	margin-bottom: 25px;
}

.gallery {
	margin-bottom: 1.5em;
	margin-right: -7px;
	margin-left: -7px;
}

.gallery-item {
	display: inline-block;
	text-align: center;
	vertical-align: top;
	width: 100%;
	margin: 0;
	padding: 7px;
	margin-bottom: 35px;
}

.gallery-columns-2 .gallery-item {
	max-width: 50%;
}

.gallery-columns-3 .gallery-item {
	max-width: 33.33%;
}

.gallery-columns-4 .gallery-item {
	max-width: 25%;
}

.gallery-columns-5 .gallery-item {
	max-width: 20%;
}

.gallery-columns-6 .gallery-item {
	max-width: 16.66%;
}

.gallery-columns-7 .gallery-item {
	max-width: 14.28%;
}

.gallery-columns-8 .gallery-item {
	max-width: 12.5%;
}

.gallery-columns-9 .gallery-item {
	max-width: 11.11%;
}

.gallery-columns-6 .gallery-caption,
.gallery-columns-7 .gallery-caption,
.gallery-columns-8 .gallery-caption,
.gallery-columns-9 .gallery-caption {
	display: none;
}

.blocks-gallery-caption {
	width: inherit;
	margin-bottom: 40px;
}

/*--------------------------------------------------------------
# Col
--------------------------------------------------------------*/
.row-flex {
	display: flex;
	flex-wrap: wrap;
	margin-right: -15px;
	margin-left: -15px;
}

.col-flex {
	min-height: 1px;
	padding-right: 15px;
	padding-left: 15px;
}

.col-flex-xs-12 {
	flex: 0 0 100%;
	max-width: 100%;
}

.col-flex-xs-11 {
	flex: 0 0 91.66667%;
	max-width: 91.66667%;
}

.col-flex-xs-10 {
	flex: 0 0 83.33333%;
	max-width: 83.33333%;
}

.col-flex-xs-9 {
	flex: 0 0 75%;
	max-width: 75%;
}

.col-flex-xs-8 {
	flex: 0 0 66.66667%;
	max-width: 66.66667%;
}

.col-flex-xs-7 {
	flex: 0 0 58.33333%;
	max-width: 58.33333%;
}

.col-flex-xs-6 {
	flex: 0 0 50%;
	max-width: 50%;
}

.col-flex-xs-5 {
	flex: 0 0 41.66667%;
	max-width: 41.66667%;
}

.col-flex-xs-4 {
	flex: 0 0 33.33333%;
	max-width: 33.33333%;
}

.col-flex-xs-3 {
	flex: 0 0 25%;
	max-width: 25%;
}

.col-flex-xs-2 {
	flex: 0 0 16.66667%;
	max-width: 16.66667%;
}

.col-flex-xs-1 {
	flex: 0 0 8.33333%;
	max-width: 8.33333%;
}

/*--------------------------------------------------------------
# Layout
--------------------------------------------------------------*/
.site-content {
	padding-top: 30px;
	padding-bottom: 50px;
}

.site-content:after {
	clear: both;
	display: block;
	content: "";
}

.site-content.no-top-spacing {
	padding-top: 0 !important;
}

.site-content.no-bottom-spacing {
	padding-bottom: 0 !important;
}

.page.full-content:not(.elementor-page) .site-content {
	margin-right: auto;
	margin-left: auto;
	padding-right: 15px;
	padding-left: 15px;
}

.hidden-xs {
	display: none !important;
}

.single-product .site-content {
	padding-top: 0;
}

.razzi-blog-page .site-content {
	padding-top: 50px;
}

.razzi-catalog-page .site-content {
	padding-top: 20px;
}

.blog-sidebar {
	margin-top: 40px;
}

.razzi-container-wide,
.razzi-container,
.container {
	padding-right: 15px;
	padding-left: 15px;
}

.razzi-hide-on-mobile {
	display: none;
}

.site-header__border {
	border-bottom: 1px solid var(--rz-border-color-light);
}

.site-footer__no-padding-top {
	padding-top: 0 !important;
}

/*--------------------------------------------------------------
# Content
--------------------------------------------------------------*/
/*--------------------------------------------------------------
## Preloader
--------------------------------------------------------------*/
.preloader {
	position: fixed;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
	z-index: 99999999;
	background: #fff;
}

.preloader .preloader-icon {
	position: absolute;
	top: 50%;
	right: 50%;
	transform: translate(50%, -50%);
	display: block;
}

.preloader .spinner {
	width: 40px;
	height: 40px;
	margin: -20px -20px 0 0;
	transform: none;
	display: inline-block;
	border-radius: 50%;
	border: 2px solid;
	border-top-color: transparent;
	animation: razzi-spin infinite 1s linear;
}

.no-js .preloader {
	display: none;
}

/*--------------------------------------------------------------
## Topbar
--------------------------------------------------------------*/
.razzi-topbar__text {
	color: var(--rz-color-dark);
	letter-spacing: 0.02em;
	text-transform: uppercase;
	font-size: 11px;
	font-weight: 500;
	display: flex;
}

.razzi-topbar__text svg,
.razzi-topbar__text img {
	margin: 0 0 0 14px;
	vertical-align: middle;
}

.razzi-topbar__text .razzi-svg-icon svg {
	width: auto;
	height: auto;
}

.razzi-topbar__text.text-normal {
	text-transform: inherit;
}

.topbar-menu {
	padding: 0;
	margin: 0;
	list-style: none;
	margin-right: -12px;
	margin-left: -12px;
	display: flex;
}

.topbar-menu ul.sub-menu {
	min-width: 80px;
	position: absolute;
	top: 100%;
	right: 0;
	opacity: 0;
	transition: .3s;
	z-index: 1000;
	pointer-events: none;
	text-align: right;
	background-color: var(--rz-background-color-light);
	box-shadow: 0px 2px 6px rgba(0, 0, 0, 0.05);
	list-style: none;
	margin: 0;
	padding: 0;
}

.topbar-menu ul.sub-menu li:not(:last-child) {
	border-bottom: 1px solid var(--rz-border-color-light);
}

.topbar-menu ul.sub-menu ul {
	right: 100%;
	top: 0;
	transform: scaleX(1);
}

.topbar-menu li {
	display: inline-block;
	width: 100%;
	position: relative;
}

.topbar-menu li a {
	display: block;
	width: 110%;
	font-size: 14px;
	padding: 10px 14px 9px;
	margin: 0;
	opacity: 1;
	white-space: nowrap;
	color: #111;
}

.topbar-menu li a:hover {
	color: var(--rz-color-primary);
}

.topbar-menu li:hover > ul {
	opacity: 1;
	transform: scaleX(1);
	pointer-events: initial;
}

.topbar-menu > li {
	display: flex;
	align-items: center;
	height: inherit;
}

.topbar-menu > li > a {
	font-weight: 500;
	color: var(--rz-color-dark);
}

.topbar-menu > li.menu-item-has-children > a {
	position: relative;
	padding-left: 20px;
}

.topbar-menu > li.menu-item-has-children > a .toggle-menu-children {
	left: 0;
	-webkit-transform: translateY(-50%) rotate(0);
	-moz-transform: translateY(-50%) rotate(0);
	-o-transform: translateY(-50%) rotate(0);
	-ms-transform: translateY(-50%) rotate(0);
	transform: translateY(-50%) rotate(0);
}

.topbar-menu .menu-item-has-children {
	position: relative;
	padding-left: 20px;
}

.topbar-menu .menu-item-has-children .toggle-menu-children {
	position: absolute;
	left: 9px;
	top: 50%;
	transform: translateY(-50%);
	line-height: 1;
	cursor: pointer;
	transition: .3s transform;
	-webkit-transform: rotate(90deg);
	-moz-transform: rotate(90deg);
	-o-transform: rotate(90deg);
	-ms-transform: rotate(90deg);
	transform: rotate(90deg);
}

.topbar-menu-container .topbar-menu ul a {
	padding: 0;
}

.topbar-menu-container .topbar-menu ul a:hover {
	--rz-color-primary: #FF6F61;
}

.topbar-menu-container .topbar-menu li.row-flex {
	display: flex;
}

.topbar-menu-container .topbar-menu li li a {
	--rz-color-dark: #111111;
}

.topbar-menu-container .topbar-menu > li > a {
	padding: 0 2px;
	position: relative;
}

.topbar-menu-container .topbar-menu > li > a:after {
	display: none;
}

.topbar-menu-container .topbar-menu > li.menu-item-has-children > a {
	padding-left: 3px;
}

.topbar-menu-container ul.sub-menu li:not(:last-child) {
	border: none;
}

.topbar-menu-container.has-arrow .topbar-menu > li.menu-item-has-children > a {
	padding-left: 20px;
}

.topbar {
	--rz-icon-color: #A0A0A0;
}

.topbar .razzi-currency,
.topbar .razzi-language {
	padding: 0 20px;
	width: fit-content;
}

.topbar .razzi-currency:not(:last-child):before,
.topbar .razzi-language:not(:last-child):before {
	content: '';
	display: block;
	position: absolute;
	left: 0;
	top: 50%;
	transform: translateY(-50%);
	width: 1px;
	height: 10px;
	background-color: #cdcdcd;
}

.topbar .razzi-currency .content-droplist ul li a,
.topbar .razzi-language .content-droplist ul li a {
	color: #111;
}

.topbar .socials-menu .menu {
	margin-right: -10px;
	margin-left: -10px;
}

.topbar .socials-menu .menu li {
	padding: 0;
}

.topbar .socials-menu .menu li a {
	display: inline-block;
	color: var(--rz-icon-color);
	padding: 0 10px;
	font-size: 14px;
}

.topbar .socials-menu .menu li a:hover {
	color: var(--rz-dark-color);
}

.topbar .primary-navigation ul ul a {
	color: #111;
}

.topbar .primary-navigation .nav-menu > li > a {
	font-size: 16px;
}

.topbar .razzi-topbar__close {
	cursor: pointer;
}

.topbar {
	height: 45px;
	background-color: var(--rz-background-color-gray);
	color: var(--rz-color-dark);
}

.topbar .razzi-container-fluid {
	display: flex;
	align-items: center;
	height: 100%;
}

.topbar-items {
	display: flex;
	align-items: center;
	height: inherit;
}

.mobile-topbar-items {
	white-space: nowrap;
}

.mobile-topbar-items > * {
	margin-left: 0;
	padding: 0 20px;
}

.mobile-topbar-items .topbar-menu .menu-item-has-children {
	padding-left: 0;
}

.mobile-topbar-items .topbar-menu .sub-menu {
	display: none;
}

.topbar-mobile .topbar-menu {
	margin-right: -8px;
	margin-left: -8px;
}

.topbar-mobile .topbar-menu li a {
	padding: 0 8px;
}

.topbar-mobile p {
	margin: 0;
}

.mobile-topbar-items {
	display: flex;
	justify-content: center;
	width: 100%;
}

.razzi-topbar__text span:not(.razzi-svg-icon) {
	margin-left: 0 !important;
}

/*--------------------------------------------------------------
## Header
--------------------------------------------------------------*/
.site-header {
	--rz-header-color-light: #ffffff;
	--rz-header-color-dark: #111111;
	--rz-header-color-darker: #1f1f1f;
	--rz-header-text-color-gray: #767676;
	--rz-header-background-color-light: #ffffff;
	--rz-header-background-color-dark: #1F1F1F;
}

.site-header .razzi-header-container {
	display: flex;
	align-items: center;
	height: 100%;
	position: relative;
}

.site-header .submenu__arrow {
	position: absolute;
	width: 12px;
	height: 12px;
	border: 1px solid transparent;
	border-bottom-color: #d7d7d7;
	border-right-color: #d7d7d7;
	top: -6px;
	right: 50%;
	background-color: var --rz-background-color-light;
	z-index: 99;
	transform: translateX(50%) rotate(-135deg);
}

.site-branding {
	flex: 0 1 auto;
	position: relative;
	z-index: 100;
}

.site-branding .logo {
	position: relative;
	transition: none;
}

.site-branding .logo:hover {
	text-decoration: none;
}

.site-branding .logo img {
	display: inline-block;
	vertical-align: middle;
}

.site-branding .logo .logo-transparent {
	opacity: 0;
	visibility: hidden;
	transition: .5s;
}

.site-branding .logo.logo-text {
	font-weight: 600;
	font-size: 28px;
	line-height: 41px;
	color: var(--rz-header-color-dark);
}

.site-branding .logo svg {
	vertical-align: middle;
}

.site-branding .logo-light {
	opacity: 0;
	position: absolute;
	right: 0;
	top: 0;
}

.header-transparent .site-branding .logo.active-logo .logo-transparent {
	opacity: 1;
	visibility: visible;
}

.header-transparent .site-branding .logo.active-logo .logo-main {
	opacity: 0;
	visibility: hidden;
	transition: .5s;
}

.header-transparent .site-header.minimized .site-branding .logo.active-logo .logo-transparent {
	opacity: 0;
	visibility: hidden;
}

.header-transparent .site-header.minimized .site-branding .logo.active-logo .logo-main {
	opacity: 1;
	visibility: visible;
}

.ra-search-form .form-search,
.ra-search-form .search-inner-content {
	display: flex;
	width: 100%;
	position: relative;
}

.ra-search-form .product-cat {
	width: auto;
	float: right;
	position: relative;
	height: 42px;
	line-height: 42px;
	cursor: pointer;
	background-color: inherit;
}

.ra-search-form .product-cat.active:hover .cats-search {
	opacity: 1;
	z-index: 9998;
	top: 100%;
	transform: scaleX(1);
}

.ra-search-form .product-cat.active:hover .product-cat-label:before {
	z-index: 9999;
	opacity: 1;
	top: 100%;
}

.ra-search-form .form-search {
	width: 100%;
	margin: 0;
}

.ra-search-form .form-search.actived .search-wrapper .search-results,
.ra-search-form .form-search.actived ~ .search-results > .search-list {
	top: 100%;
	transform: scaleX(1);
	z-index: 9999;
}

.ra-search-form .form-search.actived ~ .quick-links {
	display: none;
}

.ra-search-form .form-search.searched .close-search-results {
	opacity: 1;
	z-index: 8888;
}

.ra-search-form .form-search.searching .razzi-loading {
	opacity: 1;
	visibility: visible;
}

.ra-search-form .form-search.searching .search-submit:before {
	opacity: 0;
}

.ra-search-form .form-search.searching ~ .quick-links {
	display: none;
}

.ra-search-form .razzi-loading {
	position: absolute;
	bottom: -50px;
	right: calc( 50% - 10px);
	transform: translateY(-50%);
	opacity: 0;
	visibility: hidden;
}

.ra-search-form .razzi-loading:before {
	height: 20px;
	width: 20px;
}

.ra-search-form .search-wrapper {
	width: 100%;
	display: flex;
	position: relative;
}

.ra-search-form .search-wrapper ::-webkit-scrollbar {
	background: transparent;
	width: 7px;
}

.ra-search-form .search-wrapper ::-webkit-scrollbar-thumb {
	background-color: var(--rz-border-color);
}

.ra-search-form .quick-links .label {
	font-size: 15px;
	line-height: 22px;
	color: var(--rz-color-dark);
	margin: 15px 0 20px;
	line-height: 1;
	font-weight: 500;
}

.ra-search-form .quick-links .links {
	list-style: none;
	padding: 0;
	margin: 0;
}

.ra-search-form .quick-links .links li {
	padding: 7px 0;
}

.ra-search-form .quick-links .links a {
	position: relative;
}

.ra-search-form .quick-links .links a:after {
	content: '';
	position: absolute;
	bottom: -2px;
	right: 0;
	left: 0;
	width: 0;
	height: 1px;
	background-color: var(--rz-color-dark);
	transition: .5s;
	opacity: 0;
}

.ra-search-form .quick-links .links a:hover:after {
	opacity: 1;
	width: 100%;
}

.ra-search-form .search-results {
	position: relative;
}

.ra-search-form .search-results > .search-list {
	border-top: none;
	z-index: -1;
	padding: 0;
	transform: scaleX(0);
	max-height: calc( 100vh - 370px);
}

.ra-search-form .search-results .result-title {
	font-weight: 400;
	font-size: 15px;
	line-height: 22px;
	padding: 24px var(--rz-modal-spacing);
	margin: 0 -30px 0 -30px;
	border-top: 1px solid #E2E2E2;
}

.ra-search-form .search-results .result-title.not-found {
	display: none;
}

.ra-search-form .search-results .search-list.result-list-not-found {
	padding: 10px 0;
}

.ra-search-form .search-results .search-list.result-list-not-found .list-item {
	flex-direction: column;
	align-items: center;
	padding: 0;
}

.ra-search-form .search-results .search-list.result-list-not-found .list-item .text {
	font-size: 15px;
	line-height: 22.5px;
	margin-bottom: 13px;
	color: var(--rz-color-darker);
}

.ra-search-form .search-results .search-list.result-list-not-found .list-item .razzi-svg-icon {
	font-size: 22px;
	color: var(--rz-color-lighter);
}

.ra-search-form .search-results .search-list .list-item {
	display: flex;
	align-items: center;
	margin-top: 20px;
}

.ra-search-form .search-results .search-list .list-item:first-child {
	margin-top: 0;
}

.ra-search-form .search-results .search-list .list-item.view-more .button-normal {
	line-height: 35px;
}

.ra-search-form .search-results .search-list .list-item img {
	max-width: 100px;
	margin-left: 30px;
}

.ra-search-form .search-results .search-list .list-item .title-item {
	font-size: 15px;
	font-weight: 600;
	line-height: 23px;
	color: var(--rz-color-dark);
	display: block;
}

.ra-search-form .search-results .search-list .list-item .title-item:hover {
	color: var(--rz-color-primary);
}

.ra-search-form .search-results .search-list .list-item .star-rating {
	float: none;
	margin-top: 5px;
}

.ra-search-form .search-results .search-list .list-item .price-item {
	font-size: 15px;
	color: var(--rz-text-color-gray);
	line-height: 23px;
	font-weight: 500;
	margin-top: 2px;
}

.ra-search-form .search-results .search-list .list-item .price-item .sale {
	display: none;
}

.ra-search-form .search-results .search-list .list-item del {
	font-size: 14px;
	padding-left: 5px;
	font-weight: 400;
}

.ra-search-form .search-results .search-list .list-item ins {
	text-decoration: none;
	background-color: transparent;
	color: var(--rz-color-primary);
	font-size: 16px;
}

.ra-search-form .search-results .search-list .search-item {
	display: flex;
	align-items: center;
}

.ra-search-form .close-search-results {
	position: absolute;
	top: 50%;
	transform: translateY(-50%);
	left: 25px;
	font-size: 16px;
	display: flex;
	align-items: center;
	justify-content: center;
	color: var(--rz-header-color-dark);
	z-index: 10;
	opacity: 0;
	transition: none;
}

.ra-search-form .product-cat-label {
	padding-left: 25px;
	padding-right: 25px;
	border: 1px solid var(--rz-border-color);
	border-left: none;
	color: var(--rz-header-text-color-gray);
	position: relative;
	height: 100%;
	white-space: nowrap;
}

.ra-search-form .product-cat-label .razzi-svg-icon {
	position: absolute;
	left: 25px;
	top: 53%;
	transform: translateY(-50%);
	font-size: 18px;
}

.ra-search-form .product-cat-dd {
	position: absolute;
	top: 0;
	right: 0;
	height: 100%;
	cursor: pointer;
	min-height: 42px;
	width: 100%;
	z-index: 10;
	-webkit-appearance: none;
	-moz-appearance: none;
	appearance: none;
	color: var(--rz-header-text-color-gray);
	background-position: calc(100% - (100% - 25px)) 50%;
	opacity: 0;
}

.ra-search-form .product-cat-dd:focus {
	color: var(--rz-color-dark);
}

.ra-search-form .search-field {
	float: right;
	height: 42px;
	line-height: 1;
	border-top: 1px solid var(--rz-border-color);
	border-bottom: 1px solid var(--rz-border-color);
	border-right: none;
	border-left: none;
	padding-left: 25px;
	padding-right: 25px;
	position: relative;
	width: 100%;
	border-radius: 0;
}

.ra-search-form .search-field:focus {
	outline: none;
}

.ra-search-form.search-every-thing .search-field {
	border-right: 1px solid var(--rz-border-color);
}

.ra-search-form ::-webkit-input-placeholder {
	color: #777;
}

.ra-search-form ::-moz-placeholder {
	color: #777;
}

.ra-search-form :-ms-input-placeholder {
	color: #777;
}

.ra-search-form :-moz-placeholder {
	color: #777;
}

.ra-search-form .search-submit {
	float: left;
	height: 45px;
	line-height: 47px;
	background-color: var(--rz-header-bacground-color-light);
	border: 1px solid var(--rz-border-color);
	white-space: nowrap;
	display: flex;
	align-items: center;
	cursor: pointer;
}

.ra-search-form .search-submit .razzi-svg-icon {
	display: block;
	font-size: 18px;
	order: 3;
}

.ra-search-form .search-submit .button-label {
	order: 2;
}

.ra-search-modal .search-inner-content {
	flex-direction: column;
}

.ra-search-modal .product-cat {
	height: 54px;
	line-height: 54px;
	background-color: var(--rz-background-color-light);
	margin-bottom: 20px;
}

.ra-search-modal .product-cat-label {
	border: 1px solid var(--rz-border-color-gray);
	background-color: var(--rz-background-color-light);
}

.ra-search-modal .product-cat-label:focus {
	border-color: var(--rz-border-color-dark);
}

.ra-search-modal .title {
	font-size: 18px;
	color: var(--rz-color-darker);
	font-weight: 600;
}

.ra-search-modal .search-field {
	border: 1px solid var(--rz-border-color-gray);
	padding-left: 42px;
	height: 54px;
	line-height: 54px;
}

.ra-search-modal .search-field:focus {
	border-color: var(--rz-color-dark);
}

.ra-search-modal .search-submit {
	position: absolute;
	left: 0;
	background-color: transparent;
	color: var(--rz-text-color-gray);
	padding: 0;
	width: 68px;
	height: 54px;
	line-height: 56px;
	display: block;
	text-align: center;
	z-index: 999;
	border: none;
	transition: none;
}

.ra-search-modal .search-submit .razzi-svg-icon {
	margin: 0;
}

.ra-search-modal form.actived .search-submit {
	opacity: 0;
}

.ra-search-modal .search-results {
	border: 0;
	margin-top: 30px;
}

.ra-search-modal .quick-links {
	margin-top: 30px;
}

.ra-search-modal .quick-links .label {
	padding: 30px var(--rz-modal-spacing) 20px;
	margin: 0 -30px 0 -30px;
	border-top: 1px solid #E2E2E2;
}

.site-header .header-search .search-icon {
	color: var(--rz-color-lighter);
	cursor: pointer;
}

.ra-search-form .search-results .result-title {
	margin: 0 -20px;
}

.ra-search-modal .quick-links .label {
	margin: 0 -20px 0 -20px;
}

.ra-account-modal .modal-content {
	height: 100%;
	flex-direction: column;
	justify-content: center;
	padding-right: 50px;
	padding-left: 50px;
}

.ra-account-modal .modal-content .form-row {
	padding: 0;
}

.ra-account-modal .modal-content form {
	display: flex;
	flex-direction: column;
	justify-content: center;
	height: 100%;
}

.ra-account-modal .woocommerce-error .error-message {
	margin: 0;
	padding: 0;
	list-style-type: none;
}

.ra-account-modal .razzi-button {
	width: 100%;
	line-height: 50px;
	cursor: pointer;
}

.ra-account-modal .razzi-button.razzi-loading:before {
	right: 50%;
	top: -10px;
}

.ra-account-modal .razzi-button.button-medium {
	line-height: 48px;
}

.ra-account-modal .razzi-button.create-account {
	margin-top: 20px;
}

.ra-account-modal form.register button.razzi-button {
	margin: 20px 0 0 0;
}

.ra-account-modal div.nsl-container.nsl-container-block .nsl-container-buttons {
	width: 100%;
}

.site-header .header-account {
	height: inherit;
}

.site-header .header-account .account-icon {
	font-size: 17px;
	display: flex;
	align-items: center;
	height: inherit;
	position: relative;
	top: -2px;
	color: var(--rz-header-color-dark);
}

.site-header .header-account .account-links {
	display: none;
}

.ra-account-modal .modal-content {
	padding-right: 20px;
	padding-left: 20px;
}

.ra-hamburger-modal ul.nav-menu > li .razzi-svg-icon {
	font-size: 14px;
}

.ra-account-modal .modal-content form {
	height: auto;
	margin-top: 40px;
}

.site-header .header-wishlist .wishlist-icon {
	position: relative;
	font-size: 18px;
	color: var(--rz-header-color-dark);
	position: relative;
}

.site-header .header-wishlist .counter {
	position: absolute;
	top: -10px;
	left: -10px;
	font-size: 10px;
	font-weight: 500;
	color: var(--rz-background-text-color-primary);
	text-align: center;
	line-height: 11px;
	min-width: 18px;
	height: 18px;
	border-radius: 30px;
	padding: 4px;
	background-color: var(--rz-background-color-primary);
	display: inline-block;
}

.site-header .header-cart {
	padding-left: 19px;
}

.site-header .header-cart > a {
	position: relative;
	color: var(--rz-header-color-dark);
}

.site-header .header-cart .razzi-svg-icon {
	font-size: 18px;
}

.site-header .header-cart .icon-shop-cart {
	font-size: 20px;
}

.site-header .header-cart .counter {
	position: absolute;
	top: -10px;
	left: -10px;
	font-size: 10px;
	font-weight: 500;
	color: var(--rz-background-text-color-primary);
	text-align: center;
	line-height: 11px;
	min-width: 18px;
	height: 18px;
	border-radius: 30px;
	padding: 4px;
	background-color: var(--rz-background-color-primary);
	display: inline-block;
}

.ra-cart-modal .modal-header {
	justify-content: center;
}

.ra-cart-modal .modal-content {
	padding-left: 0;
	padding-bottom: 0;
	padding-right: 0;
	height: 100%;
	position: static;
}

.ra-cart-modal .widget_shopping_cart_content {
	height: 100%;
	padding-bottom: 340px;
	position: static;
}

.widget_shopping_cart_content {
	position: relative;
}

.widget_shopping_cart_content .woocommerce-mini-cart {
	display: flex;
	flex-direction: column;
	padding: 0;
	margin: 0;
}

.widget_shopping_cart_content .woocommerce-mini-cart .woocommerce-mini-cart-item {
	display: flex;
}

.widget_shopping_cart_content a.remove {
	color: #a2a5a6;
	line-height: 1;
}

.widget_shopping_cart_content a.remove:hover {
	color: var(--rz-color-dark);
}

.widget_shopping_cart_content a.remove .razzi-svg-icon {
	font-size: 14px;
	transform: translateY(2px);
}

.widget_shopping_cart_content a.remove .name {
	font-size: 14px;
	margin-right: 5px;
}

.widget_shopping_cart_content ul.cart_list {
	margin: 0;
	padding: 0 var(--rz-modal-spacing);
	overflow-y: auto;
	height: 100%;
}

.widget_shopping_cart_content ul.cart_list .mini_cart_item {
	display: flex;
	align-items: center;
	padding: 0 0 var(--rz-modal-spacing) 0;
	position: relative;
	border-bottom: 1px solid var(--rz-border-color-light);
	margin-bottom: var(--rz-modal-spacing);
}

.widget_shopping_cart_content ul.cart_list .mini_cart_item:last-child {
	border: none;
	margin-bottom: 0;
	padding-bottom: 0;
}

.widget_shopping_cart_content ul.cart_list .mini_cart_item:last-child:not(:first-child) .razzi-quantity-dropdown .qty-options {
	top: auto;
	bottom: 29px;
}

.widget_shopping_cart_content .woocommerce-mini-cart-item__thumbnail {
	padding-left: var(--rz-modal-spacing);
}

.widget_shopping_cart_content .woocommerce-mini-cart-item__thumbnail img {
	display: block;
	float: none;
	margin-left: 0;
	max-width: 120px;
}

.widget_shopping_cart_content .woocommerce-mini-cart-item__summary {
	flex: 1;
	display: flex;
	flex-flow: column;
	justify-content: space-between;
}

.widget_shopping_cart_content .woocommerce-mini-cart-item__summary .variation {
	margin-top: 5px;
}

.widget_shopping_cart_content .woocommerce-mini-cart-item__summary .variation > dt {
	float: right;
	clear: both;
}

.widget_shopping_cart_content .woocommerce-mini-cart-item__summary .variation > dt:before {
	display: none;
}

.widget_shopping_cart_content .woocommerce-mini-cart-item__summary .variation > dd {
	float: right;
}

.widget_shopping_cart_content .woocommerce-mini-cart-item__name {
	font-size: 15px;
	font-weight: 600;
	color: var(--rz-color-dark);
	padding-left: 20px;
}

.widget_shopping_cart_content .woocommerce-mini-cart-item__name a {
	color: var(--rz-color-dark);
}

.widget_shopping_cart_content .woocommerce-mini-cart-item__price {
	font-weight: 500;
	display: block;
	margin-top: 5px;
	color: var(--rz-text-color-gray);
}

.widget_shopping_cart_content .woocommerce-mini-cart-item__remove {
	text-align: left;
	display: flex;
	flex-flow: column;
	justify-content: center;
}

.widget_shopping_cart_content .variation {
	font-size: 14px;
	margin: 0;
}

.widget_shopping_cart_content .variation dt {
	font-weight: 400;
	display: inline-block;
}

.widget_shopping_cart_content .variation dt:before {
	content: "|";
	display: inline-block;
	margin: 0 0 0 4px;
}

.widget_shopping_cart_content .variation dt:first-child:before {
	display: none;
}

.widget_shopping_cart_content .variation dd {
	display: inline-block;
	margin: 0 5px 0 0;
}

.widget_shopping_cart_content .variation dd :first-child {
	margin-top: 0;
}

.widget_shopping_cart_content .variation dd :last-child {
	margin-bottom: 0;
}

.widget_shopping_cart_content .quantity {
	border: 0;
}

.widget_shopping_cart_content .quantity .qty-button {
	display: none;
}

.widget_shopping_cart_content .quantity .qty {
	color: var(--rz-color-dark);
	text-align: center;
	font-weight: 400;
}

.widget_shopping_cart_content .quantity .qty-dropdown {
	color: var(--rz-color-dark);
}

.widget_shopping_cart_content .quantity .current {
	position: relative;
}

.widget_shopping_cart_content .quantity .current .svg-icon {
	position: absolute;
	left: 0;
	top: 50%;
	margin-top: -7px;
}

.widget_shopping_cart_content .woocommerce-cart-item__qty {
	margin-top: 25px;
	display: flex;
	align-items: center;
	justify-content: space-between;
}

.widget_shopping_cart_content .total {
	font-size: 15px;
	font-weight: 500;
	text-align: left;
	color: var(--rz-color-dark);
	background-color: var(--rz-background-color-gray);
	padding: 24px var(--rz-modal-spacing);
	margin: 0 calc(var(--rz-modal-spacing)* -1);
}

.widget_shopping_cart_content .total strong {
	font-weight: 500;
	float: right;
}

.widget_shopping_cart_content .woocommerce-mini-cart__buttons {
	display: flex;
	flex-direction: column;
	margin: var(--rz-modal-spacing) 0 0 0;
}

.widget_shopping_cart_content .woocommerce-mini-cart__buttons .razzi-button {
	height: 54px;
	line-height: 54px;
}

.widget_shopping_cart_content .woocommerce-mini-cart__buttons .checkout {
	margin-top: 10px;
}

.widget_shopping_cart_content .widget_shopping_cart_footer {
	position: absolute;
	bottom: 0;
	right: 0;
	left: 0;
	padding: 0 var(--rz-modal-spacing) var(--rz-modal-spacing) var(--rz-modal-spacing);
	background-color: #fff;
}

.widget_shopping_cart_content .woocommerce-mini-cart__empty-message {
	position: absolute;
	top: calc( 50% - 15px);
	transform: translateY(-50%);
	width: 100%;
	font-weight: 500;
	font-size: 24px;
	line-height: 35px;
	color: var(--rz-color-dark);
	padding: 0 var(--rz-modal-spacing);
	margin: 0;
}

.widget_shopping_cart_content .woocommerce-mini-cart__empty-message > span {
	display: flex;
	align-items: center;
	justify-content: center;
}

.widget_shopping_cart_content .woocommerce-mini-cart__empty-message .razzi-svg-icon {
	font-weight: 400;
	margin-right: 17px;
}

.widget_shopping_cart_content .woocommerce-mini-cart__empty-message .razzi-button {
	width: 100%;
	margin-top: var(--rz-modal-spacing);
}

.ra-cart-modal .widget_shopping_cart_content {
	padding-bottom: 310px;
}

.widget_shopping_cart_content .woocommerce-mini-cart-item__thumbnail img {
	max-width: 100px;
}

.widget_shopping_cart_content .woocommerce-mini-cart-item__name {
	padding-left: 0;
}

.site-header .header-hamburger {
	color: var(--rz-header-color-dark);
}

.site-header .header-hamburger > span {
	cursor: pointer;
}

.ra-hamburger-modal .hamburger-panel-content {
	height: 100%;
	display: flex;
	flex-direction: column;
	overflow-y: auto;
}

.ra-hamburger-modal .hamburger-panel-content::-webkit-scrollbar {
	width: 0;
}

.ra-hamburger-modal .hamburger-panel-content:hover::-webkit-scrollbar {
	width: 0;
}

.ra-hamburger-modal .modal-header {
	border: none;
}

.ra-hamburger-modal .modal-content {
	height: 100%;
	display: flex;
	align-items: center;
}

.ra-hamburger-modal .modal-footer {
	padding: 40px 30px;
}

.ra-hamburger-modal .hamburger-navigation {
	width: 100%;
}

.ra-hamburger-modal .mobile-panel-search {
	padding: 0 0 50px;
}

.ra-hamburger-modal ul.nav-menu {
	padding: 0;
	margin: 0;
}

.ra-hamburger-modal ul.nav-menu a {
	font-weight: 500;
	font-size: 36px;
	line-height: 52px;
	position: relative;
	display: block;
}

.ra-hamburger-modal ul.nav-menu > li {
	margin-bottom: 10px;
}

.ra-hamburger-modal ul.nav-menu > li .razzi-svg-icon {
	font-size: 24px;
}

.ra-hamburger-modal ul.nav-menu ul {
	padding: 10px 0 0 0;
	margin: 0;
	display: none;
}

.ra-hamburger-modal ul.nav-menu ul li {
	padding: 6px 0;
}

.ra-hamburger-modal ul.nav-menu ul li a {
	font-size: 18px;
	line-height: 27px;
	font-weight: 400;
}

.ra-hamburger-modal ul.nav-menu li.current-menu-parent > a, .ra-hamburger-modal ul.nav-menu li.current_page_parent > a, .ra-hamburger-modal ul.nav-menu li.current-menu-item > a, .ra-hamburger-modal ul.nav-menu li.current_page_item > a, .ra-hamburger-modal ul.nav-menu li:hover > a {
	color: var(--rz-color-primary);
}

.ra-hamburger-modal ul.nav-menu li.current-menu-parent .razzi-svg-icon, .ra-hamburger-modal ul.nav-menu li.current_page_parent .razzi-svg-icon, .ra-hamburger-modal ul.nav-menu li.current-menu-item .razzi-svg-icon, .ra-hamburger-modal ul.nav-menu li.current_page_item .razzi-svg-icon, .ra-hamburger-modal ul.nav-menu li:hover .razzi-svg-icon {
	transition: .5s;
}

.ra-hamburger-modal ul.nav-menu li.active > a .toggle-menu-children .razzi-svg-icon {
	-webkit-transform: rotate(-180deg);
	-moz-transform: rotate(-180deg);
	-o-transform: rotate(-180deg);
	-ms-transform: rotate(-180deg);
	transform: rotate(-180deg);
}

.ra-hamburger-modal ul.nav-menu li.menu-item-has-children .toggle-menu-children {
	position: absolute;
	left: 0;
	top: 20px;
	transform: translateY(-50%);
	display: none;
	line-height: 1;
	font-size: 14px;
	cursor: pointer;
}

.ra-hamburger-modal ul.nav-menu li.menu-item-has-children .toggle-menu-children .razzi-svg-icon {
	transition: none;
}

.ra-hamburger-modal ul.nav-menu li.menu-item-has-children > a {
	font-weight: 500;
}

.ra-hamburger-modal ul.nav-menu.active-arrow li.menu-item-has-children .toggle-menu-children {
	display: block;
}

.ra-hamburger-modal ul {
	list-style-type: none;
}

.ra-hamburger-modal .socials-menu li {
	padding: 0 5px;
}

.ra-hamburger-modal .socials-menu li a {
	color: #a0a0a0;
}

.ra-hamburger-modal .socials-menu li a:hover {
	color: var(--rz-color-dark);
}

.ra-hamburger-modal .menu-copyright {
	font-size: 13px;
	line-height: 19px;
	color: #919191;
	margin-top: 15px;
}

.ra-menu-mobile-modal .menu-mobile-panel-content {
	height: 100%;
	display: flex;
	flex-direction: column;
	overflow-y: auto;
}

.ra-menu-mobile-modal .modal-header {
	justify-content: flex-start;
}

.ra-menu-mobile-modal .modal-content {
	display: flex;
	flex-direction: column;
	justify-content: space-between;
	align-items: flex-start;
	padding-top: 60px;
	padding-bottom: 0;
}

.ra-menu-mobile-modal .content-footer {
	padding: 40px 0;
}

.ra-menu-mobile-modal ul.nav-menu ul {
	padding-right: 5px;
}

.ra-menu-mobile-modal ul.nav-menu ul li a {
	font-size: 20px;
	line-height: 1.5;
}

.ra-menu-mobile-modal ul.nav-menu li.menu-item-has-children .toggle-menu-children {
	display: block;
}

.ra-menu-mobile-modal ul.nav-menu li.menu-item-has-children > a {
	padding-left: 25px;
}

.ra-menu-mobile-modal ul.nav-menu > li {
	padding-right: 0;
	width: 100%;
	flex-direction: column;
	align-items: flex-start;
}

.ra-menu-mobile-modal ul.nav-menu > li > a {
	font-size: 24px;
}

.ra-menu-mobile-modal ul.nav-menu a {
	line-height: 36px;
}

.razzi-menu-badges {
	--rz-badges-bg-color: #dd3333;
	white-space: nowrap;
	font-weight: 600;
	font-size: 9px;
	line-height: 12px;
	padding: 2px 4px;
	bottom: 15px;
	left: -5px;
	background-color: var(--rz-badges-bg-color);
	color: var(--rz-color-lighter);
	position: relative;
}

.razzi-menu-badges:before {
	content: "";
	position: absolute;
	top: 100%;
	right: 0;
	border: 4px solid;
	border-left-color: transparent !important;
	border-bottom-color: transparent !important;
	border-left-width: 7px;
	border-right-width: 0;
	border-color: var(--rz-badges-bg-color);
}

.site-header .campaign-bar {
	height: 50px;
}

.site-header .campaign-bar > * {
	height: 100%;
	display: flex;
	align-items: center;
	justify-content: center;
}

.site-header.transparent ~ .campaign-bar {
	display: none;
}

.site-header.light ~ .campaign-bar {
	padding-top: 0;
}

.campaign-bar__campaigns {
	display: flex;
	height: 100%;
}

.campaign-bar__campaigns .razzi-promotion {
	flex: 1;
	background-position: center center;
	background-size: cover;
	height: 100%;
	padding: 5px 20px;
	display: flex;
	align-items: center;
	justify-content: center;
	font-weight: 500;
	font-size: 13px;
	line-height: 19px;
	letter-spacing: 0.02em;
	text-transform: uppercase;
	color: var(--rz-color-dark);
}

.razzi-currency {
	position: relative;
	display: flex;
	align-items: center;
	height: inherit;
}

.razzi-currency .current {
	cursor: pointer;
	transition: 0.5s;
	font-weight: 500;
	font-size: 14px;
	position: relative;
	color: var(--rz-header-color-dark);
}

.razzi-currency .current .razzi-svg-icon {
	margin-right: 5px;
	transform: translateY(2px);
}

.razzi-currency .content-droplist {
	min-width: 80px;
	position: absolute;
	top: 110%;
	right: 0;
	opacity: 0;
	transition: .3s;
	z-index: 1000;
	pointer-events: none;
	text-align: right;
}

.razzi-currency .content-droplist ul {
	background-color: var(--rz-background-color-light);
	box-shadow: 0px 2px 6px rgba(0, 0, 0, 0.05);
	list-style: none;
	margin: 0;
	padding: 0;
}

.razzi-currency .content-droplist ul li {
	padding: 0;
}

.razzi-currency .content-droplist ul li a {
	display: block;
	width: 100%;
	font-size: 14px;
	padding: 13px 20px;
	margin: 0;
	opacity: 1;
	white-space: nowrap;
}

.razzi-currency .content-droplist ul li a:hover {
	background-color: var(--rz-background-color-gray);
}

.razzi-currency .content-droplist ul li:not(:last-child) {
	border-bottom: 1px solid var(--rz-border-color-light);
}

.razzi-currency .content-droplist ul li.actived a {
	color: #000;
	pointer-events: none;
}

.razzi-currency:hover .content-droplist {
	opacity: 1;
	pointer-events: initial;
	top: 100%;
}

.header-currencies {
	height: inherit;
}

.header-currencies .razzi-currency .current {
	font-size: 16px;
}

.header-currencies .razzi-currency .content-droplist {
	box-shadow: 0px 2px 6px rgba(0, 0, 0, 0.05);
}

.razzi-language {
	position: relative;
	display: flex;
	align-items: center;
	height: inherit;
}

.razzi-language .current {
	cursor: pointer;
	transition: 0.5s;
	font-weight: 500;
	font-size: 14px;
	position: relative;
	color: var(--rz-header-color-dark);
}

.razzi-language .current .razzi-svg-icon {
	margin-right: 5px;
	transform: translateY(2px);
}

.razzi-language .language-dropdown {
	min-width: 80px;
	position: absolute;
	top: 110%;
	right: 0;
	opacity: 0;
	transition: .3s;
	z-index: 1000;
	pointer-events: none;
	text-align: right;
}

.razzi-language .language-dropdown ul {
	background-color: var(--rz-background-color-light);
	box-shadow: 0px 2px 6px rgba(0, 0, 0, 0.05);
	list-style: none;
	margin: 0;
	padding: 0;
}

.razzi-language .language-dropdown ul li {
	padding: 0;
}

.razzi-language .language-dropdown ul li a {
	display: block;
	width: 100%;
	font-size: 14px;
	padding: 10px 20px 9px;
	margin: 0;
	opacity: 1;
	white-space: nowrap;
}

.razzi-language .language-dropdown ul li a:hover {
	background-color: var(--rz-background-color-gray);
}

.razzi-language .language-dropdown ul li:not(:last-child) {
	border-bottom: 1px solid var(--rz-border-color-light);
}

.razzi-language .language-dropdown ul li.actived a {
	color: #000;
	pointer-events: none;
}

.razzi-language:hover .language-dropdown {
	opacity: 1;
	pointer-events: initial;
	top: 100%;
}

.header-languages {
	height: inherit;
}

.header-languages .razzi-language .current {
	font-size: 16px;
}

.header-languages .razzi-language .language-dropdown {
	box-shadow: 0px 2px 6px rgba(0, 0, 0, 0.05);
}

.header-v2 .header-languages {
	margin-left: 16px;
}

.header-v2 .header-languages .dropdown {
	border-right: 1px solid var(--rz-border-color-gray);
	padding-right: 20px;
}

.header-transparent .site-header {
	position: absolute;
	right: 0;
	left: 0;
	z-index: 999;
	padding-top: 0;
	padding-bottom: 0;
	--rz-header-background-color-light: transparent;
	--rz-header-background-color-dark: transparent;
}

.header-transparent .razzi-header-minimized {
	display: none;
}

.header-transparent .campaign-bar {
	display: none;
}

.header-transparent .header-department {
	border-color: var(--rz-border-color-light);
}

.header-transparent .header-search.form-type-boxed .search-field {
	background-color: transparent;
}

.header-transparent.header-v6 .site-header {
	position: static;
}

.header-transparent.header-v6 .header-bottom {
	position: absolute;
	right: 335px;
	left: 0;
}

.header-transparent.header-v3 .header-bottom .main-navigation > ul > li > a {
	--rz-header-color-dark: #fff;
}

.header-transparent.header-transparent-text-light .site-header {
	--rz-header-color-dark: #fff;
	--rz-header-color-darker: #fff;
	--rz-header-text-color-gray: #fff;
	--rz-color-placeholder: #fff;
	--rz-border-color-darker: #fff;
}

.header-transparent.header-transparent-text-light .site-header .logo-light {
	position: static;
	opacity: 1;
}

.header-transparent.header-transparent-text-light .site-header .logo-dark {
	opacity: 0;
	position: absolute;
	right: 0;
	top: 0;
}

.header-transparent.header-transparent-text-light .header-search {
	--rz-border-color-dark: #fff;
}

.header-transparent.header-transparent-text-light .header-search.form-type-boxed .search-field {
	border: 1px solid var(--rz-border-color-light);
}

.header-transparent.header-transparent-text-light.header-v6 .header-main {
	--rz-header-color-dark: #111;
}

.header-transparent.header-transparent-text-light.header-v6 .site-header .logo-light {
	opacity: 0;
}

.header-transparent.header-transparent-text-light.header-v6 .site-header .logo-dark {
	opacity: 1;
}

.header-transparent.header-transparent-text-dark .site-header {
	--rz-header-text-color-gray: #111;
	--rz-header-color-light: #111;
	--rz-color-placeholder: #111;
}

.header-transparent.header-transparent-text-dark .header-search {
	--rz-border-color-light: #111;
}

.header-transparent.header-transparent-text-dark .header-search.form-type-boxed .search-field {
	border: 1px solid var(--rz-border-color-dark);
}

.header-transparent.header-transparent-text-dark .header-search.search-form-type {
	--rz-border-color-light: transparent;
}

.header-transparent.header-transparent-text-dark .header-department {
	border-color: var(--rz-border-color-dark);
}

.header-transparent.header-transparent-text-dark.header-v2 {
	--rz-border-color-gray: #111;
}

.header-sticky.header-transparent .site-header {
	position: fixed;
}

.header-sticky.header-v4 .site-header.minimized .header-bottom {
	margin-bottom: 0;
}

.header-sticky.header-v6 .site-header.minimized .header-bottom {
	position: fixed;
	left: 0;
	right: 335px;
	top: 0;
	background-color: #fff;
	box-shadow: 0 1px 1px 0 #f0f0f0;
	z-index: 999;
	animation-name: fadeInDown;
	animation-duration: .25s;
}

.header-sticky.header-v6.admin-bar .site-header.minimized .header-bottom {
	top: 32px;
}

.header-sticky:not(.header-v6) .site-header.minimized {
	position: fixed;
	left: 0;
	right: 0;
	top: 0;
	background-color: #fff;
	box-shadow: 0 1px 1px 0 #f0f0f0;
	z-index: 999;
	animation-name: fadeInDown;
	animation-duration: .25s;
	border-bottom: none;
	max-width: 1920px;
	margin: 0 auto;
}

.header-sticky:not(.header-v6) .site-header.minimized.header-main-no-sticky .header-main {
	display: none;
}

.header-sticky:not(.header-v6) .site-header.minimized.header-bottom-no-sticky .header-bottom {
	display: none;
}

.header-sticky:not(.header-v6) .site-header.minimized.has-transparent {
	animation-name: none;
}

.header-sticky.admin-bar .site-header.minimized {
	top: 32px;
}

.header-mobile {
	height: 60px;
	display: flex;
	align-items: center;
	justify-content: space-between;
	padding: 0 15px;
}

.header-mobile .mobile-menu a {
	color: var(--rz-header-color-dark);
	transition: none;
	display: flex;
	margin-top: 2px;
}

.header-mobile .header-cart {
	padding-left: 5px;
}

.header-mobile .mobile-search .razzi-svg-icon {
	font-size: 18px;
}

.header-mobile > * {
	line-height: 1;
}

.header-mobile .site-branding {
	flex: auto;
	text-align: center;
}

.header-mobile.header-no-menu .site-branding {
	text-align: right;
}

.header-mobile .razzi-history-back,
.header-mobile .mobile-menu {
	flex: 1;
}

.mobile-header-icons {
	display: flex;
	align-items: center;
	justify-content: flex-end;
	line-height: 1;
	flex: 1;
}

.mobile-header-icons .search-icon {
	color: var(--rz-header-color-dark);
}

.mobile-header-icons > * {
	margin-right: 15px;
}

.mobile-header-icons > *:first-child {
	margin-right: 0;
}

.header-custom-text {
	color: var(--rz-header-color-dark);
}

.admin-bar.sticky-minimized .rz-modal {
	top: 0;
}

.admin-bar.header-sticky .site-header.minimized {
	top: 0;
}

.admin-bar .rz-modal {
	top: 0;
	height: 100%;
}

.admin-bar .rz-modal.quick-view-modal {
	top: 0;
}

.header-sticky.header-transparent .site-header {
	position: absolute;
}

.razzi-history-back {
	font-size: 24px;
	line-height: 1;
	margin-top: 4px;
	color: var(--rz-header-color-dark);
}

.razzi-history-back .razzi-svg-icon {
	display: block;
}

/*--------------------------------------------------------------
## Page Header
--------------------------------------------------------------*/
.page-header__title {
	font-size: 28px;
	padding: 0 0 10px;
	margin: 0;
	line-height: 1.2;
}

.page-header .site-breadcrumb {
	padding-bottom: 5px;
	overflow: auto;
	white-space: nowrap;
}

.page-header .site-breadcrumb .delimiter {
	margin: 0 5px;
}

.page-header .site-breadcrumb a {
	color: #909090;
}

.razzi-hide-on__breadcrumb .site-breadcrumb {
	display: none;
}

.razzi-hide-on__title .page-header__title {
	display: none;
}

.razzi-catalog-page-content__no-top-spacing .site-content {
	padding-top: 0;
}

.mobile-catalog-page-header--layout-2 {
	position: relative;
	margin-right: -15px;
	margin-left: -15px;
}

.mobile-catalog-page-header--layout-2 .featured-image {
	display: block;
	position: absolute;
	right: 0;
	top: 0;
	width: 100%;
	height: 100%;
	background-size: cover;
	background-repeat: no-repeat;
	background-position: 50% 50%;
}

.mobile-catalog-page-header--layout-2 .featured-image::before {
	content: '';
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	bottom: 0;
}

.mobile-catalog-page-header--layout-2 .page-header__content {
	position: relative;
	text-align: center;
	display: flex;
	flex-direction: column;
	padding: 42px 0 19px;
}

.mobile-catalog-page-header--layout-2 .woocommerce-breadcrumb {
	padding: 0;
	justify-content: center;
	order: 2;
}

.mobile-catalog-page-header--layout-2 .page-title {
	order: 1;
	padding: 0 0 6px;
	font-size: 32px;
	margin: 0;
	text-align: center;
}

/*--------------------------------------------------------------
## Posts and pages
--------------------------------------------------------------*/
.sticky {
	display: block;
}

.blog-wrapper.sticky .entry-title {
	position: relative;
	padding-right: 25px;
}

.blog-wrapper.sticky .entry-title:before {
	content: "";
	background-image: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIg0KCSB2aWV3Qm94PSIwIDAgNDkzLjM1MyA0OTMuMzUzIiA+DQoJPHBhdGggZD0iTTYyLjM4NCwzOC4xMTRjLTcuMTM4LTcuMTMzLTE1Ljc1Mi0xMC43MDYtMjUuODM3LTEwLjcwNmMtMTAuMDg5LDAtMTguNzAyLDMuNTc2LTI1Ljg0MSwxMC43MDYNCgkJQzMuNTcxLDQ1LjI1MywwLDUzLjg2NywwLDYzLjk1NUMwLDc3LjY1OCw2LjA4OCw4OC4xMjgsMTguMjcxLDk1LjM2djM2MS40NWMwLDIuNDc1LDAuOTAyLDQuNjE3LDIuNzE0LDYuNDI0DQoJCWMxLjgwNywxLjgwNywzLjk0OSwyLjcxLDYuNDIzLDIuNzFoMTguMjcxYzIuNDc0LDAsNC42MTUtMC44OTYsNi40MjMtMi43MWMxLjgwOS0xLjgwNywyLjcxMi0zLjk0OSwyLjcxMi02LjQyNFY5NS4zNg0KCQljMTIuMTg1LTcuMjM2LDE4LjI3MS0xNy43MDMsMTguMjcxLTMxLjQwNUM3My4wODUsNTMuODcsNjkuNTE4LDQ1LjI1Nyw2Mi4zODQsMzguMTE0eiIvPg0KCTxwYXRoIGQ9Ik00ODcuOTMyLDY5LjM4NWMtMy42Mi0zLjYxNy03LjkwNS01LjQyNi0xMi44NTQtNS40MjZjLTIuNDcxLDAtNy42NTksMS45OTctMTUuNTU4LDUuOTk2DQoJCWMtNy44OTcsMy45OTktMTYuMjc1LDguNDctMjUuMTI1LDEzLjQxOGMtOC44NDMsNC45NDktMTkuMzIxLDkuNDE5LTMxLjQwMSwxMy40MThjLTEyLjA4NywzLjk5OS0yMy4yNzEsNS45OTYtMzMuNTQ0LDUuOTk2DQoJCWMtOS41MjEsMC0xNy44OTUtMS44MDktMjUuMTMzLTUuNDI0Yy0yMy45ODItMTEuMjMxLTQ0LjgxNi0xOS42MDctNjIuNTIyLTI1LjEyN2MtMTcuNy01LjUxOS0zNi43MzItOC4yNzctNTcuMDk5LTguMjc3DQoJCWMtMzUuMjE0LDAtNzUuMjc5LDExLjQxOC0xMjAuMTk3LDM0LjI1OGMtMTEuMDQzLDUuNTItMTguNTYsOS42MTMtMjIuNTU3LDEyLjI3N2MtNS45MDIsNC4zOC04Ljg1NCw5LjYxMS04Ljg1NCwxNS43MDN2MjExLjg0Mg0KCQljMCw0Ljk0OCwxLjgxMiw5LjIzNiw1LjQyOSwxMi44NDdjMy42MTIsMy42Miw3Ljg5OCw1LjQyOCwxMi44NDcsNS40MjhjMy4wNDQsMCw2LjE4LTAuODU1LDkuNDE5LTIuNTY3DQoJCWM1MS43NzItMjcuNzkxLDk1LjkzLTQxLjY4NSwxMzIuNDc1LTQxLjY4NWMxMy44OTMsMCwyNy40NTQsMi4wOTQsNDAuNjc4LDYuMjc5YzEzLjIyOSw0LjE4OCwyNC4yMjIsOC43NTgsMzIuOTc2LDEzLjcwMg0KCQljOC43NjEsNC45NDgsMTkuMDgyLDkuNTIxLDMwLjk3OCwxMy43MDljMTEuOTAyLDQuMTc5LDIzLjY1NCw2LjI3NiwzNS4yNjIsNi4yNzZjMjkuMzE0LDAsNjQuNDMzLTExLjAzNiwxMDUuMzUyLTMzLjExOQ0KCQljNS4xNDQtMi42NjMsOC44OTctNS4yNzcsMTEuMjc2LTcuODQ4YzIuMzgxLTIuNTY5LDMuNTcyLTYuMjMxLDMuNTcyLTEwLjk5NVY4Mi4yMjZDNDkzLjM1Myw3Ny4yNzksNDkxLjU0Niw3Myw0ODcuOTMyLDY5LjM4NXoiDQoJCQkvPg0KPC9zdmc+DQo=");
	position: absolute;
	top: 50%;
	right: 0;
	transform: translateY(-50%);
	font-size: 18px;
	width: 14px;
	height: 14px;
	background-repeat: no-repeat;
}

.single-post .post-wrapper .entry-content {
	font-size: 18px;
}

.single-post .entry-header {
	margin-bottom: 70px;
}

.updated:not(.published) {
	display: none;
}

.page-links {
	clear: both;
	margin: 1.5em 0 0;
	width: 100%;
	display: inline-block;
}

.page-links .post-page-numbers {
	display: inline-block;
	font-size: 15px;
	font-weight: 500;
	padding: 9px 20px;
	text-decoration: none;
	border-bottom: 1px solid var(--rz-border-color-light);
	margin: -3px;
	color: #909090;
}

.page-links .post-page-numbers.current {
	border-color: var(--rz-border-color-primary);
	color: var(--rz-color-primary);
}

.page-links .post-page-numbers:first-child {
	margin-right: 20px;
}

.entry-title {
	margin: 0 0 13px;
}

.post-wrapper .entry-title {
	font-size: 48px;
}

.entry-meta {
	display: inline-flex;
	flex-wrap: wrap;
	align-items: center;
	color: var(--rz-text-color-gray);
}

.entry-meta a {
	color: var(--rz-text-color-gray);
}

.entry-meta a:hover {
	color: var(--rz-text-color);
}

.entry-meta .meta {
	margin-left: 5px;
}

.entry-meta .meta-date:before {
	content: '/';
	display: inline-block;
	margin-left: 5px;
}

.entry-meta .meta-author {
	text-transform: capitalize;
}

.entry-footer {
	clear: both;
}

.razzi-post__tag {
	margin-right: -2px;
	margin-left: -2px;
	padding-top: 30px;
}

.razzi-post__tag a {
	border: 1px solid var(--rz-border-color-gray);
	display: inline-block;
	padding: 9px 21px;
	font-size: 14px;
	color: var(--rz-text-color);
	margin: 4px 2px;
}

.razzi-post__tag a:hover {
	border-color: var(--rz-border-color-dark);
}

.razzi-post__socials-share {
	margin-top: 18.5px;
	margin-right: -7.5px;
	margin-left: -7.5px;
}

.razzi-post__socials-share a {
	display: inline-flex;
	align-items: center;
	padding: 15px 32px;
	color: var(--rz-color-lighter);
	margin: 7.5px;
}

.razzi-post__socials-share .after-text {
	margin-right: 15px;
}

.razzi-post__socials-share .social-share-link {
	background-color: #666;
}

.razzi-post__socials-share .social-share-link svg {
	font-size: 19px;
}

.razzi-post__socials-share .social-share-link.facebook {
	background-color: #475A96;
}

.razzi-post__socials-share .social-share-link.twitter {
	background-color: #49B2E8;
}

.razzi-post__socials-share .social-share-link.googleplus {
	background-color: #D74047;
}

.razzi-post__socials-share .social-share-link.tumblr {
	background-color: #001833;
}

.razzi-post__socials-share .social-share-link.pinterest {
	background-color: #df0022;
}

.razzi-post__socials-share .social-share-link.linkedin {
	background-color: #0270ad;
}

.razzi-post__socials-share .social-share-link.reddit {
	background-color: #f74301;
}

.razzi-post__socials-share .social-share-link.stumbleupon {
	background-color: #eb4823;
}

.razzi-post__socials-share .social-share-link.telegram {
	background-color: #33a8db;
}

.razzi-post__socials-share .social-share-link.pocket {
	background-color: #e63e51;
}

.razzi-post__socials-share .social-share-link.email {
	background-color: #d75147;
}

.post-wrapper {
	margin-bottom: 80px;
}

.post-wrapper .post-thumbnail {
	margin-top: 70px;
}

.blog-wrapper {
	margin-bottom: 53px;
}

.blog-wrapper .entry-header {
	margin-bottom: 20px;
	display: block;
	position: relative;
}

.blog-wrapper .entry-header .blog-date {
	position: absolute;
	right: 0;
	top: 20px;
	background-color: var(--rz-background-color-light);
	color: var(--rz-color-dark);
	font-size: 11px;
	font-weight: 500;
	padding: 3px 15px;
	text-transform: uppercase;
}

.blog-wrapper .entry-header .entry-title,
.blog-wrapper .entry-header .razzi-button {
	font-weight: 600;
}

.blog-wrapper .entry-summary {
	margin-top: 0;
}

.blog-wrapper .entry-content {
	margin: 0 0 17px;
}

.blog-wrapper .entry-content p {
	margin: 0;
}

.blog-wrapper--grid {
	display: flex;
	flex-wrap: wrap;
	margin: 0 -15px;
}

.blog-wrapper--grid .blog-wrapper {
	width: 50%;
	padding: 0 15px;
}

.full-content .blog-wrapper--grid.blog-columns--2 {
	margin: 0 -25px;
}

.full-content .blog-wrapper--grid.blog-columns--2 .blog-wrapper {
	padding: 0 25px;
}

.blog-columns--3 .blog-wrapper {
	width: 33.33%;
}

.blog-wrapper--listing .blog-wrapper {
	display: flex;
	align-items: flex-start;
	margin-bottom: 40px;
	padding-bottom: 40px;
	border-bottom: 1px solid var(--rz-border-color-light);
}

.blog-wrapper--listing a.post-thumbnail {
	display: flex;
}

.blog-wrapper--listing .entry-header {
	flex: none;
	max-width: 40%;
	margin: 0 0 0 40px;
}

.razzi-posts__found {
	text-align: center;
	margin-top: 11px;
	margin-bottom: 30px;
}

.razzi-posts__found-inner {
	display: inline-block;
	padding: 10px 50px;
	border-bottom: 2px solid var(--rz-border-color-light);
	position: relative;
	color: #767676;
	font-size: 15px;
}

.razzi-posts__found-inner .count-bar {
	position: absolute;
	bottom: -2px;
	right: 0;
	background-color: var(--rz-background-color-dark);
	height: 2px;
}

.razzi-posts__taxs-list {
	margin-bottom: 51px;
	text-align: center;
}

.razzi-posts__taxs-list ul {
	list-style: none;
	padding: 0;
	margin: 0;
	overflow-x: auto;
	overflow-y: hidden;
	display: flex;
	flex-wrap: nowrap;
	justify-content: center;
}

.razzi-posts__taxs-list ul li {
	display: inline-block;
	padding: 0 17px 10px;
}

.razzi-posts__taxs-list ul li a {
	font-weight: 500;
	position: relative;
}

.razzi-posts__taxs-list ul li a:after {
	content: "";
	position: absolute;
	left: 0;
	bottom: 0;
	width: 0;
	border-bottom: 1px solid var(--rz-color-primary);
	transition: width .4s;
}

.razzi-posts__taxs-list ul li a.selected, .razzi-posts__taxs-list ul li a:hover {
	color: var(--rz-color-primary);
}

.razzi-posts__taxs-list ul li a.selected:after, .razzi-posts__taxs-list ul li a:hover:after {
	width: 100%;
	right: 0;
}

.razzi-posts__taxs-list ul li:first-child {
	padding-right: 0;
}

.razzi-posts__taxs-list ul li:last-child {
	padding-left: 0;
}

.razzi-posts__taxs-list ul::-webkit-scrollbar {
	display: none;
}

body:not(.full-content) .razzi-posts__taxs-list ul {
	justify-content: start;
}

.razzi-posts__wrapper {
	position: relative;
}

.razzi-posts__loading {
	position: absolute;
	top: 0;
	right: 0;
	bottom: -50px;
	left: 0;
	z-index: 998;
	background-color: var(--rz-background-color-light);
	display: none;
	text-align: center;
}

.razzi-posts__loading .razzi-loading {
	position: absolute;
	right: 50%;
	transform: translateX(50%);
}

.razzi-posts__loading.show {
	display: block;
}

.razzi-posts__related {
	margin-bottom: 50px;
}

.razzi-posts__related .related-title {
	margin: 0 0 57px;
}

.razzi-posts__related .blog-wrapper {
	margin-bottom: 0;
}

.razzi-posts__related .blog-wrapper .entry-header {
	margin-bottom: 15px;
}

.razzi-posts__related .blog-wrapper .entry-content,
.razzi-posts__related .blog-wrapper .razzi-button {
	display: none;
}

.razzi-posts__related .blog-wrapper .entry-title {
	margin-bottom: 15px;
	font-size: 20px;
}

.blog-wrapper--listing {
	display: block;
	width: 100%;
}

.blog-wrapper--listing .entry-header {
	margin-bottom: 20px;
	margin-left: 0;
	max-width: 100%;
}

.blog-wrapper--listing .entry-summary {
	height: auto;
}

.blog-wrapper--listing .blog-wrapper {
	margin-bottom: 20px;
	padding-bottom: 20px;
	display: block;
}

.razzi-post__socials-share .social-share-link {
	display: block;
	text-align: center;
}

.blog-wrapper .entry-title {
	font-size: 18px;
	line-height: 1.2;
}

.single-post .site-content {
	padding-top: 20px;
}

.single-post .entry-header {
	margin-bottom: 40px;
}

.entry-footer {
	clear: both;
}

.post-wrapper .entry-title {
	font-size: 24px;
	line-height: 1.2;
}

.post-wrapper .entry-meta {
	font-size: 14px;
}

.razzi-posts__taxs-list {
	margin: 10px 0 20px;
}

.razzi-posts__taxs-list ul {
	justify-content: flex-start;
}

/*--------------------------------------------------------------
## Comments
--------------------------------------------------------------*/
.comment-content a {
	word-wrap: break-word;
}

.bypostauthor {
	display: block;
}

.comments-title {
	font-size: 32px;
	color: var(--rz-color-darker);
	padding: 30px 0 0;
	margin: 0;
	text-align: center;
}

.comments-title.has-comments {
	padding-bottom: 10px;
}

.comment-list {
	margin: 37px 0 0 0;
	padding: 0;
	list-style: none;
	border-bottom: 1px solid var(--rz-border-color-light);
}

.comment-list .children {
	list-style: none;
	padding-right: 0;
	margin-right: 90px;
}

.comment-list > li:first-child .comment-body {
	border: none;
	padding-top: 0;
}

.comment-list .comment-body {
	padding: 30px 0 35px;
	border-top: 1px solid var(--rz-border-color-light);
}

.comment-list .depth-5 .children {
	margin-right: 0;
}

.comment-list .comment-meta {
	position: relative;
	padding-right: 60px;
}

.comment-list .comment-meta:before, .comment-list .comment-meta:after {
	content: "";
	display: table;
	table-layout: fixed;
}

.comment-list .comment-meta:after {
	clear: both;
}

.comment-list .avatar {
	border-radius: 50%;
	position: absolute;
	right: 0;
}

.comment-list .comment-author {
	float: right;
}

.comment-list .comment-author .says {
	display: none;
}

.comment-list .comment-metadata {
	display: flex;
	align-items: center;
	justify-content: space-between;
	margin-bottom: 15px;
}

.comment-list .comment-metadata a {
	font-size: 14px;
	color: var(--rz-text-color-gray);
}

.comment-list .comment-metadata a:hover {
	color: var(--rz-color-dark);
}

.comment-list .comment-metadata .fn {
	font-weight: 500;
	text-transform: capitalize;
	font-style: initial;
	color: var(--rz-color-dark);
}

.comment-list .comment-metadata .fn a {
	font-size: inherit;
	color: inherit;
}

.comment-list .comment-metadata .edit-link {
	margin-right: 10px;
}

.comment-list .comment-meta ~ .comment-content {
	margin-right: 90px;
}

.comment-list .comment-content {
	font-size: 16px;
	padding: 5px 0 0;
}

.comment-list .comment-content p:first-child {
	margin-top: 0;
}

.comment-list .comment-content p:last-child {
	margin-bottom: 0;
}

.comment-list .comment-content ul {
	margin-bottom: 1em;
}

.comment-list .comment-content img {
	display: block;
	margin: 10px 0;
}

.comment-list .reply {
	margin-top: 10px;
	margin-right: -4px;
	margin-left: -4px;
}

.comment-list .comment-edit-link,
.comment-list .comment-reply-link {
	font-size: 12px;
	font-weight: 500;
	text-transform: uppercase;
	padding: 0 4px;
}

.comment-list .comment-reply-link {
	display: inline-block;
}

.comment-respond {
	font-size: 16px;
	margin: 40px auto 0;
}

.comment-respond .comment-reply-title {
	margin: 0 0 20px;
	text-align: center;
	font-size: 24px;
}

.comment-respond .comment-reply-title small {
	float: left;
}

.comment-respond .comment-form {
	margin-right: -15px;
	margin-left: -15px;
	text-align: center;
}

.comment-respond .comment-form > p {
	padding-right: 15px;
	padding-left: 15px;
	margin: 0 0 20px;
}

.comment-respond .comment-form textarea,
.comment-respond .comment-form input[type=text],
.comment-respond .comment-form input[type=email] {
	width: 100%;
	display: block;
}

.comment-respond .comment-form .comment-notes {
	margin-bottom: 32px;
}

.comment-respond .comment-form-author,
.comment-respond .comment-form-email {
	width: 50%;
	float: right;
}

.comment-respond .form-submit {
	clear: both;
}

.comment-awaiting-moderation {
	display: block;
}

p.no-comments {
	margin-top: 35px;
	padding: 10px 20px;
	color: var(--rz-background-text-color-primary);
	background-color: var(--rz-background-color-primary);
}

.comments-area .page-numbers {
	display: inline-block;
	font-size: 15px;
	font-weight: 500;
	padding: 7px 20px;
	text-decoration: none;
	margin: 30px -3px;
	color: #909090;
	border-bottom: 1px solid var(--rz-border-color-light);
}

.comments-area .page-numbers.prev, .comments-area .page-numbers.next {
	border-bottom: none;
	margin-right: 0;
	margin-left: 0;
}

.comments-area .page-numbers.prev {
	padding-right: 0;
}

.comments-area .page-numbers.next {
	padding-left: 0;
}

.comments-area .page-numbers.current {
	border-color: var(--rz-border-color-primary);
	color: var(--rz-color-primary);
}

.page .comments-area {
	margin-top: 100px;
}

.comment .comment-metadata {
	display: block;
	padding-right: 0;
	margin-bottom: 20px;
}

.comment .comment-metadata .fn {
	display: block;
}

.comment .avatar {
	max-width: 50px;
}

.comment .comment-content {
	margin-right: 70px;
}

.comment-list .children {
	margin-right: 0;
}

.comment-respond .comment-form-author,
.comment-respond .comment-form-email {
	width: 100%;
}

/*--------------------------------------------------------------
# Default
--------------------------------------------------------------*/
.wp-block-button {
	margin-bottom: 25px;
}

.wp-block-button .wp-block-button__link {
	cursor: pointer;
	display: inline-block;
	margin: 0;
	padding: 12px 25px;
	line-height: 1.5;
	font-size: 16px;
	font-weight: 500;
	text-align: center;
	text-decoration: none;
	overflow-wrap: break-word;
	color: #fff;
}

.wp-block-button .wp-block-button__link:hover {
	text-decoration: none !important;
}

.wp-block-button.is-style-outline .wp-block-button__link {
	border: 1px solid;
	color: var(--rz-color-dark);
}

.wp-block-button.is-style-outline .wp-block-button__link:not(.has-background), .wp-block-button.is-style-outline .wp-block-button__link:focus:not(.has-background), .wp-block-button.is-style-outline .wp-block-button__link:active:not(.has-background) {
	background: transparent;
}

.wp-block-button.is-style-squared .wp-block-button__link {
	border-radius: 0;
}

.wp-block-button:not(.is-style-outline) {
	color: #fff;
}

blockquote cite,
blockquote .wp-block-quote__citation,
.wp-block-quote cite {
	margin-top: 26px;
}

.wp-block-quote.is-large,
.wp-block-quote.is-style-large,
.wp-block-quote {
	padding: 20px 30px;
	border-right: 3px solid var(--rz-color-primary);
}

.wp-block-quote.has-text-align-right {
	padding: 20px 30px;
	border-left: 3px solid var(--rz-color-primary);
}

.wp-block-quote cite {
	font-style: italic;
	color: #838889;
	font-size: 14px;
}

.wp-block-pullquote p {
	font-size: 28px;
}

.wp-block-pullquote.is-style-solid-color blockquote p {
	font-size: 32px;
}

.wp-block-quote.is-large cite,
.wp-block-quote.is-large .wp-block-quote__citation,
.wp-block-quote.is-style-large cite,
.wp-block-quote.is-style-large .wp-block-quote__citation {
	font-size: 18px;
	text-align: right;
}

hr.wp-block-separator {
	background-color: #bbb;
	border: 0;
	height: 1px;
	margin-bottom: 1.5em;
}

.wp-block-pullquote:not(.is-style-solid-color) {
	background-color: #f7f7f7;
}

.wp-block-pullquote {
	background-color: #f7f7f7;
	border-right: none;
	font-size: 20px;
	padding: 0;
	color: var(--rz-color-dark);
}

.wp-block-pullquote blockquote {
	border: none;
	margin: 0;
	padding: 40px 30px;
}

.wp-block-pullquote cite {
	color: #838889;
	text-transform: capitalize;
	font-size: 14px;
	font-style: italic;
}

.wp-block-pullquote.alignleft {
	text-align: right;
}

.wp-block-pullquote.alignright {
	text-align: left;
}

.wp-block-pullquote.aligncenter {
	text-align: center;
}

.wp-block-pullquote.is-style-solid-color blockquote {
	background-color: transparent;
	max-width: 100%;
	padding: 40px 30px;
}

.wp-block-pullquote.is-style-solid-color blockquote cite {
	font-style: italic;
}

.wp-block-pullquote.is-style-solid-color blockquote {
	background-color: transparent;
	max-width: 100%;
}

.wp-block-pullquote.alignleft p,
.wp-block-pullquote.alignright p,
.wp-block-pullquote.alignleft blockquote > .editor-rich-text p,
.wp-block-pullquote.alignright blockquote > .editor-rich-text p {
	font-size: 20px;
}

.wp-block-pullquote cite,
.wp-block-pullquote footer,
.wp-block-pullquote__citation {
	margin-top: 1em;
}

.wp-block-pullquote .wp-block-pullquote__citation {
	color: #40464d;
}

.wp-block-code {
	color: var(--rz-color-darker);
}

.wp-block-code code {
	background: transparent;
}

.has-large-font-size {
	font-size: 36px;
}

figure.is-resized {
	margin-top: 0;
	margin-bottom: 0;
}

figure.alignleft, figure.alignright {
	margin-top: 0;
}

img.alignright {
	clear: both;
}

.aligncenter {
	text-align: center;
}

.wp-block-archives {
	margin-bottom: 35px;
}

.wp-block-archives,
ul.wp-block-categories {
	overflow: hidden;
	padding: 0;
}

.wp-block-archives li,
ul.wp-block-categories li {
	padding: 7px 0;
	clear: both;
	list-style: none;
}

.wp-block-archives li:last-child,
ul.wp-block-categories li:last-child {
	padding-bottom: 0;
}

.wp-block-archives li a,
ul.wp-block-categories li a {
	text-decoration: none;
}

ul.wp-block-latest-posts {
	list-style: none;
	margin: 0 0 1em;
	padding: 0;
}

ul.wp-block-latest-posts ul {
	list-style: none;
}

ul.wp-block-latest-posts li {
	padding: 5px 0;
	margin-bottom: 0;
}

ul.wp-block-latest-posts li:last-child {
	padding-bottom: 0;
}

ul.wp-block-latest-posts li a {
	color: var(--rz-color-dark);
	text-decoration: none;
}

ul.wp-block-latest-posts li a:hover {
	color: var(--rz-color-darker);
}

.wp-block-latest-posts.is-grid li a {
	text-decoration: none;
}

.wp-block-search .wp-block-search__label {
	font-size: 16px;
	font-weight: 600;
	margin: 0 0 5px;
	display: block;
	color: var(--rz-color-dark);
}

.wp-block-search .wp-block-search__input {
	border: 1px solid var(--rz-border-color);
}

.wp-block-search .wp-block-search__button {
	background-color: var(--rz-background-color-dark);
	color: var(--rz-color-lighter);
	padding: 0 15px;
	border: none;
}

.wp-block-search.wp-block-search__button-inside .wp-block-search__inside-wrapper .wp-block-search__button {
	padding: 0 15px;
}

.wp-block-latest-comments__comment {
	margin-bottom: 0;
}

.wp-block-tag-cloud {
	margin-right: -2px;
	margin-left: -2px;
}

.wp-block-tag-cloud a {
	border: 1px solid var(--rz-border-color-gray);
	display: inline-block;
	padding: 9px 21px;
	font-size: 14px !important;
	color: var(--rz-text-color);
	margin: 4px 2px;
	text-decoration: none;
}

.wp-block-tag-cloud a:hover {
	border-color: var(--rz-color-dark);
	text-decoration: none !important;
}

.wp-block-group .wp-block-group__inner-container > h2 {
	font-size: 16px;
	font-weight: 600;
	text-transform: uppercase;
	line-height: 1;
	margin: 0 0 20px;
	padding: 0 0 13px;
	border-bottom: 2px solid;
	display: block;
}

ol.wp-block-latest-comments {
	padding-right: 0;
}

.wp-block-cover-image.has-background-dim::before, .wp-block-cover.has-background-dim::before {
	background-color: rgba(0, 0, 0, 0.5);
	opacity: 1;
}

.wp-block-cover {
	margin-bottom: 32px;
}

.wp-block-cover:last-child {
	margin-bottom: 0;
}

.wp-block-cover p:not(.has-text-color) {
	color: #fff;
}

.wp-block-columns .wp-block-column > *:first-child {
	margin-top: 0;
}

.wp-block-columns.alignfull .wp-block-column p:not(.has-background), .wp-block-columns.alignfull .wp-block-column h1:not(.has-background), .wp-block-columns.alignfull .wp-block-column h2:not(.has-background), .wp-block-columns.alignfull .wp-block-column h3:not(.has-background), .wp-block-columns.alignfull .wp-block-column h4:not(.has-background), .wp-block-columns.alignfull .wp-block-column h5:not(.has-background), .wp-block-columns.alignfull .wp-block-column h6:not(.has-background) {
	padding-right: 15px;
	padding-left: 15px;
}

.wp-block-embed.wp-embed-aspect-1-1 .wp-block-embed__wrapper,
.wp-block-embed.wp-embed-aspect-1-2 .wp-block-embed__wrapper,
.wp-block-embed.wp-embed-aspect-4-3 .wp-block-embed__wrapper,
.wp-block-embed.wp-embed-aspect-9-16 .wp-block-embed__wrapper,
.wp-block-embed.wp-embed-aspect-16-9 .wp-block-embed__wrapper,
.wp-block-embed.wp-embed-aspect-18-9 .wp-block-embed__wrapper,
.wp-block-embed.wp-embed-aspect-21-9 .wp-block-embed__wrapper {
	position: relative;
}

.wp-block-embed.wp-embed-aspect-1-1 .wp-block-embed__wrapper:before,
.wp-block-embed.wp-embed-aspect-1-2 .wp-block-embed__wrapper:before,
.wp-block-embed.wp-embed-aspect-4-3 .wp-block-embed__wrapper:before,
.wp-block-embed.wp-embed-aspect-9-16 .wp-block-embed__wrapper:before,
.wp-block-embed.wp-embed-aspect-16-9 .wp-block-embed__wrapper:before,
.wp-block-embed.wp-embed-aspect-18-9 .wp-block-embed__wrapper:before,
.wp-block-embed.wp-embed-aspect-21-9 .wp-block-embed__wrapper:before {
	content: "";
	display: block;
	padding-top: 50%;
}

.wp-block-embed.wp-embed-aspect-16-9 .wp-block-embed__wrapper:before {
	padding-top: 56.25%;
}

.wp-block-embed.wp-embed-aspect-1-1 .wp-block-embed__wrapper iframe,
.wp-block-embed.wp-embed-aspect-1-2 .wp-block-embed__wrapper iframe,
.wp-block-embed.wp-embed-aspect-4-3 .wp-block-embed__wrapper iframe,
.wp-block-embed.wp-embed-aspect-9-16 .wp-block-embed__wrapper iframe,
.wp-block-embed.wp-embed-aspect-16-9 .wp-block-embed__wrapper iframe,
.wp-block-embed.wp-embed-aspect-18-9 .wp-block-embed__wrapper iframe,
.wp-block-embed.wp-embed-aspect-21-9 .wp-block-embed__wrapper iframe {
	position: absolute;
	top: 0;
	left: 0;
	bottom: 0;
	right: 0;
	width: 100%;
	height: 100%;
}

.blocks-gallery-caption,
.wp-block-embed figcaption,
.wp-block-image figcaption {
	color: #555d66;
	font-size: 13px;
	text-align: center;
}

.wp-block-group.has-background {
	margin-bottom: 50px;
}

pre.wp-block-verse {
	white-space: pre-wrap;
}

.wp-block-table td,
.wp-block-table th {
	padding: 10px 20px;
	border-color: var(--rz-border-color-gray);
}

table.large-padding thead th,
table.large-padding thead td,
table.large-padding th,
table.large-padding td {
	padding: 10px;
}

button,
[type="button"],
[type="reset"],
[type="submit"],
input[type="text"],
input[type="email"] {
	-webkit-appearance: none;
	appearance: none;
	border-radius: 0;
}

/*--------------------------------------------------------------
# Page
--------------------------------------------------------------*/
.error404 .site-content {
	padding: 110px 15px;
}

.error404 .content-area {
	width: 100%;
}

.error404 .error-404 {
	max-width: 440px;
	margin: auto;
	text-align: center;
}

.error404 .error-404 .page-title {
	font-size: 36px;
	margin: 0 0 19px;
}

.error404 .error-404 .page-content {
	margin: 0 0 37px;
	font-size: 18px;
	line-height: 1.5;
}

.error404 .error-404 .razzi-button {
	padding: 0 34px;
}

.error404 .error-404__svg {
	margin-bottom: 27px;
}

.error404 .error-404__svg svg {
	width: 54px;
	height: 54px;
}

.maintenance-page #site-header,
.maintenance-page .site-header,
.maintenance-page #topbar-mobile,
.maintenance-page #site-footer {
	display: none;
}

.maintenance-page .site-content {
	padding: 0 15px;
}

/*--------------------------------------------------------------
# Footer
--------------------------------------------------------------*/
#gotop {
	position: fixed;
	bottom: 25px;
	left: 10px;
	z-index: 999;
	display: flex;
	width: 36px;
	height: 36px;
	background-color: #111;
	color: #ffff;
	box-shadow: 0 0 5px rgba(0, 0, 0, 0.17);
	justify-content: center;
	align-items: center;
	opacity: 0;
	border-radius: 50%;
	transform: translateX(-100%) rotate(90deg);
	transition: all .25s ease;
}

#gotop.show-scroll {
	opacity: 1;
	transform: translateX(0) rotate(90deg);
}

.single-product--sticky-bottom #gotop {
	bottom: 130px;
}

#gotop.show-scroll {
    transform: translateX(0) rotate(-90deg);
}
.footer-newsletter {
	text-align: center;
	--rz-button-bg-color: #525252;
	--rz-button-color: #fff;
	--rz-textbox-color: #A0A0A0;
	--rz-textbox-bg-color: #303030;
	--rz-textbox-border-color: transparent;
	--rz-footer-newsletter-border-color: #2b2b2b;
	--rz-footer-newsletter-top-spacing: 110px;
	--rz-footer-newsletter-bottom-spacing: 41px;
}

.site-footer-dark .footer-newsletter,
.site-footer-custom .footer-newsletter {
	padding-top: var(--rz-footer-newsletter-top-spacing);
	padding-bottom: var(--rz-footer-newsletter-bottom-spacing);
}

.site-footer-light .footer-newsletter .footer-container,
.site-footer-gray .footer-newsletter .footer-container {
	padding-top: var(--rz-footer-newsletter-top-spacing);
	padding-bottom: var(--rz-footer-newsletter-bottom-spacing);
}

.footer-newsletter.has-divider .footer-container:before {
	content: '';
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	width: 100%;
	height: 1px;
	background-color: var(--rz-footer-newsletter-border-color);
}

.footer-newsletter .newsletter-title {
	margin: 0 0 30px;
}

.footer-newsletter .mc4wp-form-fields {
	display: flex;
	max-width: 570px;
	margin: auto;
}

.footer-newsletter .mc4wp-form-fields input[type="email"] {
	padding: 17px 30px;
	width: 100%;
	border: none;
	background-color: var(--rz-textbox-bg-color);
	color: var(--rz-color-lighter);
	border: 1px solid var(--rz-textbox-border-color);
}

.footer-newsletter .mc4wp-form-fields input[type="email"]::placeholder {
	color: var(--rz-textbox-color);
}

.footer-newsletter .mc4wp-form-fields input[type="submit"] {
	margin-right: 5px;
	padding: 0 35px;
	background-color: var(--rz-button-bg-color);
	color: var(--rz-button-color);
}

.footer-newsletter.layout-v2 .mc4wp-form-fields input[type="email"] {
	padding-right: 20px;
	padding-left: 20px;
	background-color: transparent;
	border: none;
	border-bottom: 1px solid var(--rz-textbox-bg-color);
}

.footer-newsletter.layout-v2 .mc4wp-form-fields input[type="submit"] {
	margin-right: 0;
	padding: 0 20px;
	background-color: transparent;
	color: var(--rz-button-color);
	border: none;
	border-bottom: 1px solid var(--rz-textbox-bg-color);
}

.footer-branding .logo.logo-text {
	font-size: 40px;
	font-weight: 600;
}

.footer-payments .payments {
	list-style: none;
	padding: 0;
	margin: 0 -2.5px;
}

.footer-payments li {
	display: inline-block;
	padding: 0 2.5px;
}

.footer-payments li a {
	display: block;
}

.footer-branding .logo.logo-text {
	font-size: 40px;
	font-weight: 600;
}

.footer-menu {
	list-style: none;
	padding: 0;
	margin: 0 -12px;
}

.footer-menu li {
	display: inline-block;
	padding: 0 12px;
}

.footer-widgets {
	color: var(--rz-text-color-gray);
	--rz-footer-widget-border-color: #2b2b2b;
	--rz-footer-widget-top-spacing: 64px;
	--rz-footer-widget-bottom-spacing: 64px;
}

.site-footer-dark .footer-widgets,
.site-footer-custom .footer-widgets {
	padding-top: var(--rz-footer-widget-top-spacing);
	padding-bottom: var(--rz-footer-widget-bottom-spacing);
}

.site-footer-light .footer-widgets .footer-container,
.site-footer-gray .footer-widgets .footer-container {
	padding-top: var(--rz-footer-widget-top-spacing);
	padding-bottom: var(--rz-footer-widget-bottom-spacing);
}

.footer-widgets.has-divider .footer-container:before {
	content: '';
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	width: 100%;
	height: 1px;
	background-color: var(--rz-footer-widget-border-color);
}

.footer-widgets .widget {
	margin-bottom: 19px;
	padding: 0;
	border: none;
}

.footer-widgets .widget-title,
.footer-widgets .wp-block-group .wp-block-group__inner-container > h2 {
	font-size: 13px;
	line-height: 1.46154;
	padding-bottom: 16px;
	margin: 0;
	border: none;
	font-weight: 500;
	letter-spacing: 0.02em;
}

.footer-widgets .widget-title .razzi-svg-icon,
.footer-widgets .wp-block-group .wp-block-group__inner-container > h2 .razzi-svg-icon {
	display: none;
}

.footer-widgets .widget_text {
	line-height: 1.7;
}

.footer-widgets .widget_text .widget-title {
	padding-bottom: 16px;
}

.footer-widgets .widget_text p {
	margin-top: 0;
}

.footer-widgets .widget_nav_menu li {
	padding: 4px 0;
}

.footer-widgets .widget_nav_menu li:first-child {
	padding-top: 0;
}

.footer-widgets .widget_archive li,
.footer-widgets .widget_categories li {
	border: none;
}

.footer-widgets .razzi-widget__social-links .social-links a.social {
	color: var(--rz-text-color-gray);
}

.footer-widgets .razzi-widget__social-links .social-links a.social:hover {
	color: var(--rz-text-color-hover);
}

.footer-widgets-area-diff .diff-row {
	display: flex;
	flex-wrap: wrap;
	justify-content: space-between;
	margin-right: -15px;
	margin-left: -15px;
}

.footer-widgets-area-diff .diff-row > * {
	padding: 0 15px;
}

.footer-extra {
	--rz-footer-extra-border-color: #2b2b2b;
	--rz-footer-extra-top-spacing: 112px;
	--rz-footer-extra-bottom-spacing: 105px;
}

.site-footer-dark .footer-extra,
.site-footer-custom .footer-extra {
	padding-top: var(--rz-footer-extra-top-spacing);
	padding-bottom: var(--rz-footer-extra-bottom-spacing);
}

.site-footer-light .footer-extra .footer-container,
.site-footer-gray .footer-extra .footer-container {
	padding-top: var(--rz-footer-extra-top-spacing);
	padding-bottom: var(--rz-footer-extra-bottom-spacing);
}

.footer-extra.has-divider .footer-container:before {
	content: '';
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	width: 100%;
	height: 1px;
	background-color: var(--rz-footer-extra-border-color);
}

.footer-extra__inner {
	text-align: center;
}

.footer-extra__inner > *:not(:last-child) {
	margin-bottom: 32px;
}

.footer-links {
	--rz-footer-links-border-color: #2b2b2b;
	--rz-footer-links-top-spacing: 64px;
	--rz-footer-links-bottom-spacing: 64px;
}

.site-footer-dark .footer-links,
.site-footer-custom .footer-links {
	padding-top: var(--rz-footer-links-top-spacing);
	padding-bottom: var(--rz-footer-links-bottom-spacing);
}

.site-footer-light .footer-links .footer-container,
.site-footer-gray .footer-links .footer-container {
	padding-top: var(--rz-footer-links-top-spacing);
	padding-bottom: var(--rz-footer-links-bottom-spacing);
}

.footer-links .widget {
	margin-bottom: 10px;
	border: none;
	padding: 0;
}

.footer-links .widget .widget-title {
	border: none;
	text-transform: inherit;
}

.footer-links .widget:last-child {
	margin-bottom: 0;
}

.footer-links .widget_nav_menu .widget-title {
	font-size: 14px;
	font-weight: 500;
	display: inline-block;
	margin-bottom: 0;
	padding: 0 0 0 5px;
}

.footer-links .widget_nav_menu .widget-title + * {
	display: inline-block;
}

.footer-links .widget_nav_menu ul {
	display: flex;
	flex-wrap: wrap;
}

.footer-links .widget_nav_menu ul li {
	display: inline-block;
	position: relative;
	padding: 0 10px;
}

.footer-links .widget_nav_menu ul li:after {
	position: absolute;
	top: 0;
	left: 0;
	height: 12px;
	width: 1px;
	content: "|";
}

.footer-links .widget_nav_menu ul li a {
	position: relative;
	font-size: 14px;
	color: var(--rz-text-color-gray);
}

.footer-links .widget_nav_menu ul li a:before {
	position: absolute;
	bottom: 0;
	left: 0;
	width: 0;
	height: 1px;
	content: "";
	transition: 0.35s;
}

.footer-links .widget_nav_menu ul li a:hover {
	color: var(--rz-color-primary);
}

.footer-links .widget_nav_menu ul li a:hover:before {
	width: 100%;
	right: 0;
	left: auto;
}

.footer-links .widget_nav_menu ul li a:hover::after {
	background-color: var(--rz-color-primary);
}

.footer-links .widget_nav_menu ul li:last-child:after {
	display: none;
}

.footer-links.has-divider .footer-container:before {
	content: '';
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	width: 100%;
	height: 1px;
	background-color: var(--rz-footer-links-border-color);
}

.footer-main {
	font-size: 14px;
	padding: 22px 0;
	--rz-footer-main-border-color: #2b2b2b;
	--rz-footer-main-top-spacing: 22px;
	--rz-footer-main-bottom-spacing: 22px;
}

.site-footer-dark .footer-main,
.site-footer-custom .footer-main {
	padding-top: var(--rz-footer-main-top-spacing);
	padding-bottom: var(--rz-footer-main-bottom-spacing);
}

.site-footer-light .footer-main .footer-container,
.site-footer-gray .footer-main .footer-container {
	padding-top: var(--rz-footer-main-top-spacing);
	padding-bottom: var(--rz-footer-main-bottom-spacing);
}

.footer-main.has-divider .footer-container:before {
	content: '';
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	width: 100%;
	height: 1px;
	background-color: var(--rz-footer-main-border-color);
}

.footer-main .footer-container {
	display: flex;
	align-items: center;
}

.footer-main .footer-items {
	display: flex;
	align-items: center;
}

.header-v6 .footer-main {
	font-size: 16px;
}

.site-footer {
	--rz-text-color-gray: #cdcdcd;
	--rz-text-color-hover: #fff;
	background-size: cover;
	background-color: var(--rz-color-darker);
	color: var(--rz-text-color-gray);
	position: relative;
	clear: both;
}

.site-footer .newsletter-title,
.site-footer .widget-title,
.site-footer .logo-text,
.site-footer .wp-block-group .wp-block-group__inner-container > h2 {
	color: var(--rz-color-lighter);
}

.site-footer .custom-text,
.site-footer input[type="email"],
.site-footer .copyright,
.site-footer .socials-menu li a,
.site-footer .menu li a,
.site-footer a {
	color: var(--rz-text-color-gray);
}

.site-footer .socials-menu li a:hover,
.site-footer .menu li a:hover,
.site-footer a:hover {
	color: var(--rz-text-color-hover);
}

.site-footer .menu li a {
	position: relative;
}

.site-footer .menu li a:after {
	content: '';
	position: absolute;
	bottom: -2px;
	right: 0;
	left: 0;
	width: 0;
	height: 1px;
	background-color: var(--rz-text-color-hover);
	transition: .5s;
	opacity: 0;
}

.site-footer .menu li a:hover:after {
	opacity: 1;
	width: 100%;
}

.site-footer .socials-menu .menu {
	margin-right: -7.5px;
	margin-left: -7.5px;
}

.site-footer .socials-menu li {
	padding: 0 7.5px;
}

.site-footer .socials-menu li a {
	font-size: 20px;
}

.site-footer .socials-menu li a::after {
	display: none;
}

.site-footer .logo .logo-text {
	font-weight: 600;
	font-size: 28px;
	line-height: 1;
}

.site-footer.has-divider {
	border-top: 1px solid #2b2b2b;
}

.site-footer-light {
	--rz-color-darker: #fff;
	--rz-text-color-gray: #444;
	--rz-color-lighter: #111;
	--rz-text-color-hover: #111;
}

.site-footer-light .footer-main {
	padding: 0;
	--rz-footer-main-border-color: rgba( 0, 0, 0, .15 );
}

.site-footer-light .footer-newsletter {
	--rz-button-bg-color: #fff;
	--rz-button-color: #111;
	--rz-textbox-color: #A0A0A0;
	--rz-textbox-bg-color: #fff;
	--rz-textbox-border-color: #cdcdcd;
	--rz-footer-newsletter-border-color: rgba( 0, 0, 0, .15 );
}

.site-footer-light .footer-newsletter .mc4wp-form-fields input[type="email"]:focus {
	--rz-textbox-border-color: #111;
}

.site-footer-light .footer-newsletter:not(.layout-v2) .mc4wp-form-fields input[type="submit"] {
	border: 1px solid var(--rz-textbox-border-color);
}

.site-footer-light .footer-newsletter:not(.layout-v2) .mc4wp-form-fields input[type="submit"]:hover {
	--rz-textbox-border-color: #111;
}

.site-footer-light .footer-newsletter.layout-v2 {
	--rz-textbox-bg-color: #111;
}

.site-footer-light .footer-widgets {
	--rz-footer-widget-border-color: rgba( 0, 0, 0, .15 );
}

.site-footer-light .footer-widgets .widget.dropdown {
	border-color: #cdcdcd;
}

.site-footer-light .razzi-widget__social-links .social-links {
	justify-content: space-between;
}

.site-footer-light .footer-extra {
	--rz-footer-extra-border-color: rgba( 0, 0, 0, .15 );
}

.site-footer-gray {
	--rz-color-darker: #F5F5F5;
	--rz-text-color-gray: #525252;
	--rz-color-lighter: #111;
	--rz-text-color-hover: #111;
}

.site-footer-gray .footer-main {
	padding: 0;
	--rz-footer-main-border-color: rgba( 0, 0, 0, .06 );
}

.site-footer-gray .footer-newsletter {
	--rz-button-bg-color: #F5F5F5;
	--rz-button-color: #111;
	--rz-textbox-color: #A0A0A0;
	--rz-textbox-bg-color: #F5F5F5;
	--rz-textbox-border-color: #cdcdcd;
	--rz-footer-newsletter-border-color: rgba( 0, 0, 0, .06 );
}

.site-footer-gray .footer-newsletter .mc4wp-form-fields input[type="email"]:focus {
	--rz-textbox-border-color: #111;
}

.site-footer-gray .footer-newsletter:not(.layout-v2) .mc4wp-form-fields input[type="submit"] {
	border: 1px solid var(--rz-textbox-border-color);
}

.site-footer-gray .footer-newsletter:not(.layout-v2) .mc4wp-form-fields input[type="submit"]:hover {
	--rz-textbox-border-color: #111;
}

.site-footer-gray .footer-newsletter.layout-v2 {
	--rz-textbox-bg-color: #111;
}

.site-footer-gray .footer-widgets {
	--rz-footer-widget-border-color: rgba( 0, 0, 0, .06 );
}

.site-footer-gray .footer-widgets .widget.dropdown {
	border-color: #cdcdcd;
}

.site-footer-gray .razzi-widget__social-links .social-links {
	justify-content: space-between;
}

.site-footer-gray .footer-extra {
	--rz-footer-extra-border-color: rgba( 0, 0, 0, .06 );
}

.site-footer-dark .has-divider,
.site-footer-custom .has-divider {
	position: relative;
}

.site-footer-light .has-divider .footer-container,
.site-footer-gray .has-divider .footer-container {
	position: relative;
}

.site-footer {
	background-repeat: no-repeat;
	background-position: center center;
	clear: both;
}

.site-footer .footer-newsletter {
	--rz-footer-newsletter-top-spacing: 30px;
	--rz-footer-newsletter-bottom-spacing: 40px;
}

.site-footer .footer-widgets {
	--rz-footer-widget-top-spacing: 30px;
	--rz-footer-widget-bottom-spacing: 40px;
}

.site-footer .footer-widgets {
	--rz-footer-links-top-spacing: 30px;
	--rz-footer-links-bottom-spacing: 40px;
}

.site-footer .footer-extra {
	--rz-footer-extra-top-spacing: 30px;
	--rz-footer-extra-bottom-spacing: 40px;
}

.site-footer .footer-links {
	--rz-footer-links-bottom-spacing: 40px;
	--rz-footer-links-top-spacing: 40px;
}

.footer-main .footer-items {
	padding: 5px 0;
}

.footer-widgets .footer-widgets-area {
	width: 100%;
}

.footer-widgets .widget .widget-title {
	display: flex;
	justify-content: space-between;
	padding-bottom: 0;
	line-height: 1;
}

.footer-widgets .widget .widget-title .razzi-svg-icon {
	display: inline-flex;
	font-size: 18px;
}

.footer-widgets .widget .widget-title.active .razzi-svg-icon {
	transform: rotate(180deg);
}

.footer-widgets .widget .clicked {
	display: none;
	margin-top: 15px;
}

.footer-widgets .widget.dropdown {
	border-bottom: 1px solid #444;
	padding-bottom: 17px;
	margin-bottom: 0;
}

.footer-widgets .widget:not(.dropdown) {
	margin-top: 17px;
}

.footer-widgets .footer-widgets-area-diff .diff-row > * {
	margin-bottom: 21px;
	width: 100%;
}

.footer-widgets .footer-widgets-area:not(.footer-widgets-area-diff) {
	margin-bottom: 20px;
}

.footer-newsletter:not(.layout-v2) .mc4wp-form-fields,
.razzi-newsletter:not(.layout-v2) .mc4wp-form-fields {
	display: block;
}

.footer-newsletter:not(.layout-v2) .mc4wp-form-fields input[type="submit"],
.footer-newsletter:not(.layout-v2) .mc4wp-form-fields input[type="email"],
.razzi-newsletter:not(.layout-v2) .mc4wp-form-fields input[type="submit"],
.razzi-newsletter:not(.layout-v2) .mc4wp-form-fields input[type="email"] {
	width: 100%;
	text-align: center;
}

.footer-newsletter:not(.layout-v2) .mc4wp-form-fields input[type="submit"],
.razzi-newsletter:not(.layout-v2) .mc4wp-form-fields input[type="submit"] {
	margin: 10px 0 0 0;
}

.footer-extra__inner > *:not(:last-child) {
	margin-bottom: 20px;
}

.footer-main .footer-container {
	display: block;
}

.footer-main .footer-items {
	text-align: center;
	display: block;
	padding: 5px 0;
}

.footer-links .widget {
	margin-bottom: 19px;
}

.footer-links .widget_nav_menu .widget-title {
	display: block;
	margin-bottom: 10px;
	padding: 0;
}

.footer-links .widget_nav_menu ul {
	margin-right: -10px;
	margin-left: -10px;
}

.footer-links .widget_nav_menu ul li a {
	font-size: 14px;
}

/*--------------------------------------------------------------
# Navigation bar
--------------------------------------------------------------*/
.navigation-bar-standard {
	--rz-navigation-bar-height: 50px;
	padding-bottom: var(--rz-navigation-bar-height);
}

.navigation-bar-simple + #gotop,
.navigation-bar-standard + #gotop {
	bottom: 75px;
}

.rz-navigation-bar_icon {
	font-size: 18px;
	line-height: 1;
}

.rz-navigation-bar_icon .icon-shop-cart {
	font-size: 20px;
}

.rz-navigation-bar_icon.cart-icon, .rz-navigation-bar_icon.wishlist-icon {
	position: relative;
}

.rz-navigation-bar_icon.cart-icon .counter, .rz-navigation-bar_icon.wishlist-icon .counter {
	position: absolute;
	top: -10px;
	left: 10px;
	font-size: 10px;
	font-weight: 500;
	color: var(--rz-background-text-color-primary);
	text-align: center;
	line-height: 11px;
	min-width: 18px;
	height: 18px;
	border-radius: 30px;
	padding: 4px;
	background-color: var(--rz-background-color-primary);
	display: inline-block;
}

.rz-navigation-bar .add_to_cart_button {
	line-height: 1;
}

.rz-navigation-bar .add_to_cart_button.loading:before {
	opacity: 1;
	width: 16px;
	height: 16px;
	display: inline-block;
	border-radius: 50%;
	border: 2px solid;
	border-color: transparent var(--rz-border-color-lighter) var(--rz-border-color-lighter) var(--rz-border-color-lighter);
	-webkit-animation: razzi-spin infinite 1s linear;
	animation: razzi-spin infinite 1s linear;
	transition: opacity .2s linear .2s;
	content: "";
}

.rz-navigation-bar .add_to_cart_button.loading .razzi-svg-icon {
	display: none;
}

.rz-navigation-bar .add_to_cart_button .add-to-cart-text {
	display: none;
}

.rz-navigation-bar .checkout-text-button {
	display: none;
}

.rz-navigation-bar .added_to_cart {
	display: none;
}

.rz-navigation-bar .rz-loop_atc_button .razzi-svg-icon {
	color: var(--rz-background-text-color-primary);
}

.rz-navigation-bar.hide {
	display: none;
}

.rz-navigation-bar__standard {
	position: fixed;
	bottom: 0;
	right: 0;
	left: 0;
	z-index: 1100;
	background-color: #fff;
	border-top: 1px solid var(--rz-border-color-light);
	display: flex;
	align-items: center;
	justify-content: space-between;
	padding: 15px 15px 13px;
}

.rz-navigation-bar__simple .add_to_cart_button,
.rz-navigation-bar__simple .rz-navigation-bar_icon {
	position: fixed;
	bottom: 15px;
	left: 15px;
	z-index: 1000;
	width: 40px;
	height: 40px;
	background-color: var(--rz-background-color-primary);
	border-radius: 100%;
	box-shadow: 0px 0px 3px rgba(255, 255, 255, 0.3);
	font-size: 15px;
	display: flex;
	justify-content: center;
	align-items: center;
}

.rz-navigation-bar__simple .add_to_cart_button.filter-icon,
.rz-navigation-bar__simple .rz-navigation-bar_icon.filter-icon {
	margin-top: 5px;
}

.rz-navigation-bar__simple .add_to_cart_button .razzi-svg-icon,
.rz-navigation-bar__simple .rz-navigation-bar_icon .razzi-svg-icon {
	color: var(--rz-background-text-color-primary);
}

.rz-navigation-bar__simple .add_to_cart_button .icon-shop-cart,
.rz-navigation-bar__simple .rz-navigation-bar_icon .icon-shop-cart {
	font-size: 18px;
	margin-top: -2px;
}

.rz-navigation-bar.rz-navigation-bar--floating-button {
	padding: 0;
}

.rz-navigation-bar.rz-navigation-bar--floating-button .rz-loop_atc_button {
	background-color: var(--rz-background-color-dark);
	color: var(--rz-color-lighter);
	width: 100%;
	left: 0;
	right: 0;
	bottom: 0;
	border-radius: 0;
	font-size: 16px;
	height: 54px;
	line-height: 54px;
	text-align: center;
}

.rz-navigation-bar.rz-navigation-bar--floating-button .rz-loop_atc_button .add-to-cart-text,
.rz-navigation-bar.rz-navigation-bar--floating-button .rz-loop_atc_button .checkout-text-button {
	display: inline-block;
	padding-right: 10px;
}

.rz-navigation-bar.rz-navigation-bar--floating-button .rz-loop_atc_button:not(.loading).razzi-svg-icon {
	display: inline-block;
}

.rz-navigation-bar_items-left .rz-navigation-bar_icon {
	left: auto;
	right: 15px;
}

.rz-navigation-bar_items-center .rz-navigation-bar_icon {
	left: 50%;
	transform: translateX(-50%);
}

.rz-navigation-bar__sticky-atc .price {
	font-size: 24px;
	font-weight: 500;
	color: var(--rz-color-dark);
	margin: 0;
}

.rz-navigation-bar__sticky-atc .price del {
	margin-left: 13px;
	font-size: 18px;
	color: #a0a0a0;
}

.rz-navigation-bar__sticky-atc .price ins {
	background-color: transparent;
	color: var(--rz-color-primary);
}

.rz-navigation-bar__sticky-atc .add_to_cart_button,
.rz-navigation-bar__sticky-atc .rz-loop_atc_button {
	order: 2;
	font-size: 15px;
	text-align: center;
	width: 40px;
	height: 40px;
	line-height: 45px;
	border-radius: 100%;
	background-color: var(--rz-background-color-primary);
	box-shadow: 0px 0px 3px #fff;
	position: relative;
	outline: none;
}

.rz-navigation-bar__sticky-atc .checkout_button {
	font-size: 18px;
}

.rz-navigation-bar__type-variable {
	position: fixed;
	left: 0;
	bottom: 0;
	width: 100%;
	z-index: 1000;
}

.rz-navigation-bar__type-variable--header {
	display: flex;
	justify-content: space-between;
	width: 100%;
}

.rz-navigation-bar__type-variable--content {
	display: none;
	width: 100%;
	position: absolute !important;
	right: 0;
	left: 0;
	bottom: 0;
	padding: 30px 15px;
	background-color: var(--rz-background-color-light);
	z-index: 9999;
}

.rz-navigation-bar__type-variable--content .product-size-guide {
	display: none;
}

.rz-navigation-bar__type-variable--content form.cart .variations {
	border: none;
}

.rz-navigation-bar__type-variable--content form.cart .variations tr {
	display: flex;
	flex-direction: column;
	justify-content: center;
	align-items: center;
}

.rz-navigation-bar__type-variable--content form.cart .variations tr:not(:last-child) {
	margin-bottom: 20px;
}

.rz-navigation-bar__type-variable--content form.cart .variations td {
	border: none;
	padding: 0;
}

.rz-navigation-bar__type-variable--content form.cart .variations td.label {
	margin-bottom: 10px;
	font-weight: 500;
}

.rz-navigation-bar__type-variable--content form.cart .rz-wishlist-button,
.rz-navigation-bar__type-variable--content form.cart .rz-buy-now-button {
	display: none;
}

.rz-navigation-bar__type-variable--content form.cart .product-button-wrapper button.single_add_to_cart_button {
	min-width: 200px;
}

.rz-navigation-bar__btn-close {
	position: absolute;
	left: 25px;
}

.rz-navigation-bar__type-out-of-stock {
	justify-content: center;
}

.rz-navigation-bar__btn-place-order {
	width: 100%;
}

.rz-navigation-bar__add-to-order {
	padding: 0;
}

.rz-navigation-bar__off-layer {
	position: fixed;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
	cursor: pointer;
	background-color: var(--rz-background-color-dark);
	opacity: 0;
	z-index: -1;
	transition: .3s;
}

.rz-navigation-bar__off-layer.active {
	opacity: .5;
	z-index: 9;
}

.single-product div.product.rz-navigation-bar__type-variable--content .product-button-wrapper {
	flex-wrap: nowrap;
}

.single-product div.product.rz-navigation-bar__type-variable--content .product-button-wrapper > * {
	margin-bottom: 0;
}

.single-product div.product.rz-navigation-bar__type-variable--content .product-button-wrapper .single_add_to_cart_button {
	margin: 0 15px 0 0;
}

.single-product div.product.rz-navigation-bar__type-variable--content .product-button-wrapper .quantity .qty-dropdown .qty-options {
	top: auto;
	bottom: calc(100% - 1px);
}

.single-product .navigation-bar-standard,
.woocommerce-cart .navigation-bar-standard {
	--rz-navigation-bar-height: 70px;
}

/*--------------------------------------------------------------
# Popup
--------------------------------------------------------------*/
.newsletter-popup-modal h1, .newsletter-popup-modal h2, .newsletter-popup-modal h3, .newsletter-popup-modal h4, .newsletter-popup-modal h5, .newsletter-popup-modal h6 {
	color: var(--rz-color-dark);
	line-height: 1.357em;
}

.newsletter-popup-modal .newsletter-title {
	color: var(--rz-color-dark);
	line-height: 1.357em;
	font-size: 28px;
	font-weight: 500;
	margin-bottom: 17px;
}

.newsletter-popup-modal .button-close {
	top: 28px;
	left: 28px;
	transform: none;
	z-index: 10;
	color: #a0a0a0;
	cursor: pointer;
}

.newsletter-popup-modal .button-close:hover {
	color: #a0a0a0;
}

.newsletter-popup-modal .modal-content {
	width: 830px;
	max-width: 90%;
	max-height: 600px;
	position: absolute;
	top: 50%;
	right: 50%;
	transform: translate(50%, -50%);
	background-color: #fff;
	padding: 0;
}

.newsletter-popup-modal .newsletter-popup-content {
	font-size: 18px;
	color: var(--rz-color-dark);
}

.newsletter-popup-modal .n-close {
	font-size: 14px;
	color: #767676;
	position: relative;
	display: inline-flex;
}

.newsletter-popup-modal .n-close:before {
	content: "";
	height: 18px;
	width: 18px;
	background-color: #e2e2e2;
	margin: 2px 0 0 14px;
	float: right;
	transition: 0.15s all ease-out;
	flex: none;
}

.newsletter-popup-modal .n-close:after {
	transform: rotate(-45deg);
	content: "";
	width: 6px;
	height: 10px;
	display: block;
	border: solid #111111;
	border-width: 0 0 2px 2px;
	position: absolute;
	top: 5px;
	right: 6px;
	opacity: 0;
}

.newsletter-popup-modal .n-close.active:after {
	opacity: 1;
}

.newsletter-popup-layout-1-column .modal-content {
	padding: 10px;
	width: 570px;
}

.newsletter-popup-layout-1-column .newsletter-popup-image {
	position: relative;
	min-height: 250px;
	display: flex;
	flex-direction: column;
	justify-content: center;
	align-items: center;
	text-align: center;
}

.newsletter-popup-layout-1-column .newsletter-popup-image:before {
	content: '';
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
	background-color: rgba(17, 17, 17, 0.3);
	z-index: 1;
}

.newsletter-popup-layout-1-column .newsletter-popup-image__holder {
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
	background-size: cover;
}

.newsletter-popup-layout-1-column .newsletter-popup-content {
	--rz-color-dark:#fff;
	position: relative;
	padding: 30px 0;
	z-index: 2;
	width: 63%;
}

.newsletter-popup-layout-1-column .newsletter-popup-wrapper {
	padding: 50px 40px 20px;
	text-align: center;
}

.newsletter-popup-layout-1-column .newsletter-popup-wrapper .newsletter-popup-content {
	display: none;
}

.newsletter-popup-layout-1-column .newsletter-popup-form {
	margin-bottom: 50px;
}

.newsletter-popup-layout-1-column .newsletter-popup-form .mc4wp-form-fields {
	display: flex;
	flex-wrap: wrap;
}

.newsletter-popup-layout-1-column .newsletter-popup-form .mc4wp-form-fields input[type=email] {
	flex: 1;
	margin-left: 6px;
	height: 46px;
	padding: 0 23px;
}

.newsletter-popup-layout-1-column .newsletter-popup-form .mc4wp-form-fields input[type="submit"] {
	flex: 0;
	line-height: 46px;
	padding: 0 25px;
}

.newsletter-popup-layout-1-column .newsletter-popup-form .razzi-svg-icon {
	display: none;
}

.newsletter-popup-layout-1-column .button-close {
	color: #fff;
}

.newsletter-popup-layout-1-column .button-close:hover .razzi-svg-icon {
	color: #fff;
}

.newsletter-popup-layout-2-columns .modal-content {
	display: flex;
}

.newsletter-popup-layout-2-columns .newsletter-popup-image {
	flex: 0.92;
	line-height: 0;
}

.newsletter-popup-layout-2-columns .newsletter-popup-image.no-image {
	flex: none;
}

.newsletter-popup-layout-2-columns .newsletter-popup-wrapper {
	flex: 1;
	padding: 110px 70px 26px;
}

.newsletter-popup-layout-2-columns .newsletter-popup-content {
	padding-bottom: 33px;
}

.newsletter-popup-layout-2-columns .newsletter-popup-form {
	position: relative;
	margin-bottom: 63px;
}

.newsletter-popup-layout-2-columns .mc4wp-form {
	position: relative;
	z-index: 1;
}

.newsletter-popup-layout-2-columns .mc4wp-form-fields {
	display: flex;
	flex-wrap: wrap;
}

.newsletter-popup-layout-2-columns .mc4wp-form-fields input[type=email] {
	flex: 1;
	margin-left: 6px;
	height: 46px;
	padding: 0 23px;
}

.newsletter-popup-layout-2-columns .mc4wp-form-fields input[type="submit"] {
	line-height: 46px;
	height: 46px;
}

.newsletter-popup-modal .newsletter-title {
	font-size: 18px;
	margin-bottom: 10px;
}

.newsletter-popup-modal .newsletter-popup-content {
	font-size: 14px;
}

.newsletter-popup-modal .newsletter-popup-wrapper {
	padding: 50px 15px;
}

.newsletter-popup-modal .newsletter-popup-form {
	margin-bottom: 30px;
}

.newsletter-popup-modal .newsletter-popup-form .mc4wp-form-fields {
	display: block;
}

.newsletter-popup-modal .newsletter-popup-form .mc4wp-form-fields input[type=email] {
	width: 100%;
	margin-left: 0;
	margin-bottom: 10px;
	text-align: center;
}

.newsletter-popup-modal .newsletter-popup-form .mc4wp-form-fields input[type="submit"] {
	width: 100%;
}

.newsletter-popup-modal .button-close {
	top: -12px;
	left: -10px;
	transform: none;
	z-index: 999;
	cursor: pointer;
	margin: 0;
	padding: 10px;
	background-color: #fff;
	border-radius: 50%;
	font-size: 18px;
}

.newsletter-popup-layout-1-column .newsletter-popup-image {
	min-height: 150px;
}

.newsletter-popup-layout-1-column .newsletter-popup-content {
	width: 90%;
}

.newsletter-popup-layout-1-column .newsletter-popup-wrapper {
	padding: 30px 20px;
}

.newsletter-popup-layout-1-column .button-close:hover .razzi-svg-icon {
	color: #a0a0a0;
}

.newsletter-popup-layout-1-column .button-close .razzi-svg-icon {
	color: #a0a0a0;
}

.newsletter-popup-layout-2-columns .newsletter-popup-image {
	display: none;
}

.newsletter-popup-layout-2-columns .mc4wp-form-fields input[type="submit"] {
	background-color: var(--rz-background-color-dark);
	color: var(--rz-color-lighter);
}

.newsletter-popup-layout-2-columns .newsletter-popup-content {
	padding-bottom: 25px;
	text-align: center;
}

.newsletter-popup-layout-2-columns .newsletter-popup-form .razzi-svg-icon {
	display: none;
}

.newsletter-popup-layout-2-columns .modal-content {
	width: 100%;
}

.newsletter-popup-layout-2-columns .n-close {
	display: flex;
	justify-content: center;
}

/*--------------------------------------------------------------
# Elementor
--------------------------------------------------------------*/
/*--------------------------------------------------------------
# Elementor
--------------------------------------------------------------*/
body .elementor-widget:not(:last-child) {
	margin-bottom: 0;
}

@media (max-width: 767px) {
	.elementor .elementor-hidden-phone {
		display: none;
	}
}

@media (min-width: 768px) and (max-width: 1024px) {
	.elementor .elementor-hidden-tablet {
		display: none;
	}
}

@media (min-width: 1025px) {
	.elementor .elementor-hidden-desktop {
		display: none;
	}
}

@media (min-width: 1200px) {
	.elementor-section.elementor-section-boxed > .elementor-container {
		max-width: 1170px;
	}
	.elementor-section.elementor-section-boxed > .elementor-column-gap-default {
		max-width: 1190px;
	}
	.elementor-section.elementor-section-boxed > .elementor-column-gap-extended {
		max-width: 1200px;
	}
	.elementor-section.elementor-section-boxed > .elementor-column-gap-narrow {
		max-width: 1180px;
	}
	.elementor-section.elementor-section-boxed > .elementor-column-gap-wider {
		max-width: 1200px;
	}
	.elementor-section.elementor-section-boxed > .elementor-column-gap-wide {
		max-width: 1200px;
	}
}

.elementor-section-content-space-between .elementor-container {
	justify-content: space-between;
}

.razzi-shortcode-title {
	font-weight: 500;
	font-size: 36px;
	line-height: 48px;
	margin-top: 0;
}

.razzi-shortcode-subtitle {
	font-weight: 500;
	font-size: 13px;
	line-height: 19px;
	letter-spacing: 0.02em;
	text-transform: uppercase;
	color: #A0A0A0;
	margin: 0 0 10px 0;
}

.swiper-pagination {
	position: relative;
	margin-top: 40px;
}

.swiper-pagination .swiper-pagination-bullet {
	padding: 5px;
	background-color: transparent;
	width: auto;
	height: auto;
	opacity: 1;
	margin: 0;
}

.swiper-pagination .swiper-pagination-bullet:before {
	content: "";
	width: 8px;
	height: 8px;
	outline: none;
	background-color: #d8d8d8;
	opacity: 1;
	display: block;
	border-radius: 50%;
	transition: 0.35s;
}

.swiper-pagination .swiper-pagination-bullet.swiper-pagination-bullet-active:before, .swiper-pagination .swiper-pagination-bullet:hover:before {
	background-color: var(--rz-background-color-primary);
}

.swiper-pagination.swiper-pagination-lock {
	display: none !important;
}

.swiper-container-horizontal > .swiper-pagination-bullets .swiper-pagination-bullet {
	margin: 0;
}

ul.razzi-checkmark-lists {
	list-style: none;
	margin: 0;
	padding: 0;
}

ul.razzi-checkmark-lists li {
	font-size: 18px;
	line-height: 1.5;
	margin-bottom: 12px;
	color: #111111;
}

ul.razzi-checkmark-lists li:before {
	content: '';
	display: inline-block;
	width: 12px;
	height: 12px;
	margin-left: 15px;
	background-repeat: no-repeat;
	background-image: url(data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMTQiIGhlaWdodD0iMTEiIHZpZXdCb3g9IjAgMCAxNCAxMSIgZmlsbD0ibm9uZSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4NCjxwYXRoIGQ9Ik0xMyAxTDQuNzUgMTBMMSA1LjkwOTA5IiBzdHJva2U9IiNGRjZGNjEiIHN0cm9rZS13aWR0aD0iMS44IiBzdHJva2UtbGluZWNhcD0icm91bmQiIHN0cm9rZS1saW5lam9pbj0icm91bmQiLz4NCjwvc3ZnPg0K);
}

ul.razzi-checkmark-lists li.wrong {
	color: #767676;
}

ul.razzi-checkmark-lists li.wrong:before {
	background-image: url(data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMTAiIGhlaWdodD0iMTAiIHZpZXdCb3g9IjAgMCAxMCAxMCIgZmlsbD0ibm9uZSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4NCjxwYXRoIGQ9Ik05IDFMMSA5TTEgMUw5IDkiIHN0cm9rZT0iIzkxOTE5MSIgc3Ryb2tlLXdpZHRoPSIxLjciIHN0cm9rZS1saW5lY2FwPSJyb3VuZCIgc3Ryb2tlLWxpbmVqb2luPSJyb3VuZCIvPg0KPC9zdmc+DQo=);
}

@keyframes razzi-rotate {
	0% {
		transform: rotate(0deg) scale(1);
	}
	50% {
		transform: rotate(-180deg) scale(0.6);
	}
	100% {
		transform: rotate(-360deg) scale(1);
	}
}

@keyframes razzi-scale {
	30% {
		transform: scale(0.3);
	}
	100% {
		transform: scale(1);
	}
}

@keyframes razzi-spin {
	from {
		transform: rotate(0deg);
	}
	to {
		transform: rotate(-360deg);
	}
}

@keyframes razziFadeInUp {
	from {
		opacity: 0;
		transform: translate3d(0, 80px, 0);
	}
	to {
		opacity: 1;
		transform: none;
	}
}

@-webkit-keyframes fadeInDown {
	from {
		opacity: 0;
		-webkit-transform: translate3d(0, -100%, 0);
		transform: translate3d(0, -100%, 0);
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none;
	}
}

@keyframes fadeInDown {
	from {
		opacity: 0;
		-webkit-transform: translate3d(0, -100%, 0);
		transform: translate3d(0, -100%, 0);
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none;
	}
}

@keyframes fadein {
	from {
		opacity: 0;
	}
	to {
		opacity: 1;
	}
}

@keyframes bubble {
	0%, 100% {
		transform: scale(0);
	}
	50% {
		transform: scale(1);
	}
}

@keyframes anim-ripple {
	0% {
		transform: scale(0.8);
		opacity: 0;
	}
	20% {
		transform: scale(1);
		opacity: .4;
	}
	to {
		transform: scale(1.2);
		opacity: 0;
	}
}

.swiper-container {
	margin-right: auto;
	margin-left: auto;
	position: relative;
	overflow: hidden;
	z-index: 1;
}

.swiper-wrapper {
	position: relative;
	width: 100%;
	height: 100%;
	z-index: 1;
	display: -webkit-box;
	display: -ms-flexbox;
	display: flex;
	-webkit-transition-property: -webkit-transform;
	transition-property: -webkit-transform;
	-o-transition-property: transform;
	transition-property: transform;
	transition-property: transform, -webkit-transform;
	-webkit-box-sizing: content-box;
	box-sizing: content-box;
}

.swiper-slide {
	-ms-flex-negative: 0;
	flex-shrink: 0;
	width: 100%;
	height: 100%;
	position: relative;
}

.razzi-swiper-carousel-elementor {
	position: relative;
}

.razzi-swiper-carousel-elementor .rz-swiper-button {
	font-size: 28px;
	color: #a0a0a0;
	width: 42px;
	height: 42px;
	line-height: 42px;
	display: inline-block;
	text-align: center;
	opacity: .5;
	transition: .5s;
	cursor: pointer;
	z-index: 99;
	position: absolute;
	top: 50%;
	transform: translate(0, -50%);
}

.razzi-swiper-carousel-elementor .rz-swiper-button:hover:not(.swiper-button-disabled) {
	color: var(--rz-color-dark);
	opacity: 1;
}

.razzi-swiper-carousel-elementor .rz-swiper-button svg {
			transform: rotate(-180deg)
}

.razzi-swiper-carousel-elementor .swiper-button-disabled {
	cursor: not-allowed;
}

.razzi-swiper-carousel-elementor .rz-swiper-button-prev {
	right: -15px;
}

.razzi-swiper-carousel-elementor .rz-swiper-button-next {
	left: -15px;
}

.razzi-swiper-carousel-elementor .swiper-button-disabled {
	opacity: .5;
}

.razzi-swiper-slider-elementor .rz-swiper-button {
	font-size: 24px;
	color: var(--rz-color-dark);
	background-color: #ffffff;
	width: 50px;
	height: 50px;
	line-height: 52px;
}

.razzi-swiper-slider-elementor .rz-swiper-button:hover:not(.swiper-button-disabled) {
	opacity: 1;
}

.razzi-swiper-slider-elementor .rz-swiper-button-prev {
	right: 0;
}

.razzi-swiper-slider-elementor .rz-swiper-button-next {
	left: 0;
}

.razzi-swiper-carousel-elementor .swiper-pagination-lock,
.razzi-swiper-carousel-elementor .swiper-scrollbar-lock,
.razzi-swiper-carousel-elementor .swiper-button-lock {
	display: none;
}

.razzi-banner-carousel {
	position: relative;
	opacity: 0;
}

.razzi-banner-carousel .banner-item {
	position: relative;
	overflow: hidden;
}

.razzi-banner-carousel .banner-item:hover .razzi-icon {
	transform: translateX(-3px);
	                 transform: translateX(-3px) rotateY(180deg);
}

.razzi-banner-carousel .banner-item:hover .banner-img:after {
	background-color: rgba(0, 0, 0, 0.2);
}

.razzi-banner-carousel .banner-content,
.razzi-banner-carousel .banner-img:after,
.razzi-banner-carousel .full-box-button {
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
}

.razzi-banner-carousel .banner-img:after {
	content: '';
	display: block;
	transition: ease .3s;
	background-color: rgba(0, 0, 0, 0.3);
}

.razzi-banner-carousel .banner-img img {
	display: block;
	width: 100%;
}

.razzi-banner-carousel .banner-content {
	padding: 0 30px;
	display: flex;
	flex-direction: column;
	align-items: center;
}

.razzi-banner-carousel .banner-title {
	flex: 0 0 auto;
	font-size: 44px;
	line-height: 1.2;
	margin-top: auto;
	margin-bottom: -114px;
	color: #ffffff;
	width: 100%;
	text-align: center;
	padding-top: 30px;
	padding-bottom: 30px;
}

.razzi-banner-carousel .button-link {
	flex: 0 0 auto;
	margin-top: auto;
	padding-bottom: 40px;
	padding-top: 30px;
	max-width: 100%;
	text-decoration: none;
}

.razzi-banner-carousel .button-text {
	display: block;
	white-space: nowrap;
	text-overflow: ellipsis;
	overflow: hidden;
	color: #1f1f1f;
	background-color: #ffffff;
	line-height: 54px;
	padding: 0 26px;
	min-width: 190px;
}

.razzi-banner-carousel .button-text .razzi-icon {
	margin-right: 11px;
}

.razzi-banner-carousel .swiper-pagination {
	position: relative;
	margin-top: 30px;
}

.razzi-banner-carousel__inner {
	display: flex;
}

.razzi-banner-carousel__btn-position-center .banner-content {
	justify-content: center;
}

.razzi-banner-carousel__btn-position-center .banner-title {
	margin: 0;
	padding: 0;
}

.razzi-banner-carousel__btn-position-center .button-link {
	margin: 0;
}

.razzi-newsletter .mc4wp-form-fields {
	max-width: 570px;
	display: flex;
}

.razzi-newsletter .mc4wp-form-fields input[type="email"] {
	width: 100%;
	margin-left: 5px;
	padding: 15px 30px;
}

.razzi-newsletter .mc4wp-form-fields input[type="email"]::placeholder {
	color: inherit;
}

.razzi-newsletter-2 .newsletter-title {
	margin: 0 0 17px;
}

.razzi-newsletter-2 .newsletter-desc {
	font-size: 18px;
}

.razzi-newsletter-2 .mc4wp-form-fields {
	display: flex;
	border-style: solid;
	border-color: #111111;
	border-width: 0 0 1px;
}

.razzi-newsletter-2 .mc4wp-form-fields input[type="email"] {
	font-size: 15px;
	border: none;
	width: 100%;
	padding: 0 30px;
}

.razzi-newsletter-2 .mc4wp-form-fields input[type="submit"] {
	background-color: transparent;
	color: var(--rz-color-dark);
}

.razzi-newsletter-2__heading {
	margin-bottom: 33px;
}

.razzi-countdown {
	display: flex;
}

.razzi-countdown .timer {
	padding: 0 23px;
	position: relative;
	color: var(--rz-color-dark);
	text-align: center;
}

.razzi-countdown .timer:first-child {
	padding-right: 0 !important;
}

.razzi-countdown .timer:last-child {
	padding-left: 0 !important;
}

.razzi-countdown .timer .text {
	display: block;
	text-transform: uppercase;
	font-size: 13px;
	font-weight: 500;
}

.razzi-countdown .timer .divider {
	position: absolute;
	top: 15px;
	left: -8px;
	font-size: 37px;
	line-height: 1;
	font-weight: 600;
}

.razzi-countdown .digits {
	font-size: 44px;
	font-weight: 600;
	display: block;
}

.razzi-contact-form-7 p {
	margin-bottom: 0;
}

.razzi-contact-form-7 input:not([type="submit"]),
.razzi-contact-form-7 textarea {
	width: 100%;
}

.razzi-contact-form-7 input:not([type="submit"]) {
	margin-bottom: 30px;
}

.razzi-contact-form-7 textarea {
	margin-bottom: 55px;
}

.razzi-faq .faq-title {
	font-size: 18px;
	margin: 0;
	display: flex;
	justify-content: space-between;
}

.razzi-faq .faq-desc {
	margin-top: 23px;
	margin-bottom: 4px;
}

.razzi-faq .faq-desc p {
	margin: 0;
}

.razzi-faq .box-content {
	padding: 21px 0;
	border-style: solid;
	border-color: #e2e2e2;
	border-width: 1px 0 0;
	cursor: pointer;
}

.razzi-faq .box-content .razzi-svg-icon {
	color: #1f1f1f;
	padding-top: 6px;
	padding-right: 25px;
}

.razzi-faq .box-content .razzi-svg-icon svg {
	transform: rotate(0);
	transition: ease .3s;
}

.razzi-faq .box-content .icon-active {
	display: none;
}

.razzi-faq .box-content.active .razzi-svg-default svg {
	transform: rotate(-180deg);
}

.razzi-faq .box-content.active .icon-normal {
	display: none;
}

.razzi-faq .box-content.active .icon-active {
	display: inline-block;
}

.razzi-faq .box-content:last-child {
	border-bottom-width: 1px;
}

.razzi-testimonials-carousel__content {
	font-size: 22px;
	font-style: italic;
	margin-bottom: 24px;
	color: #111;
}

.razzi-testimonials-carousel__text {
	color: #767676;
}

.razzi-testimonials-carousel {
	text-align: center;
}

.razzi-testimonials-carousel .box-item {
	padding-bottom: 35px;
}

.razzi-testimonials-carousel .swiper-pagination {
	position: static;
}

.razzi-testimonials-carousel .rz-swiper-button {
	font-size: 28px;
}

.razzi-testimonials-carousel-2 {
	position: relative;
	opacity: 0;
}

.razzi-testimonials-carousel-2 .testimonials-item {
	padding: 30px 30px 22px;
	border: 1px solid var(--rz-border-color-light);
	height: auto;
	background-color: var(--rz-background-color-light);
}

.razzi-testimonials-carousel-2 .testimonials-item.testimonials-item__author-box {
	display: flex;
}

.razzi-testimonials-carousel-2 .swiper-pagination {
	position: relative;
	margin-top: 56px;
}

.razzi-testimonials-carousel-2 .swiper-scrollbar {
	max-width: 100%;
	background-color: #e5e5e5;
	cursor: pointer;
	height: 4px;
	border-radius: 0;
	position: static;
	width: 100%;
	margin: 70px 0 0;
}

.razzi-testimonials-carousel-2 .swiper-scrollbar .swiper-scrollbar-drag {
	background-color: var(--rz-background-color-primary);
	cursor: pointer;
}

.razzi-testimonials-carousel-2__heading {
	text-align: center;
	margin-bottom: 69px;
}

.razzi-testimonials-carousel-2__heading .heading-subtitle {
	font-size: 13px;
	font-weight: 500;
	text-transform: uppercase;
	color: #909090;
	display: block;
	margin-bottom: 9px;
}

.razzi-testimonials-carousel-2__heading .heading-title {
	font-size: 36px;
	margin: 0;
}

.razzi-testimonials-carousel-2__header {
	display: flex;
	margin-bottom: 15px;
}

.razzi-testimonials-carousel-2__header .testi-image {
	flex: none;
	margin-left: 24px;
	max-width: 80px;
}

.razzi-testimonials-carousel-2__header .testi-image + .header-content {
	padding-top: 9px;
}

.razzi-testimonials-carousel-2__header .subtitle {
	font-size: 14px;
	display: block;
}

.razzi-testimonials-carousel-2__header .testi-title {
	margin: 0 0 5px;
}

.razzi-testimonials-carousel-2__header .razzi-svg-icon {
	font-size: 14px;
	color: #cdcdcd;
}

.razzi-testimonials-carousel-2__header .razzi-svg-icon.rate-active {
	color: #F8B86D;
}

.razzi-testimonials-carousel-2__footer .testi-desc {
	margin-bottom: 15px;
}

.razzi-testimonials-carousel-2__footer .testi-meta {
	font-size: 14px;
	color: var(--rz-text-color-gray);
}

.author-group {
	padding-left: 30px;
	position: relative;
	display: flex;
	flex-direction: column;
	align-items: center;
	flex: 0 1 26%;
}

.author-group:after {
	content: '';
	display: block;
	position: absolute;
	left: 0;
	top: calc(0px - 30px);
	width: 1px;
	height: calc(100% + 30px + 22px + 2px);
	background-color: #E2E2E2;
}

.author-group + .razzi-testimonials-carousel-2__gr {
	padding-right: 50px;
}

.testi-author-image {
	display: flex;
	margin-bottom: 21px;
}

.razzi-testimonials-carousel-2__centeredslides-yes .testimonials-item {
	max-width: 770px;
}

.razzi-testimonials-carousel-2__rating_position-right .header-content {
	display: flex;
	justify-content: space-between;
	width: 100%;
}

.razzi-testimonials-carousel-2__gr {
	flex: 0 1 74%;
}

.razzi-instagram-grid {
	position: relative;
}

.razzi-instagram-grid .instagram-wrapper {
	list-style: none;
	padding: 0;
	margin: 0;
	display: grid;
	grid-gap: 0;
	grid-template-columns: repeat(auto-fill, minmax(20%, 1fr));
	grid-auto-flow: dense;
}

.razzi-instagram-grid .instagram-wrapper li a:hover {
	opacity: .9;
}

.razzi-instagram-grid .instagram-wrapper img {
	display: block;
}

.razzi-instagram-grid .instagram-text-box {
	position: absolute;
	top: 50%;
	right: 50%;
	transform: translate(50%, -50%);
	line-height: 1.5;
	padding: 15px 40px;
}

.razzi-instagram-grid-2 {
	position: relative;
	overflow: hidden;
}

.razzi-instagram-grid-2 .instagram-wrapper {
	list-style: none;
	padding: 0;
	margin: 0;
	display: flex;
	flex-wrap: wrap;
}

.razzi-instagram-grid-2 .instagram-wrapper a {
	display: block;
}

.razzi-instagram-grid-2 .instagram-wrapper li a:hover {
	opacity: .9;
}

.razzi-instagram-grid-2 .instagram-wrapper img {
	display: block;
}

.razzi-instagram-grid-2 .instagram-text-wrapper {
	display: flex;
	flex-direction: column;
	justify-content: center;
	text-align: center;
	padding: 50px;
	width: 100%;
	background-color: #f5f5f5;
}

.razzi-instagram-grid-2 .instagram-text-wrapper .razzi-icon {
	display: block;
	font-size: 33px;
	margin-bottom: 6px;
}

.razzi-instagram-grid-2 .instagram-text-wrapper .instagram-title {
	font-size: 36px;
	margin: 0 0 25px;
}

.razzi-instagram-grid-2 .instagram-text-wrapper .instagram-desc {
	font-size: 18px;
	margin-bottom: 39px;
}

.elementor-widget-razzi-map {
	overflow: hidden;
}

.razzi-map__has-tab {
	display: flex;
}

.razzi-map__has-tab .razzi-map__table {
	display: block;
}

.razzi-map__has-tab .mapboxgl-ctrl-top-right {
	transform: translateX(33%);
}

.razzi-map__has-search {
	margin-top: 175px;
}

.razzi-map {
	clear: both;
	max-width: 1170px;
	margin-right: auto;
	margin-left: auto;
}

.razzi-map > * {
	height: 614px;
}

.razzi-map .box-item {
	padding: 32px 40px;
	cursor: pointer;
}

.razzi-map .box-item:not(:last-child) {
	border-bottom: 1px solid var(--rz-border-color-light);
}

.razzi-map .map-title {
	margin: 0 0 29px;
	font-size: 18px;
}

.razzi-map .map-local {
	margin-bottom: 18px;
}

.razzi-map .map-desc > *:not(:last-child) {
	margin-bottom: 17px;
}

.razzi-map .map-desc h6 {
	margin: 0 0 4px;
}

.razzi-map .mapboxgl-ctrl-bottom-left {
	display: none;
}

.razzi-map .mapboxgl-ctrl-top-right {
	position: absolute;
	z-index: 1;
	width: 75%;
	right: 0;
	left: 0;
	margin: auto;
	top: -175px;
}

.razzi-map .mapboxgl-ctrl-geocoder {
	min-width: 100%;
}

.razzi-map .mapboxgl-ctrl-geocoder ul > li > a {
	text-decoration: none;
	padding: 10px;
	color: var(--rz-color-dark);
}

.razzi-map .mapboxgl-popup-content {
	max-width: 270px;
	font-size: 15px;
}

.razzi-map .mapboxgl-popup-content .map-title {
	font-size: 16px;
	padding-left: 20px;
	margin-bottom: 13px;
}

.razzi-map .mapboxgl-popup-content .map-local {
	margin-bottom: 14px;
}

.razzi-map .mapboxgl-popup-content .map-desc > *:not(:last-child) {
	margin-bottom: 13px;
}

.razzi-map .mapboxgl-ctrl-geocoder .geocoder-icon-search {
        left: 20px;
        right: auto
}

.razzi-map__table {
	max-width: 370px;
	flex: 0 0 33%;
	margin-left: 30px;
	overflow-y: auto;
	box-shadow: 0px 4px 4px rgba(0, 0, 0, 0.02);
	display: none;
	scrollbar-color: #1f1f1f #e2e2e278;
	scrollbar-width: thin;
}

.razzi-map__table::-webkit-scrollbar {
	width: 2px;
}

.razzi-map__table::-webkit-scrollbar-track {
	background-color: #e2e2e2;
}

.razzi-map__table::-webkit-scrollbar-thumb {
	background-color: var(--rz-background-color-dark);
}

.razzi-map__content {
	width: 100%;
}

.razzi-products-tabs .products-empty .razzi-tabs-button {
	display: none;
}

.razzi-products-tabs .products-empty .products {
	list-style-type: none;
	display: flex;
	justify-content: center;
	color: var(--rz-color-dark);
}

.razzi-products-tabs ul.tabs {
	list-style: none;
	padding: 0;
	display: flex;
	justify-content: center;
}

.razzi-products-tabs ul.tabs li {
	padding: 0 15px;
	display: block;
	margin: 0;
	position: relative;
}

.razzi-products-tabs ul.tabs li a {
	padding: 0 2px;
	line-height: 24px;
	display: block;
	position: relative;
	font-weight: 500;
}

.razzi-products-tabs ul.tabs li a:after {
	content: '';
	position: absolute;
	bottom: 0;
	right: 0;
	left: 0;
	width: 0;
	height: 1px;
	background-color: var(--rz-background-color-primary);
	transition: .5s;
	opacity: 0;
}

.razzi-products-tabs ul.tabs li a:hover, .razzi-products-tabs ul.tabs li a.active {
	color: var(--rz-color-primary);
}

.razzi-products-tabs ul.tabs li a:hover:after, .razzi-products-tabs ul.tabs li a.active:after {
	opacity: 1;
	width: 100%;
}

.razzi-products-tabs ul.tabs li:first-child {
	padding-right: 0;
}

.razzi-products-tabs ul.tabs li:last-child {
	padding-left: 0;
}

.razzi-products-tabs .tabs-content.loading {
	position: relative;
}

.razzi-products-tabs .tabs-content.loading:before {
	content: '';
	display: block;
	border-radius: 100px;
	position: absolute;
}

.razzi-products-tabs .tabs-content.loading:before {
	background-color: var(--rz-background-color-primary);
	height: 13px;
	width: 13px;
	top: 0;
	right: 0;
	animation: razzi-scale 1s 0s cubic-bezier(0.09, 0.57, 0.49, 0.9) infinite;
}

.razzi-products-tabs .tabs-content.loading:before {
	z-index: 10;
	top: 50%;
	right: 50%;
}

.razzi-products-tabs .tabs-content.loading:after {
	content: '';
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	bottom: 0;
	background-color: rgba(255, 255, 255, 0.7);
	z-index: 5;
}

.razzi-products-tabs .tabs-header {
	margin-bottom: 80px;
}

.razzi-products-tabs .tabs-panel {
	min-height: 300px;
}

.razzi-products-tabs .tabs-panel .razzi-loading {
	position: absolute;
	right: 50%;
	top: 50%;
	transform: translate(50%, -50%);
}

.razzi-products-tabs .tabs-panel .razzi-tabs-button {
	text-align: center;
	opacity: 0;
	visibility: hidden;
}

.razzi-products-tabs .tabs-panel.tab-loaded {
	min-height: auto;
}

.razzi-products-tabs .tabs-panel.tab-loaded .razzi-tabs-button {
	opacity: 1;
	visibility: visible;
}

.razzi-products-tabs ul.swiper-wrapper {
	flex-wrap: nowrap;
	margin: 0;
	box-sizing: border-box;
}

.razzi-products-tabs ul.swiper-wrapper li {
	clear: none;
	padding-right: 0;
	padding-left: 0;
	margin-bottom: 0;
}

.razzi-products-tabs .swiper-pagination {
	position: static;
	margin-top: 20px;
}

.razzi-products-tabs .swiper-pagination .swiper-pagination-bullet {
	margin-top: 0;
	margin-bottom: 0;
}

.razzi-products-tabs .swiper-scrollbar {
	max-width: 570px;
	background-color: #e5e5e5;
	cursor: pointer;
	height: 4px;
	border-radius: 0;
	position: static;
	width: 100%;
	margin: 20px auto 40px;
}

.razzi-products-tabs .swiper-scrollbar-drag {
	background-color: var(--rz-background-color-primary);
	cursor: pointer;
}

.razzi-products-tabs ul.products.swiper-wrapper {
	margin: 0;
}

.razzi-products-tabs ul.products.swiper-wrapper li.product {
	padding-right: 0;
	padding-left: 0;
	margin-bottom: 0;
}

.razzi-products-tabs .ajax-load-products {
	text-align: center;
	margin-top: 30px;
	position: relative;
	right: 50%;
	transform: translateX(50%);
	display: inline-block;
	min-width: 165px;
	height: 54px;
}

.razzi-products-tabs .ajax-load-products.loading .razzi-gooey {
	display: flex;
}

.razzi-products-tabs .ajax-load-products.loading .button-text {
	display: none;
}

.razzi-products-tabs .ajax-load-products .razzi-gooey {
	background-color: transparent;
	display: none;
}

.razzi-products-tabs .ajax-load-products .razzi-gooey span {
	background-color: #fff;
}

.razzi-product-category-tabs {
	padding: 0 100px;
}

.razzi-product-category-tabs.razzi-category-parent .razzi-shortcode-title {
	margin-bottom: 75px;
}

.razzi-product-category-tabs .category-content {
	position: relative;
	padding: 0 100px;
}

.razzi-product-category-tabs .category-list {
	margin: 0 -15px;
	padding: 0;
	list-style-type: none;
	box-sizing: border-box;
	display: flex;
}

.razzi-product-category-tabs .category-list li {
	display: flex;
	flex-direction: column;
	text-align: center;
}

.razzi-product-category-tabs .category-list li .cat-thumb {
	margin-bottom: 10px;
}

.razzi-product-category-tabs .category-list li .cat-name {
	font-weight: 500;
	font-size: 20px;
	line-height: 35px;
}

.razzi-product-category-tabs .category-list li .cat-name .cat-count {
	margin-right: 5px;
	font-size: 16px;
}

.razzi-product-category-tabs .category-list li:hover .cat-name {
	color: var(--rz-color-primary);
}

.razzi-product-category-tabs ul.tabs {
	list-style: none;
	padding: 0;
	display: flex;
	justify-content: center;
}

.razzi-product-category-tabs ul.tabs li {
	padding: 0 15px;
	display: block;
	margin: 0;
	position: relative;
}

.razzi-product-category-tabs ul.tabs li a {
	padding: 0 2px;
	line-height: 24px;
	display: block;
	position: relative;
	font-weight: 500;
}

.razzi-product-category-tabs ul.tabs li a:after {
	content: '';
	position: absolute;
	bottom: 0;
	right: 0;
	left: 0;
	width: 0;
	height: 1px;
	background-color: var(--rz-background-color-primary);
	transition: .5s;
	opacity: 0;
}

.razzi-product-category-tabs ul.tabs li a:hover, .razzi-product-category-tabs ul.tabs li a.active {
	color: var(--rz-color-primary);
}

.razzi-product-category-tabs ul.tabs li a:hover:after, .razzi-product-category-tabs ul.tabs li a.active:after {
	opacity: 1;
	width: 100%;
}

.razzi-product-category-tabs ul.tabs li:first-child {
	padding-right: 0;
}

.razzi-product-category-tabs ul.tabs li:last-child {
	padding-left: 0;
}

.razzi-product-category-tabs .tabs-content.loading {
	position: relative;
}

.razzi-product-category-tabs .tabs-content.loading:before {
	content: '';
	display: block;
	border-radius: 100px;
	position: absolute;
}

.razzi-product-category-tabs .tabs-content.loading:before {
	background-color: var(--rz-background-color-primary);
	height: 13px;
	width: 13px;
	top: 0;
	right: 0;
	animation: razzi-scale 1s 0s cubic-bezier(0.09, 0.57, 0.49, 0.9) infinite;
}

.razzi-product-category-tabs .tabs-content.loading:before {
	z-index: 10;
	top: 50%;
	right: 50%;
}

.razzi-product-category-tabs .tabs-content.loading:after {
	content: '';
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	bottom: 0;
	background-color: rgba(255, 255, 255, 0.7);
	z-index: 5;
}

.razzi-product-category-tabs .tabs-header {
	margin-bottom: 80px;
}

.razzi-product-category-tabs .tabs-panel {
	min-height: 300px;
}

.razzi-product-category-tabs .tabs-panel .tab-content.swiper-container {
	position: static;
}

.razzi-product-category-tabs .tabs-panel .razzi-loading {
	position: absolute;
	right: 50%;
	top: 50%;
	transform: translateX(50%);
}

.razzi-product-category-tabs .tabs-panel .razzi-tabs-button {
	text-align: center;
	opacity: 0;
	visibility: hidden;
}

.razzi-product-category-tabs .tabs-panel.tab-loaded {
	min-height: auto;
}

.razzi-product-category-tabs .tabs-panel.tab-loaded .razzi-tabs-button {
	opacity: 1;
	visibility: visible;
}

.razzi-product-category-tabs ul.swiper-wrapper {
	margin: 0;
	box-sizing: border-box;
}

.razzi-product-category-tabs ul.swiper-wrapper li {
	clear: none;
	margin-bottom: 0;
}

.razzi-product-category-tabs.razzi-swiper-carousel-elementor .rz-swiper-button {
	position: fixed;
	top: 85px;
	width: auto;
	height: auto;
	z-index: 9;
	font-size: 36px;
}

.razzi-product-category-tabs.razzi-swiper-carousel-elementor .rz-category-arrow-prev {
	right: -113px;
}

.razzi-product-category-tabs.razzi-swiper-carousel-elementor .rz-category-arrow-next {
	left: -113px;
}

.razzi-product-category-tabs .rz-category-arrow-prev {
	right: 0;
}

.razzi-product-category-tabs .rz-category-arrow-next {
	left: 0;
}

.razzi-product-category-tabs .swiper-button-disabled {
	cursor: not-allowed;
}

.razzi-product-of-category.has-categories {
	display: flex;
	justify-content: space-between;
}

.razzi-product-of-category.has-categories .razzi-product-of-category__categories {
	width: 14.6%;
}

.razzi-product-of-category.has-categories .razzi-product-of-category__product {
	width: calc(85.4% - 30px);
}

.razzi-product-of-category__categories {
	position: relative;
	padding: 27px 30px 0 0;
}

.razzi-product-of-category__categories ul {
	margin: 0;
	padding: 0;
	list-style: none;
}

.razzi-product-of-category__categories li {
	margin-bottom: 15px;
}

.razzi-product-of-category__categories li a {
	font-weight: 500;
	font-size: 16px;
	line-height: 23px;
	color: #111111;
	position: relative;
}

.razzi-product-of-category__categories li a:after {
	content: '';
	position: absolute;
	bottom: -1px;
	right: 0;
	left: 0;
	width: 0;
	height: 1px;
	background-color: #111111;
	transition: .5s;
	opacity: 0;
}

.razzi-product-of-category__categories li a:hover:after {
	opacity: 1;
	width: 100%;
}

.razzi-products-carousel ul.swiper-wrapper {
	margin: 0;
	box-sizing: border-box;
}

.razzi-products-carousel ul.swiper-wrapper li {
	clear: none;
	padding-right: 0;
	padding-left: 0;
	margin-bottom: 0;
}

.razzi-products-carousel ul.products {
	flex-wrap: nowrap;
	list-style: none;
}

.razzi-products-carousel ul.products:not(.swiper-wrapper) {
	overflow: hidden;
}

.razzi-products-carousel ul.products li.product {
	padding-right: 0;
	padding-left: 0;
	margin-bottom: 0;
}

.razzi-products-carousel ul.products li.product:not(.swiper-slide) {
	flex-shrink: 0;
	margin-left: 30px;
}

.razzi-products-carousel .swiper-container-multirow ul.products {
	flex-wrap: wrap;
}

.razzi-products-carousel .swiper-scrollbar {
	max-width: 570px;
	background-color: #e5e5e5;
	cursor: pointer;
	height: 4px;
	border-radius: 0;
	position: static;
	width: 100%;
	margin: 5px auto 40px;
}

.razzi-products-carousel .swiper-scrollbar-drag {
	background-color: var(--rz-background-color-primary);
	cursor: pointer;
}

.razzi-products-carousel .razzi-grid-button {
	text-align: center;
	margin-top: 20px;
}

.razzi-products-carousel .razzi-grid-button a {
	line-height: 54px;
	padding: 0 44px;
}

.razzi-products-carousel .razzi-grid-button .razzi-svg-icon {
	font-size: 13px;
}

.razzi-products-carousel .product-loop-outsite {
	margin-right: -15px;
	margin-left: -15px;
}

.razzi-products-carousel .product-loop-outsite .swiper-container {
	padding-right: 15px;
	padding-left: 15px;
}

.elementor-section:not(.elementor-section-full_width) .razzi-swiper-carousel-elementor:not(.razzi-product-category-tabs) ul.product-loop-layout-12 li.product,
.elementor-section:not(.elementor-section-full_width) .razzi-swiper-carousel-elementor:not(.razzi-product-category-tabs) ul.product-loop-layout-6 li.product,
.elementor-section:not(.elementor-section-full_width) .razzi-swiper-carousel-elementor:not(.razzi-product-category-tabs) ul.product-loop-layout-5 li.product {
	margin-bottom: 15px;
	padding-top: 15px;
}

.razzi-products-carousel__heading--arrows {
	display: flex;
	justify-content: space-between;
	align-items: center;
}

.razzi-products-carousel__heading--arrows .rz-swiper-button {
	position: static;
	transform: none;
	width: auto;
	height: auto;
	line-height: normal;
}

.razzi-products-showcase {
	display: flex;
	padding: 0 85px;
}

.razzi-products-showcase:not(.show-category) .meta-cat {
	display: none !important;
}

.razzi-products-showcase:not(.show-rating) .star-rating {
	display: none !important;
}

.razzi-products-showcase:not(.show-quickview) .quick-view-button {
	display: none !important;
}

.razzi-products-showcase:not(.show-addtocart) .rz-loop_atc_button {
	display: none !important;
}

.razzi-products-showcase:not(.show-wishlist) .product-wishlist {
	display: none !important;
}

.razzi-products-showcase:not(.show-badges) .woocommerce-badges {
	display: none !important;
}

.razzi-products-showcase .showcase-image {
	width: 56%;
}

.razzi-products-showcase .showcase-box {
	width: 44%;
	padding-right: 85px;
}

.razzi-products-showcase .razzi-box-title {
	text-align: center;
}

.razzi-products-showcase .razzi-shortcode-title {
	font-weight: 500;
	font-size: 32px;
	line-height: 44px;
	margin-bottom: 60px;
}

.razzi-products-showcase ul.swiper-wrapper {
	flex-wrap: nowrap;
	margin: 0;
	padding: 0;
	list-style-type: none;
	box-sizing: border-box;
}

.razzi-products-showcase ul.swiper-wrapper li {
	clear: none;
	padding-right: 0;
	padding-left: 0;
	margin-bottom: 0;
}

.razzi-products-showcase .rz-swiper-button {
	font-size: 36px;
}

.razzi-products-showcase .swiper-pagination {
	position: static;
	margin-top: 35px;
}

.razzi-products-showcase ul.products li.product {
	width: 100%;
	margin-bottom: 0;
}

.razzi-products-showcase ul.products li.product .product-thumbnail .product-wishlist {
	position: absolute;
	top: 20px;
	left: 20px;
}

.razzi-products-showcase ul.products li.product .product-thumbnail .product-wishlist .rz-loop_button {
	opacity: 1;
	transform: translateY(0);
}

.razzi-products-showcase ul.products li.product .product-thumbnail .product-wishlist .rz-loop_button:hover {
	background-color: var(--rz-background-color-light);
	color: var(--rz-color-dark);
}

.razzi-products-showcase ul.products li.product .product-thumbnail .product-wishlist .rz-loop_button:not(.loading):before {
	left: 54px;
	right: auto;
	top: 50%;
	transform: translateY(-50%);
}

.razzi-products-showcase ul.products li.product .product-thumbnail .product-wishlist .rz-loop_button:not(.loading):after {
	right: auto;
	left: 44px;
	top: 50%;
	transform: translateY(-50%) rotate(90deg);
}

.razzi-products-showcase ul.products li.product .product-thumbnail .product-wishlist .loop_button-text {
	display: none;
}

.razzi-products-showcase ul.products li.product .product-summary {
	text-align: center;
}

.razzi-products-showcase ul.products li.product .star-rating {
	margin: 5px auto;
}

.razzi-products-showcase ul.products li.product .woocommerce-loop-product__title {
	font-size: 18px;
	margin: 0 0 5px;
}

.razzi-products-slider .product-wrapper {
	display: flex;
}

.razzi-products-slider .product-thumbnail {
	max-width: 100px;
	margin-left: 27px;
}

.razzi-products-slider .woocommerce-loop-product__title {
	font-size: 18px;
	line-height: 26.64px;
	font-weight: 500;
	margin-top: 0;
	margin-bottom: 3px;
}

.razzi-products-slider .meta-cat {
	display: block;
	font-size: 16px;
	font-weight: 400;
	color: #767676;
	margin-bottom: 12px;
}

.razzi-products-slider .rating-count {
	display: flex;
	align-items: center;
	margin-bottom: 15px;
}

.razzi-products-slider .rating-count .star-rating {
	margin-top: 0;
	margin-left: 5px;
	margin-right: 0;
}

.razzi-products-slider .rating-count .star-rating .user-rating .razzi-svg-icon {
	color: #F8B86D;
}

.razzi-products-slider .rating-count .razzi-svg-icon {
	display: inline-block;
}

.razzi-products-slider .rating-count .review-count {
	color: #909090;
	font-size: 13px;
	font-weight: 400;
	line-height: 1;
}

.razzi-products-slider .price {
	color: var(--rz-color-dark);
	font-size: 16px;
	font-weight: 500;
}

.razzi-products-slider .price ins {
	color: var(--rz-color-primary);
	background-color: transparent;
	padding-right: 5px;
}

.razzi-products-slider .price del {
	font-size: 14px;
	color: #A0A0A0;
}

.razzi-products-slider .rz-loop_atc_button {
	position: relative;
	padding: 11px 24px;
	min-width: 140px;
	background-color: var(--rz-color-dark);
	color: var(--rz-color-lighter);
	display: inline-flex;
	align-items: center;
	font-weight: 500;
	margin-top: 24px;
	transition: 0.35s;
}

.razzi-products-slider .rz-loop_atc_button:not(.loading):before, .razzi-products-slider .rz-loop_atc_button:not(.loading):after {
	display: none;
}

.razzi-products-slider .rz-loop_atc_button:before {
	opacity: 1;
	width: 16px;
	height: 16px;
	display: inline-block;
	border-radius: 50%;
	border: 2px solid;
	border-top-color: transparent;
	-webkit-animation: razzi-spin infinite 1s linear;
	animation: razzi-spin infinite 1s linear;
	transition: opacity .2s linear .2s;
	content: "";
}

.razzi-products-slider .rz-loop_atc_button.loading:before {
	position: absolute;
	top: 50%;
	right: 50%;
	margin-top: -8px;
	margin-right: -8px;
	color: #ffffff;
}

.razzi-products-slider .rz-loop_atc_button.loading .loop_button-text,
.razzi-products-slider .rz-loop_atc_button.loading .razzi-svg-icon {
	opacity: 0.2;
}

.razzi-products-slider .rz-loop_atc_button .loop_button-text {
	order: 1;
	margin-left: 10px;
}

.razzi-products-slider .rz-loop_atc_button .razzi-svg-icon {
	order: 2;
}

.razzi-products-slider .added_to_cart {
	display: none;
}

.razzi-products-slider .swiper-pagination {
	display: inline-flex;
	flex-direction: column;
	width: auto;
	position: absolute;
	top: 50%;
	left: 24px;
	right: auto;
	bottom: auto;
	transform: translateY(-50%);
	margin: 0;
}

.razzi-products-slider__item {
	position: relative;
}

.razzi-products-slider__content {
	position: absolute;
	top: 50%;
	transform: translateY(-50%);
	display: inline-block;
	background-color: #ffffff;
	padding: 47px 58px 49px 58px;
	width: 470px;
}

.razzi-products-slider__title {
	font-size: 36px;
	font-weight: 500;
	line-height: 48px;
	color: var(--rz-color-dark);
	margin-bottom: 46px;
}

.razzi-products-slider__sale {
	display: inline-flex;
	flex-direction: column;
	align-items: center;
	justify-content: center;
	text-align: center;
	position: absolute;
	left: -48px;
	top: -48px;
	width: 96px;
	height: 96px;
	background-color: #FF6F61;
	border-radius: 100%;
}

.razzi-products-slider__sale span {
	color: #FFFFFF;
	font-size: 16px;
	font-weight: 500;
	line-height: 1;
	margin-bottom: 4px;
}

.razzi-products-slider__sale span.razzi-products-slider__sale-text {
	font-size: 30px;
	font-weight: 600;
	margin-bottom: 0;
}

.razzi-products-grid .razzi-grid-button {
	text-align: center;
	margin-top: 10px;
}

.razzi-products-grid .ajax-load-products {
	text-align: center;
	margin-top: 30px;
	position: relative;
	right: 50%;
	transform: translateX(50%);
	display: inline-block;
	min-width: 165px;
	height: 54px;
}

.razzi-products-grid .ajax-load-products.loading .razzi-gooey, .razzi-products-grid .ajax-load-products.ajax-infinite .razzi-gooey {
	display: flex;
}

.razzi-products-grid .ajax-load-products.loading .button-text, .razzi-products-grid .ajax-load-products.ajax-infinite .button-text {
	display: none;
}

.razzi-products-grid .ajax-load-products.button-outline .razzi-gooey span {
	background-color: var(--rz-background-color-dark);
}

.razzi-products-grid .ajax-load-products .razzi-gooey {
	background-color: transparent;
	display: none;
}

.razzi-products-grid .ajax-load-products .razzi-gooey span {
	background-color: #fff;
}

.razzi-products-grid .woocommerce-pagination {
	text-align: center;
	margin-top: 30px;
}

.razzi-products-masonry:not(.show-category) .meta-cat {
	display: none !important;
}

.razzi-products-masonry:not(.show-rating) .star-rating {
	display: none !important;
}

.razzi-products-masonry:not(.show-quickview) .quick-view-button {
	display: none !important;
}

.razzi-products-masonry:not(.show-addtocart) .rz-loop_atc_button {
	display: none !important;
}

.razzi-products-masonry:not(.show-wishlist) .yith-wcwl-add-to-wishlist {
	display: none !important;
}

.razzi-products-masonry:not(.show-badges) .woocommerce-badges {
	display: none !important;
}

.razzi-products-masonry.btn-hidden .product-loop__buttons {
	display: none !important;
}

.razzi-products-masonry .masonry-banner-content .banner-image {
	position: relative;
	display: flex;
	line-height: 1;
}

.razzi-products-masonry .masonry-banner-content .banner-image:before {
	content: '';
	position: absolute;
	right: 0;
	top: 0;
	width: 100%;
	height: 100%;
}

.razzi-products-masonry .masonry-banner-content .banner-content {
	position: absolute;
	top: 0;
	right: 0;
	display: flex;
	flex-direction: column;
	justify-content: center;
	color: var(--rz-color-dark);
	text-align: center;
	height: 100%;
	width: 100%;
	padding: 30px 45px;
}

.razzi-products-masonry .razzi-banner__sub-title {
	font-weight: 500;
	font-size: 14px;
	line-height: 20px;
	letter-spacing: 0.01em;
	text-transform: uppercase;
}

.razzi-products-masonry .razzi-banner__title {
	font-weight: 600;
	font-size: 60px;
	line-height: 89px;
}

.razzi-products-masonry .razzi-banner__description {
	font-weight: 500;
	font-size: 28px;
	line-height: 41px;
}

.razzi-products-masonry .razzi-banner__button {
	margin-top: 12px;
}

.razzi-products-masonry .razzi-posts__found {
	margin-bottom: 0;
}

.razzi-products-masonry .woocommerce-pagination {
	text-align: center;
	margin-top: 33px;
}

.razzi-products-masonry .woocommerce-pagination ul li:not(.btn-load-more) {
	display: none;
}

.razzi-products-masonry .woocommerce-pagination ul .btn-load-more a {
	display: inline-block;
	text-align: center;
	position: relative;
	transition: none;
	font-weight: 500;
	font-size: 15px;
	line-height: 46px;
	padding: 0 40px;
	text-decoration: none;
	background-color: transparent;
	color: var(--rz-color-dark);
	border: 1px solid;
	white-space: nowrap;
	min-width: 170px;
	transition: 0.2s;
	margin: 0;
}

.razzi-products-masonry .woocommerce-pagination ul .btn-load-more a:hover {
	background-color: var(--rz-background-color-dark);
	color: var(--rz-color-lighter);
}

.razzi-products-masonry .woocommerce-pagination ul .btn-load-more .razzi-gooey-loading {
	display: none;
}

.razzi-products-masonry .woocommerce-pagination ul .btn-load-more .razzi-gooey-loading .razzi-gooey .dots span {
	width: 10px;
	height: 10px;
	filter: none;
}

.razzi-products-masonry .woocommerce-pagination.loading .btn-load-more a:hover {
	background-color: transparent;
	color: var(--rz-color-dark);
}

.razzi-products-masonry .woocommerce-pagination.loading .btn-load-more .razzi-gooey-loading {
	display: inline-block;
	opacity: 1;
}

.razzi-products-masonry .woocommerce-pagination.loading .btn-load-more .load-more-text {
	display: none;
}

.razzi-products-masonry ul.products.layout-masonry li.product.has-banner {
	grid-column: span 2;
	grid-row: span 2;
	width: 100%;
}

.razzi-products-masonry ul.products.layout-masonry li.product .razzi-banner__masonry,
.razzi-products-masonry ul.products.layout-masonry li.product .masonry-banner-content,
.razzi-products-masonry ul.products.layout-masonry li.product .banner-image {
	height: 100%;
}

.razzi-products-masonry ul.products.layout-masonry li.product .banner-image img {
	object-fit: cover;
}

.razzi-products-masonry .link-product-all {
	display: none;
}

.razzi-products-deal:not(.show-category) .meta-cat {
	display: none !important;
}

.razzi-products-deal:not(.show-rating) .star-rating {
	display: none !important;
}

.razzi-products-deal:not(.show-quickview) .quick-view-button {
	display: none !important;
}

.razzi-products-deal:not(.show-addtocart) .rz-loop_atc_button {
	display: none !important;
}

.razzi-products-deal:not(.show-wishlist) .yith-wcwl-add-to-wishlist {
	display: none !important;
}

.razzi-products-deal ul.swiper-wrapper {
	flex-wrap: nowrap;
	margin: 0;
	box-sizing: border-box;
}

.razzi-products-deal ul.swiper-wrapper li {
	clear: none;
	padding-right: 0;
	padding-left: 0;
	margin-bottom: 0;
}

.razzi-products-deal .swiper-scrollbar {
	max-width: 570px;
	background-color: #e5e5e5;
	cursor: pointer;
	height: 4px;
	border-radius: 0;
	position: static;
	width: 100%;
	margin: 5px auto 40px;
}

.razzi-products-deal .swiper-scrollbar-drag {
	background-color: var(--rz-background-color-primary);
	cursor: pointer;
}

.razzi-products-deal .swiper-pagination {
	margin-top: 0;
}

.razzi-products-deal ul.products li.product {
	padding-right: 0;
	padding-left: 0;
	margin-bottom: 0;
}

.razzi-products-deal ul.products li.product .product-summary {
	padding: 0 40px;
	text-align: center;
	position: relative;
	top: -50px;
	background-color: transparent;
}

.razzi-products-deal ul.products li.product .product-summary-deal {
	background-color: var(--rz-background-color-light);
	padding: 20px 20px 18px;
}

.razzi-products-deal ul.products li.product .product-inner {
	padding-bottom: 0;
}

.razzi-products-deal ul.products li.product .product-inner:hover .product-thumbnail .rz-loop_button {
	transform: translate(0, 0);
}

.razzi-products-deal ul.products li.product .product-thumbnail .razzi-product-deal {
	position: absolute;
	top: 20px;
}

.razzi-products-deal ul.products li.product .product-thumbnail .razzi-product-deal .deal-expire-text,
.razzi-products-deal ul.products li.product .product-thumbnail .razzi-product-deal .deal-sold,
.razzi-products-deal ul.products li.product .product-thumbnail .razzi-product-deal .timer .text {
	display: none;
}

.razzi-products-deal ul.products li.product .product-thumbnail .razzi-product-deal .razzi-countdown {
	background-color: var(--rz-background-color-primary);
	padding: 3px 10px;
	min-width: 103px;
}

.razzi-products-deal ul.products li.product .product-thumbnail .razzi-product-deal .razzi-countdown .timer {
	padding: 0 5px;
	color: var(--rz-color-lighter);
}

.razzi-products-deal ul.products li.product .product-thumbnail .razzi-product-deal .razzi-countdown .timer .divider {
	font-size: 11px;
	top: 2px;
	left: -1px;
}

.razzi-products-deal ul.products li.product .product-thumbnail .razzi-product-deal .razzi-countdown .digits {
	font-weight: 500;
	font-size: 11px;
	line-height: 16px;
	letter-spacing: 0.02em;
}

.razzi-products-deal ul.products li.product .product-thumbnail .product-loop__buttons {
	flex-direction: column;
	justify-content: flex-start;
	align-items: flex-end;
	top: 15px;
	left: 20px;
	right: auto;
	height: 100%;
	padding: 0;
}

.razzi-products-deal ul.products li.product .product-thumbnail .rz-loop_button {
	margin: 5px 0;
	transform: translate(-10px, 0);
}

.razzi-products-deal ul.products li.product .product-thumbnail .rz-loop_button:not(.loading):before {
	left: 54px;
	right: auto;
	top: 50%;
	transform: translateY(-50%);
}

.razzi-products-deal ul.products li.product .product-thumbnail .rz-loop_button:not(.loading):after {
	right: auto;
	left: 44px;
	top: 50%;
	transform: translateY(-50%) rotate(90deg);
}

.razzi-products-deal ul.products li.product .woocommerce-loop-product__title {
	font-size: 24px;
	line-height: 35px;
}

.razzi-products-deal ul.products li.product .star-rating {
	margin: 0 auto 5px;
}

.razzi-products-deal-2:not(.show-category) .meta-cat {
	display: none !important;
}

.razzi-products-deal-2:not(.show-rating) .star-rating {
	display: none !important;
}

.razzi-products-deal-2:not(.show-quickview) .quick-view-button {
	display: none !important;
}

.razzi-products-deal-2:not(.show-addtocart) .rz-loop_atc_button {
	display: none !important;
}

.razzi-products-deal-2:not(.show-wishlist) .yith-wcwl-add-to-wishlist {
	display: none !important;
}

.razzi-products-deal-2 .swiper-pagination {
	margin-top: 50px;
}

.razzi-products-deal-2 ul.products {
	flex-wrap: nowrap;
	margin: 0;
}

.razzi-products-deal-2 ul.products:not(.swiper-wrapper) {
	overflow: hidden;
}

.razzi-products-deal-2 ul.products li.product {
	padding-right: 0;
	padding-left: 0;
	margin-bottom: 0;
	border-left: 1px solid transparent;
}

.razzi-products-deal-2 ul.products li.product:not(.swiper-slide) {
	flex-shrink: 0;
	margin-left: 30px;
	width: 100%;
}

.razzi-products-deal-2 ul.products li.product .product-summary {
	padding: 0 28px;
}

.razzi-products-deal-2 ul.products li.product .product-inner {
	text-align: center;
	padding-bottom: 34px;
	border: 1px solid var(--rz-color-primary);
}

.razzi-products-deal-2 ul.products li.product .product-inner:hover .product-thumbnail .rz-loop_button {
	transform: translate(0, 0);
}

.razzi-products-deal-2 ul.products li.product .product-inner .star-rating {
	margin: 0 auto 26px;
	width: auto;
}

.razzi-products-deal-2 ul.products li.product .product-thumbnail {
	margin-bottom: 18px;
}

.razzi-products-deal-2 ul.products li.product .product-thumbnail .woocommerce-loop-product__link img {
	display: inline;
}

.razzi-products-deal-2 ul.products li.product .product-thumbnail .product-loop__buttons {
	flex-direction: column;
	justify-content: flex-start;
	align-items: flex-end;
	top: 15px;
	left: 20px;
	right: auto;
	height: 100%;
	padding: 0;
}

.razzi-products-deal-2 ul.products li.product .product-thumbnail .rz-loop_button {
	margin: 5px 0;
	transform: translate(-10px, 0);
}

.razzi-products-deal-2 ul.products li.product .product-thumbnail .rz-loop_button:not(.loading):before {
	left: 54px;
	right: auto;
	top: 50%;
	transform: translateY(-50%);
}

.razzi-products-deal-2 ul.products li.product .product-thumbnail .rz-loop_button:not(.loading):after {
	right: auto;
	left: 44px;
	top: 50%;
	transform: translateY(-50%) rotate(90deg);
}

.razzi-products-deal-2 ul.products li.product .woocommerce-loop-product__title {
	font-size: 16px;
	line-height: 23.68px;
	margin-bottom: 9px;
}

.razzi-products-deal-2 ul.products li.product .price {
	font-size: 20px;
	margin-bottom: 12px;
}

.razzi-products-deal-2 ul.products li.product .price del {
	font-size: 15px;
}

.razzi-products-deal-2 ul.products li.product .rz-stock {
	font-size: 14px;
}

.razzi-products-deal-2 ul.products li.product .rz-stock span {
	font-weight: 500;
}

.razzi-products-deal-2 .razzi-product-deal {
	margin-bottom: 20px;
}

.razzi-products-deal-2 .razzi-product-deal .deal-expire-text,
.razzi-products-deal-2 .razzi-product-deal .deal-sold {
	display: none;
}

.razzi-products-deal-2 .razzi-product-deal .razzi-countdown {
	background-color: var(--rz-background-color-primary);
	padding: 21px 26px 10px;
	width: 100%;
	justify-content: center;
	align-items: center;
}

.razzi-products-deal-2 .razzi-product-deal .razzi-countdown .timer {
	padding: 0 15px;
	color: var(--rz-color-lighter);
}

.razzi-products-deal-2 .razzi-product-deal .razzi-countdown .timer .divider {
	font-size: 24px;
	top: -5px;
	left: -3px;
}

.razzi-products-deal-2 .razzi-product-deal .razzi-countdown .timer .text {
	font-size: 11px;
}

.razzi-products-deal-2 .razzi-product-deal .razzi-countdown .digits {
	font-weight: 500;
	font-size: 32px;
	line-height: 16px;
	letter-spacing: 0.02em;
	margin-bottom: 10px;
}

.products-deal-2__heading {
	display: flex;
	justify-content: space-between;
	align-items: center;
	margin-bottom: 68px;
}

.products-deal-2__title {
	font-size: 28px;
	font-weight: 500;
	color: #111111;
}

.products-deal-2__arrows .rz-swiper-button {
	position: static;
	transform: none;
	height: 30px;
	width: 30px;
	line-height: 30px;
	background-color: #F5F5F5;
	color: #1F1F1F;
	font-size: 18px;
}

.razzi-product-shortcode {
	background-color: var(--rz-background-color-gray);
	padding: 90px 0 100px;
}

.razzi-product-shortcode.single-product div.product .woocommerce-product-gallery {
	width: 45%;
}

.razzi-product-shortcode.single-product div.product .woocommerce-product-gallery .flex-control-thumbs {
	margin: 15px 0 0 0;
}

.razzi-product-shortcode.single-product div.product .woocommerce-product-gallery .flex-control-thumbs li {
	padding: 0;
}

.razzi-product-shortcode.single-product div.product .summary-price-box .price {
	font-size: 22px;
}

.razzi-product-shortcode.single-product div.product .entry-summary {
	width: 55%;
	padding-right: 70px;
	padding-left: 40px;
	padding-top: 35px;
}

.razzi-product-shortcode.single-product div.product .entry-summary .product_title {
	font-size: 32px;
}

.razzi-product-shortcode.single-product div.product.product-type-variable form.variations_form .variations td.value {
	margin-bottom: 20px;
}

.razzi-product-shortcode.razzi-swiper-carousel-elementor .rz-swiper-button {
	width: 30px;
	height: 50px;
	line-height: 50px;
	font-size: 12px;
}

.razzi-product-shortcode.razzi-swiper-carousel-elementor .rz-swiper-button {
	opacity: 0;
}

.razzi-product-shortcode.razzi-swiper-carousel-elementor .rz-gallery-button-next {
	left: 0;
}

.razzi-product-shortcode.razzi-swiper-carousel-elementor .linked-gallery-carousel:hover .rz-swiper-button {
	opacity: 1;
}

.razzi-product-shortcode .rz-product-wrapper {
	background-color: var(--rz-background-color-light);
	padding: 30px;
	display: flex;
	box-shadow: 0px 0.5px 10px 0px rgba(0, 0, 0, 0.07);
}

.razzi-deals-carousel .countdown-slider {
	height: 550px;
	display: flex;
	align-items: center;
}

.razzi-deals-carousel .countdown-item {
	position: relative;
	padding: 15px;
}

.razzi-deals-carousel .countdown-bg {
	background-size: cover;
	background-repeat: no-repeat;
	position: absolute;
	width: 100%;
	height: 100%;
}

.razzi-deals-carousel .countdown-title {
	font-weight: 500;
	font-size: 32px;
	line-height: 44px;
	color: var(--rz-color-dark);
	margin-bottom: 30px;
}

.razzi-deals-carousel .countdown-content {
	margin-bottom: 52px;
}

.razzi-deals-carousel .digits {
	font-weight: 600;
	font-size: 40px;
	line-height: 59px;
	color: var(--rz-color-primary);
}

.razzi-deals-carousel .text {
	font-weight: 500;
	font-size: 13px;
	line-height: 19px;
	letter-spacing: 0.02em;
	text-transform: uppercase;
	color: #919191;
}

.razzi-deals-carousel .timer .divider {
	top: 7px;
	color: var(--rz-color-primary);
}

.razzi-deals-carousel .countdown-button .razzi-svg-icon {
	font-size: 13px;
}

.razzi-deals-carousel .countdown-button a {
	padding: 0 44px;
	line-height: 54px;
}

.razzi-deals-carousel .swiper-container-horizontal > .swiper-pagination-bullets {
	bottom: 30px;
}

.razzi-deals-carousel .rz-swiper-button {
	font-size: 20px;
	color: var(--rz-color-dark);
	background-color: #fff;
}

.razzi-deals-carousel .rz-swiper-button-next {
	left: 0;
}

.razzi-deals-carousel .rz-swiper-button-prev {
	right: 0;
}

.razzi-deals-carousel-2 .deals-carousel-2__thumbnail {
	margin-bottom: 21px;
}

.razzi-deals-carousel-2 .deals-carousel-2__item {
	display: flex;
	margin-bottom: 20px;
}

.razzi-deals-carousel-2 .deals-carousel-2__deal {
	font-size: 20px;
	font-weight: 500;
	color: var(--rz-color-primary);
	margin-bottom: 7px;
}

.razzi-deals-carousel-2 .deals-carousel-2__title {
	font-weight: 500;
	font-size: 18px;
	color: var(--rz-color-dark);
}

.razzi-deals-carousel-2 .razzi-countdown {
	justify-content: space-between;
	height: max-content;
	margin-left: 40px;
}

.razzi-deals-carousel-2 .timer {
	width: 48px;
	display: inline-flex;
	flex-direction: column;
	justify-content: center;
	align-items: center;
	margin-left: 4px;
	padding: 10px 0;
	background-color: var(--rz-color-primary);
}

.razzi-deals-carousel-2 .timer .digits {
	font-weight: 500;
	font-size: 20px;
	color: var(--rz-color-lighter);
	line-height: 1;
	margin-bottom: 2px;
}

.razzi-deals-carousel-2 .timer .text {
	line-height: 1;
	font-weight: 300;
	font-size: 13px;
	text-transform: lowercase;
	color: var(--rz-color-lighter);
}

.razzi-deals-carousel-2 .timer .divider, .razzi-deals-carousel-2 .timer.seconds {
	display: none;
}

.razzi-deals-carousel-2 .timer.minutes {
	margin-left: 0;
}

.razzi-deals-carousel-2 .deals-carousel-2__button .razzi-svg-icon {
	font-size: 13px;
}

.razzi-deals-carousel-2 .deals-carousel-2__button .razzi-button {
	width: 100%;
	line-height: 50px;
	color: var(--rz-color-dark);
	background-color: var(--rz-color-lighter);
	border: 1px solid var(--rz-color-primary);
}

.razzi-deals-carousel-2 .swiper-container-horizontal > .swiper-pagination-bullets {
	position: static;
	margin-top: 74px;
}

.razzi-deals-carousel-2 .rz-swiper-button {
	font-size: 20px;
	color: var(--rz-color-dark);
	background-color: #fff;
}

.razzi-deals-carousel-2 .rz-swiper-button-next {
	left: 0;
}

.razzi-deals-carousel-2 .rz-swiper-button-prev {
	right: 0;
}

.razzi-banner {
	position: relative;
	overflow: hidden;
}

.razzi-banner:hover .razzi-banner__featured-image {
	transform: scale(1.05);
}

.razzi-banner:hover .razzi-icon {
	transform: translateX(-3px);
                transform: translateX(-3px) rotateY(180deg);
}

.razzi-banner:hover .image-zoom img {
	transform: scale(1.05);
	-ms-transform: scale(1.05);
	/* IE 9 */
	-moz-transform: scale(1.05);
	/* Firefox */
	-webkit-transform: scale(1.05);
	/* Safari and Chrome */
	-o-transform: scale(1.05);
	/* Opera */
}

.razzi-banner .razzi-countdown {
	display: inline-flex;
	justify-content: center;
	padding: 3px 13px 4px 11px;
	margin-bottom: 30px;
	background-color: var(--rz-background-color-primary);
}

.razzi-banner .razzi-countdown .timer {
	min-width: 20px;
	padding: 0 5px;
	color: var(--rz-color-lighter);
}

.razzi-banner .razzi-countdown .timer .text {
	display: none;
	font-size: 9px;
	font-weight: 500;
}

.razzi-banner .razzi-countdown .timer .divider {
	top: 3px;
	left: -1px;
	font-size: 9px;
	font-weight: 500;
}

.razzi-banner .razzi-countdown .digits {
	font-size: 11px;
	font-weight: 500;
}

.razzi-banner__featured-image {
	transform: scale(1.01);
	transition: .3s;
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	bottom: 0;
}

.razzi-banner__featured-image:before {
	content: '';
	position: absolute;
	right: 0;
	left: 0;
	top: 0;
	width: 100%;
	height: 100%;
	z-index: 9;
}

.razzi-banner-content {
	position: relative;
	z-index: 1;
	height: 400px;
	max-width: 100%;
	display: flex;
	margin: auto;
	padding: 30px 70px;
}

.razzi-banner-content__sub-title {
	font-size: 14px;
	text-transform: uppercase;
	margin: 0;
}

.razzi-banner-content__title {
	font-size: 28px;
	line-height: 1.35714;
	margin: 0 0 16px;
}

.razzi-banner-content__description {
	margin: 0 0 16px;
}

.razzi-banner-content__button-link {
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	bottom: 0;
	z-index: 2;
}

.razzi-banner-content__sale {
	position: absolute;
	top: 20px;
	left: 20px;
	width: 96px;
	height: 96px;
	border-radius: 50%;
	background-color: var(--rz-background-color-primary);
	display: flex;
	flex-direction: column;
	align-items: center;
	justify-content: center;
	color: #ffffff;
	font-weight: 500;
	font-size: 28px;
}

.razzi-banner-content__sale--text {
	font-size: 16px;
	margin-bottom: 6px;
	line-height: 1;
}

.razzi-banner-content__sale--unit {
	margin-right: 3px;
}

.razzi-banner-content__sale--number {
	line-height: 1.1;
}

.razzi--v-position-top .razzi-banner-content {
	align-items: flex-start;
}

.razzi--v-position-bottom .razzi-banner-content {
	align-items: flex-end;
}

.razzi--v-position-middle .razzi-banner-content {
	align-items: center;
}

.razzi--h-position-left .razzi-banner-content {
	justify-content: flex-start;
}

.razzi--h-position-right .razzi-banner-content {
	justify-content: flex-end;
}

.razzi--h-position-center .razzi-banner-content {
	justify-content: center;
}

.razzi-banner-content__sale--text.has-background, .razzi-banner-content__sale--number.has-background, .razzi-banner-content__sale--unit.has-background {
	-webkit-background-clip: text;
	background-clip: text;
	color: transparent;
	-webkit-text-fill-color: transparent;
}

.razzi-banner__button-2 {
	margin-right: 30px;
}

.razzi-brands-carousel {
	opacity: 0;
}

.razzi-brands-carousel .list-brands {
	display: flex;
	align-items: center;
}

.razzi-brands-carousel .brand-item {
	text-align: center;
}

.razzi-brands-carousel .brand-item img {
	transition: transform 0.3s;
	padding-top: 3px;
}

.razzi-brands-carousel .brand-item:hover img {
	transform: translateY(-3px);
}

.razzi-brands-carousel .swiper-pagination {
	position: relative;
	margin-top: 31px;
}

.razzi-brands-carousel .rz-swiper-button {
	background-color: transparent;
	font-size: 28px;
	color: #a0a0a0;
}

.razzi-brands-carousel .rz-swiper-button:hover {
	color: var(--rz-color-dark);
}

.razzi-brands-grid {
	overflow: hidden;
}

.razzi-brands-grid .heading-title {
	font-size: 36px;
	margin: 0 0 66px;
	text-align: center;
}

.razzi-brands-grid .list-brands {
	display: flex;
	flex-wrap: wrap;
	border-style: solid;
	border-color: #ccc;
	border-width: 1px 1px 0 0;
}

.razzi-brands-grid .brand-item {
	padding: 15px;
	border-style: solid;
	border-color: #ccc;
	border-width: 0 0 1px 1px;
}

.razzi-brands-grid .brand-item a {
	display: flex;
	flex-direction: column;
	align-items: center;
	justify-content: center;
	background-color: #fff;
	text-align: center;
	min-height: 110px;
	transition: transform 0.3s;
}

.razzi-brands-grid .brand-item img {
	display: block;
}

.razzi-brands-grid .brand-item:hover > a {
	transform: translateY(-6px);
}

.razzi-brands-grid .brands-button {
	display: flex;
	justify-content: center;
	margin-top: 77px;
	text-decoration: none;
}

.razzi-brands-grid.razzi-brands-grid__border-none .list-brands {
	margin-right: -15px;
	margin-left: -15px;
}

.razzi-brands-grid-box-shadow-yes .razzi-brands-grid .brand-item a {
	box-shadow: 0px 4px 4px rgba(0, 0, 0, 0.02);
}

.razzi-slides-elementor {
	opacity: 0;
}

.razzi-slides-elementor .item-slider {
	justify-content: center;
	align-items: center;
	position: relative;
	overflow: hidden;
	height: 400px;
	width: 100%;
}

.razzi-slides-elementor .item-slider:not(:first-child) {
	display: none;
}

.razzi-slides-elementor .item-slider.swiper-slide {
	display: block;
}

.razzi-slides-elementor .item-slider:before {
	content: '';
	position: absolute;
	right: 0;
	top: 0;
	width: 100%;
	height: 100%;
}

.razzi-slides-elementor .slick-slide-inner {
	background-repeat: no-repeat;
	background-position: center;
	position: absolute;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	display: flex;
}

.razzi-slides-elementor .swiper-pagination {
	margin-top: 0;
	position: absolute;
	bottom: 34px;
	right: 0;
	left: 0;
}

.razzi-slides-elementor .swiper-lazy-preloader {
	width: auto;
	height: auto;
	margin: 0;
	animation: none;
	transform-origin: initial;
}

.razzi-slides-elementor .swiper-lazy-preloader:after {
	display: none;
}

.razzi-slides-elementor .swiper-lazy-preloader .razzi-posts__loading {
	display: block;
}

.razzi-slides-elementor .button-text {
	line-height: 1.3;
}

.razzi-slides-elementor .button-text:not(.razzi-button--underlined) {
	padding: 17px 35px;
}

.razzi-slides-elementor .button-text .razzi-svg-icon {
	margin-right: 14px;
}

.razzi-slides-elementor .razzi-slide-content {
	position: relative;
}

.razzi-slides-elementor .razzi-slide__sale {
	position: absolute;
	top: -35px;
	left: -35px;
	width: 96px;
	height: 96px;
	border-radius: 50%;
	background-color: var(--rz-background-color-primary);
	display: flex;
	flex-direction: column;
	align-items: center;
	justify-content: center;
	color: #ffffff;
	font-size: 28px;
	z-index: 1;
}

.razzi-slides-elementor .razzi-slide__sale .sale-text {
	font-size: 26px;
	font-weight: 600;
	line-height: 1;
}

.razzi-slides-elementor .razzi-slide__sale .sale-betext {
	font-size: 16px;
	font-weight: 500;
	margin-bottom: 8px;
	line-height: 1;
}

.razzi-slides-elementor .button-link-all {
	position: absolute;
	top: 0;
	left: 0;
	bottom: 0;
	right: 0;
}

.razzi-slide-banner__video {
	width: 100%;
	height: 100%;
	object-fit: fill;
}

.razzi-slide-banner__video--ytb {
	position: relative;
	height: 0;
	overflow: hidden;
}

.razzi-slide-banner__video--ytb iframe {
	position: absolute;
	top: 0;
	right: 0;
	height: 100%;
	width: 100%;
	border: 0;
	background-color: #000;
}

.razzi-slide-banner__ratio--219 .razzi-slide-banner__video--ytb {
	padding-bottom: 42.8571%;
}

.razzi-slide-banner__ratio--169 .razzi-slide-banner__video--ytb {
	padding-bottom: 56.25%;
}

.razzi-slide-banner__ratio--43 .razzi-slide-banner__video--ytb {
	padding-bottom: 75%;
}

.razzi-slide-banner__ratio--32 .razzi-slide-banner__video--ytb {
	padding-bottom: 66.6666%;
}

.razzi-slide-banner__ratio--11 .razzi-slide-banner__video--ytb {
	padding-bottom: 100%;
}

.razzi-slide-banner__ratio--916 .razzi-slide-banner__video--ytb {
	padding-bottom: 177.8%;
}

.razzi-slide-heading {
	font-size: 44px;
	font-weight: 500;
	line-height: 1.45455;
	color: var(--rz-color-dark);
	margin-bottom: 19px;
	display: inline-block;
}

.razzi-slide-before-desc {
	font-size: 24px;
	font-weight: 500;
	margin-bottom: 22px;
}

.razzi-slide-description {
	font-size: 18px;
	margin-bottom: 37px;
}

.razzi-slide-button {
	margin: -15px;
}

.razzi-slide-button > * {
	display: inline-block;
	margin: 15px;
}

.razzi-slides-elementor--arrow-style-2 .rz-swiper-button {
	right: 40px;
	top: auto;
	bottom: 20px;
}

.razzi-slides-elementor--arrow-style-2 .rz-swiper-button-next {
	right: 105px;
	left: auto;
}

.razzi-slides-elementor--arrow-style-3 .rz-swiper-button {
	top: auto;
	bottom: 0;
	right: auto;
	left: 0;
	transform: none;
}

.razzi-slides-elementor--arrow-style-3 .rz-swiper-button-prev {
	left: 50px;
}

.razzi--v-position-top .slick-slide-inner {
	align-items: flex-start;
}

.razzi--v-position-bottom .slick-slide-inner {
	align-items: flex-end;
}

.razzi--v-position-middle .slick-slide-inner {
	align-items: center;
}

.razzi--h-position-left .slick-slide-inner {
	justify-content: flex-start;
}

.razzi--h-position-right .slick-slide-inner {
	justify-content: flex-end;
}

.razzi--h-position-center .slick-slide-inner {
	justify-content: center;
}

.razzi-products-carousel__centeredslides-yes .swiper-slide {
	max-width: 770px;
}

.razzi-products-carousel__centeredslides-yes .slick-slide-inner {
	width: 100%;
}

.razzi-products-carousel__centeredslides-yes .razzi-slide-content {
	padding: 70px;
}

.razzi-isolate-slides .slick-slide-inner {
	display: flex;
	height: 100%;
}

.razzi-isolate-slides .swiper-pagination {
	position: absolute;
	left: 25px;
	top: 50%;
	transform: translateY(-50%);
	display: flex;
	flex-direction: column;
	width: auto;
	margin: 0;
}

.razzi-isolate-slides .swiper-pagination .swiper-pagination-bullet:not(.swiper-pagination-bullet-active):before {
	background-color: rgba(31, 31, 31, 0.4);
}

.razzi-isolate-slides__wrapper {
	flex: 1 1 43.8%;
	color: var(--rz-color-dark);
	text-align: center;
	position: relative;
	display: flex;
	align-items: center;
	justify-content: space-between;
	align-items: center;
	height: 100%;
}

.razzi-isolate-slides__wrapper:before {
	content: '';
	position: absolute;
	top: 30px;
	right: 30px;
	width: calc( 100% - 60px);
	height: calc( 100% - 60px);
	background-color: var(--rz-background-color-light);
}

.razzi-isolate-slides__image {
	flex: 1 1 56.2%;
	height: 100%;
}

.razzi-isolate-slides__content {
	position: relative;
	width: 100%;
	padding: 30px;
}

.razzi-isolate-slides__before-title {
	font-weight: 600;
	font-size: 44px;
	line-height: 65px;
	text-transform: uppercase;
	margin-bottom: 20px;
}

.razzi-isolate-slides__title {
	font-weight: 600;
	font-size: 110px;
	line-height: 102px;
	text-transform: uppercase;
}

.razzi-isolate-slides__title.has-background {
	-webkit-background-clip: text;
	background-clip: text;
	color: transparent;
}

.razzi-isolate-slides__after-title {
	font-weight: 500;
	font-size: 24px;
	line-height: 35px;
	margin-bottom: 15px;
}

.razzi-isolate-slides__description {
	font-size: 15px;
	line-height: 22px;
}

.razzi-isolate-slides__description p {
	margin: 0;
}

.razzi-isolate-slides__button {
	margin-top: 37px;
}

.razzi-isolate-slides__button .button-text {
	padding: 0 44px;
	line-height: 52px;
}

.razzi-posts-carousel {
	opacity: 0;
}

.razzi-posts-carousel .list-posts {
	position: relative;
}

.razzi-posts-carousel .list-posts__inner {
	display: flex;
}

.razzi-posts-carousel .blog-wrapper {
	box-shadow: 0 0 4px rgba(0, 0, 0, 0.02);
	margin-bottom: 0;
	height: auto;
	background-color: #fff;
}

.razzi-posts-carousel .post-thumbnail img {
	display: block;
}

.razzi-posts-carousel .post-summary {
	padding: 25px 40px 37px;
}

.razzi-posts-carousel .post-summary .post-meta {
	font-size: 14px;
	margin-bottom: 10px;
	color: #767676;
}

.razzi-posts-carousel .post-summary .post-meta a {
	color: #767676;
}

.razzi-posts-carousel .post-summary .post-meta a:hover {
	color: #111;
}

.razzi-posts-carousel .post-summary .post-title {
	margin: 0;
	font-size: 20px;
}

.razzi-posts-carousel .post-button {
	display: flex;
	justify-content: center;
	margin-top: 77px;
	text-decoration: none;
}

.razzi-posts-carousel .swiper-pagination {
	position: relative;
	margin-top: 30px;
}

.razzi-posts-carousel .rz-swiper-button {
	top: calc(50% - 75px);
}

.razzi-posts-carousel__heading {
	text-align: center;
	margin-bottom: 66px;
}

.razzi-posts-carousel__heading .heading-subtitle {
	font-size: 13px;
	font-weight: 500;
	text-transform: uppercase;
	color: #909090;
	display: block;
	margin-bottom: 9px;
}

.razzi-posts-carousel__heading .heading-title {
	font-size: 36px;
	margin: 0;
}

.razzi-posts-carousel-2__heading {
	display: flex;
	justify-content: space-between;
	align-items: center;
	margin-bottom: 67px;
}

.razzi-posts-carousel-2__heading .heading-title {
	font-size: 36px;
	padding-left: 25px;
	margin: 0;
}

.razzi-posts-carousel-2 {
	opacity: 0;
}

.razzi-posts-carousel-2 .list-posts__inner {
	display: flex;
}

.razzi-posts-carousel-2 .blog-wrapper {
	margin-bottom: 0;
}

.razzi-posts-carousel-2 .entry-header {
	margin-bottom: 21px;
}

.razzi-posts-carousel-2 .entry-title {
	margin-bottom: 10px;
}

.razzi-posts-carousel-2 a.post-thumbnail {
	display: flex;
}

.razzi-posts-carousel-2 .rz-swiper-button {
	top: calc(50% - 90px);
}

.razzi-posts-carousel-2 .swiper-pagination {
	position: relative;
	margin-top: 30px;
}

.razzi-banner-collection {
	position: relative;
}

.razzi-banner-collection:hover .razzi-banner-clt__content-inner {
	box-shadow: 0px 10px 20px rgba(0, 0, 0, 0.02);
}

.razzi-banner-clt__content {
	position: absolute;
	bottom: 50%;
	transform: translateY(50%);
	right: 0;
	left: 0;
	display: flex;
	justify-content: center;
	z-index: 1;
}

.razzi-banner-clt__content-title {
	font-size: 28px;
	margin: 0 0 12px;
}

.razzi-banner-clt__content-desc {
	font-size: 15px;
	color: var(--rz-color-dark);
	padding-bottom: 8px;
}

.razzi-banner-clt__content-inner {
	padding: 32px 71px 0;
	background-color: #fff;
	text-align: center;
	max-width: 425px;
	transition: 0.35s;
}

.razzi-banner-clt__content-button {
	transform: translateY(25px);
	padding: 0 34px;
}

.razzi-banner-clt__images {
	display: flex;
	flex-wrap: wrap;
}

.razzi-banner-clt__images img {
	display: block;
}

.razzi-banner-clt__images-item {
	position: relative;
}

.razzi-banner-clt__images-item:before {
	content: '';
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
	background-color: transparent;
	z-index: 1;
}

.razzi-banner-clt-link {
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	bottom: 0;
	z-index: 2;
}

.razzi-popular-keywords {
	text-align: center;
	padding: 90px 0 110px;
}

.razzi-popular-keywords .heading-title {
	font-size: 60px;
	line-height: 1.33333;
	margin: 0 0 66px;
}

.razzi-popular-keywords__inner {
	margin: -15px;
}

.razzi-popular-keywords__inner .button-link {
	display: inline-block;
	padding: 15px;
}

.razzi-popular-keywords__inner .button-text {
	padding: 13px 15px;
	line-height: 1.5;
	min-width: 190px;
	border-width: 2px;
}

.razzi-popular-keywords__inner .button-text:hover {
	border-color: #ffffff;
	background-color: #ffffff;
	color: #111111;
}

.razzi-image-content-box__bg {
	height: 100%;
}

.elementor-section-full_width .elementor-widget-razzi-image-content-box {
	overflow: hidden;
}

.elementor-section-full_width .elementor-widget-razzi-image-content-box .razzi-image-content-box__bg {
	width: 55vw;
}

.razzi-image-content-box__content {
	padding: 112px 0 112px 105px;
}

.razzi-image-content-box__content .subtitle {
	color: #909090;
	font-size: 13px;
	font-weight: 500;
	text-transform: uppercase;
	margin-bottom: 9px;
}

.razzi-image-content-box__content .banner-title {
	font-size: 44px;
	margin: 0 0 26px;
}

.razzi-image-content-box__content .banner-desc {
	font-size: 18px;
	margin-bottom: 42px;
}

.razzi-image-content-box__content .button-text {
	line-height: 54px;
	padding: 0 43px;
}

.elementor-widget-razzi-image-content-box .elementor-widget-container {
	background-color: #F5F5F5;
}

.razzi-image-position-left .razzi-image-content-box__left {
	order: 2;
}

.razzi-image-position-left .razzi-image-content-box__right {
	order: 1;
}

.razzi-image-position-left .razzi-image-content-box__bg {
	position: absolute;
	right: 0;
}

.razzi-banner-video {
	position: relative;
}

.razzi-banner-video .full-box-button,
.razzi-banner-video .banner-featured-image {
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
}

.razzi-banner-video .full-box-button {
	z-index: 1;
}

.razzi-banner-video__marker .razzi-icon,
.razzi-banner-video__marker {
	position: absolute;
	top: 50%;
	right: 50%;
	transform: translate(50%, -50%);
}

.razzi-banner-video__marker:after {
	content: '';
	display: block;
	width: 68px;
	height: 68px;
	border-radius: 50%;
	background-color: #fff;
}

.razzi-banner-video__marker .razzi-icon {
	line-height: 1;
	color: #000;
	font-size: 24px;
}

.razzi-promo-box {
	position: relative;
}

.razzi-promo-box:hover .razzi-icon {
	transform: translateX(-3px);
                transform: translateX(-3px) rotateY(180deg);
}

.razzi-promo-box:hover .image-zoom img {
	transform: scale(1.05);
	-ms-transform: scale(1.05);
	/* IE 9 */
	-moz-transform: scale(1.05);
	/* Firefox */
	-webkit-transform: scale(1.05);
	/* Safari and Chrome */
	-o-transform: scale(1.05);
	/* Opera */
}

.razzi-promo-box:hover .razzi-promo-box__image:after {
	background-color: rgba(0, 0, 0, 0.15);
}

.razzi-promo-box__link {
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	bottom: 0;
	z-index: 2;
}

.razzi-promo-box__content {
	position: absolute;
	z-index: 1;
	display: flex;
	flex-direction: column;
	align-items: center;
	padding: 30px;
	background-color: #ffffff;
}

.razzi-promo-box__title {
	margin: 0 0 13px;
	font-size: 28px;
}

.razzi-promo-box__image {
	position: relative;
}

.razzi-promo-box__image img {
	display: block;
}

.razzi-promo-box__image:after {
	content: '';
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
	display: block;
	transition: ease .3s;
	background-color: rgba(0, 0, 0, 0);
}

.razzi-promo-box__image + .razzi-promo-box__content {
	bottom: -65px;
}

.razzi-promo-box__sale {
	position: absolute;
	top: 20px;
	width: 96px;
	height: 96px;
	border-radius: 50%;
	background-color: var(--rz-background-color-primary);
	display: flex;
	flex-direction: column;
	align-items: center;
	justify-content: center;
	color: #ffffff;
	font-weight: 500;
	font-size: 28px;
	z-index: 1;
}

.razzi-promo-box__sale .sale-price {
	font-size: 20px;
	font-weight: 600;
	line-height: 1;
}

.razzi-promo-box__sale .regular-price {
	font-size: 14px;
	font-weight: 600;
	margin-bottom: 8px;
	line-height: 1;
	text-decoration: line-through;
}

.razzi-promo-box__price-position--right .razzi-promo-box__sale {
	left: 20px;
}

.razzi-promo-box__price-position--left .razzi-promo-box__sale {
	right: 20px;
}

.razzi-promo-box__content-position--left .razzi-promo-box__content {
	top: 105px;
	bottom: 105px;
	right: -142px;
	justify-content: center;
}

.razzi-promo-box__content-position--left .razzi-promo-box {
	margin-right: 142px;
}

.razzi-promo-box__content-position--right .razzi-promo-box__content {
	top: 105px;
	bottom: 105px;
	left: -142px;
	justify-content: center;
}

.razzi-promo-box__content-position--right .razzi-promo-box {
	margin-left: 142px;
}

.razzi-promo-box__content-position--bottom .razzi-promo-box__content {
	right: 75px;
	left: 75px;
}

.razzi-promo-box__description {
	margin: 0 0 13px;
	font-size: 18px;
}

.razzi-image-box {
	text-align: center;
	box-shadow: 0px 4px 4px rgba(0, 0, 0, 0.02);
	transition: 0.3s;
}

.razzi-image-box:hover {
	transition: 0.3s;
}

.razzi-image-box:hover.transition-y {
	transform: translateY(-3px);
}

.razzi-image-box .box-thumbnail {
	position: relative;
	line-height: 0;
	display: table;
	margin: auto;
}

.razzi-image-box .box-thumbnail .box-number {
	position: absolute;
	display: flex;
	flex-direction: column;
	justify-content: center;
	top: -9px;
	left: 9px;
	min-height: 34px;
	min-width: 34px;
	border-radius: 50%;
	color: #fff;
	background-color: var(--rz-background-color-primary);
}

.razzi-image-box .box-title {
	margin: 0;
	display: flex;
	align-items: center;
	justify-content: center;
}

.razzi-image-box .box-summary {
	padding: 14px 5px;
}

.razzi-image-box .razzi-icon {
	margin-left: 16px;
	font-size: 33px;
}

.razzi-image-box__button-link {
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	bottom: 0;
	z-index: 2;
}

.razzi-image-box-position--left .razzi-image-box {
	display: flex;
	align-items: center;
}

.razzi-image-box-position--left .box-title {
	justify-content: space-between;
	display: flex;
	align-items: center;
}

.razzi-image-box-position--left .box-title .razzi-icon {
	order: 2;
	margin-left: 0;
}

.razzi-image-box-position--left .box-thumbnail {
	margin-left: 30px;
	max-width: 84px;
}

.razzi-image-box-position--left .box-summary {
	flex: 1;
	width: 100%;
	padding: 0;
}

.razzi-image-box__icon-position--right .box-title {
	display: flex;
	align-items: center;
}

.razzi-image-box__icon-position--right .box-title .razzi-icon {
	order: 2;
	margin-left: 0;
	margin-right: 16px;
}

.razzi-image-button {
	position: relative;
}

.razzi-image-button img {
	display: block;
}

.razzi-image-button:hover .razzi-svg-icon {
	transform: translateX(-3px);
            transform: translateX(-3px) rotateY(180deg);
}

.razzi-image-button:hover:before {
	background-color: rgba(0, 0, 0, 0.15);
}

.razzi-image-button:before {
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
	content: '';
	display: block;
	transition: ease .3s;
	background-color: rgba(0, 0, 0, 0.05);
}

.razzi-image-button__link {
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
}

.razzi-image-button__button {
	display: flex;
	justify-content: center;
	text-decoration: none;
	white-space: nowrap;
	text-overflow: ellipsis;
	overflow: hidden;
	color: #111111;
	background-color: #ffffff;
	line-height: 54px;
	padding: 0 26px;
	max-width: 100%;
	min-width: 190px;
	font-weight: 500;
}

.razzi-image-button__button .razzi-svg-icon {
	font-size: 13px;
	margin-right: 13px;
	display: inline-block;
	transition: 0.5s;
			transform: rotateY(180deg);
}

.razzi-image-button__position {
	position: absolute;
	top: 50%;
	right: 50%;
	transform: translate(50%, -50%);
}

.razzi-image-button__text {
	font-size: 28px;
	font-weight: 500;
	line-height: 38px;
	text-align: center;
	color: var(--rz-color-dark);
	margin-bottom: 15px;
}

.btn-position-bottom .razzi-image-button:before {
	bottom: 54px;
	height: auto;
}

.btn-position-bottom .razzi-image-button__position {
	position: static;
	transform: none;
}

.razzi-product-banner {
	position: relative;
	display: inline-flex;
}

.razzi-product-banner .full-box-button {
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	bottom: 0;
	z-index: 2;
}

.razzi-product-banner.has-hover:hover .razzi-icon {
	transform: translateX(-3px);
                transform: translateX(-3px) rotateY(180deg);
}

.razzi-product-banner .banner-image {
	position: relative;
	flex: none;
	max-width: 80%;
}

.razzi-product-banner .banner-content__sale {
	position: absolute;
	right: 0;
	top: 0;
}

.razzi-product-banner .banner-content__sale > *:not(:last-child) {
	margin-bottom: 8px;
}

.razzi-product-banner .banner-price {
	display: flex;
	align-items: center;
	padding: 12px 21px;
	background-color: #fff;
	color: var(--rz-color-dark);
	font-size: 18px;
	font-weight: 500;
}

.razzi-product-banner .sale-price {
	order: 2;
	color: var(--rz-color-primary);
}

.razzi-product-banner .sale-price + .regular-price {
	font-size: 14px;
	text-decoration: line-through;
	color: #909090;
	margin-left: 5px;
}

.razzi-product-banner .regular-price {
	order: 1;
}

.razzi-product-banner .product-badges {
	display: inline-block;
	font-size: 11px;
	font-weight: 500;
	text-transform: uppercase;
	padding: 3px 11px;
	color: #fff;
	background-color: var(--rz-background-color-dark);
}

.razzi-product-banner .banner-content {
	display: flex;
	flex-direction: column;
	justify-content: center;
	transform: translateX(36px);
}

.razzi-product-banner .banner-title {
	font-size: 36px;
	margin: 0 0 27px;
	line-height: 1.33333;
}

.razzi-product-banner .razzi-icon {
	font-size: 13px;
	margin-right: 13px;
}

.content-position-bottom .razzi-product-banner {
	display: block;
}

.content-position-bottom .razzi-product-banner .banner-content {
	margin-top: 15px;
	transform: none;
}

.razzi-lookbook-slider-elementor {
	opacity: 0;
}

.razzi-lookbook-slider-elementor .slick-slide-inner {
	position: absolute;
	right: 0;
	left: 0;
	height: 100%;
	display: flex;
	align-items: center;
	z-index: 1;
}

.razzi-lookbook-slider-elementor .slick-slide-block {
	height: 100%;
	margin: 0;
}

.razzi-lookbook-slider-elementor .slick-slide-block > * {
	padding: 0;
}

.razzi-lookbook-slider-elementor .slick-slide-block__img {
	position: relative;
}

.razzi-lookbook-slider-elementor .razzi-slide-heading {
	font-size: 60px;
	line-height: 1.33333;
	margin-bottom: 42px;
}

.razzi-lookbook-slider-elementor .button-text {
	line-height: 1.3;
	padding: 17px 42px;
}

.razzi-lookbook-slider-elementor .button-text .razzi-svg-icon {
	margin-right: 14px;
}

.razzi-lookbook-slider-elementor .rz-swiper-button {
	font-size: 20px;
	color: var(--rz-color-dark);
	background-color: #ffffff;
	line-height: 43px;
}

.razzi-lookbook-slider-elementor .rz-swiper-button:hover:not(.swiper-button-disabled) {
	color: var(--rz-color-dark);
	opacity: 1;
}

.razzi-lookbook-slider-elementor .rz-swiper-button-prev {
	right: 0;
}

.razzi-lookbook-slider-elementor .rz-swiper-button-next {
	left: 0;
}

.razzi-lookbook-slider-elementor .product-item {
	display: inline-block;
	padding: 10px;
	background-color: #ffffff;
	text-align: center;
	position: absolute;
	width: 220px;
	right: 30px;
	top: 0;
	opacity: 0;
	pointer-events: none;
	transition: .3s;
}

.razzi-lookbook-slider-elementor .product-item .product-image img {
	display: block;
}

.razzi-lookbook-slider-elementor .product-item .product-name {
	margin: 0 0 5px;
}

.razzi-lookbook-slider-elementor .product-item .product-price {
	font-size: 15px;
	font-weight: 600;
	color: #767676;
}

.razzi-lookbook-slider-elementor .product-item .product-price ins {
	background-color: transparent;
	color: var(--rz-color-primary);
	padding-right: 5px;
}

.razzi-lookbook-slider-elementor .product-item .product-summary {
	padding: 18px 0 8px;
}

.razzi-lookbook-slider-elementor .product-item .razzi-slide-button {
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
}

.razzi-lookbook-slider-elementor .slick-slide-block__blank {
	background-color: #fff;
}

.razzi-lookbook-slider-elementor .razzi-lookbook-item {
	position: absolute;
	top: 40%;
	right: 40%;
	cursor: pointer;
	z-index: 2;
	--rz-lookbook-color-primary: #ffffff;
}

.razzi-lookbook-slider-elementor .razzi-lookbook-item:after {
	content: '';
	display: block;
	width: 16.8px;
	height: 16.8px;
	background-color: var(--rz-lookbook-color-primary);
	border-radius: 50%;
}

.razzi-lookbook-slider-elementor .razzi-lookbook-item:before {
	content: '';
	display: block;
	width: 42px;
	height: 42px;
	background-color: var(--rz-lookbook-color-primary);
	opacity: .15;
	border-radius: 50%;
	position: absolute;
	right: calc(-50% - 4.4px);
	top: calc(-50% - 4.4px);
	animation: anim-ripple 1.5s linear 0s infinite;
}

.razzi-lookbook-slider-elementor .razzi-lookbook-item.active .product-item {
	opacity: 1;
	z-index: 1;
	pointer-events: all;
}

.razzi-lookbook-slider-elementor .full-box-button {
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
}

@media (min-width: 768px) {
	.elementor-widget-razzi-lookbook-slider:not(.razzi-lookbook-slider-nav-position-both) .razzi-lookbook-slider-elementor .rz-swiper-button {
		top: inherit;
		bottom: 0;
		transform: none;
	}
	.elementor-widget-razzi-lookbook-slider:not(.razzi-lookbook-slider-nav-position-both) .razzi-lookbook-slider-elementor .rz-swiper-button-next {
		left: inherit;
		right: 42px;
	}
}

.razzi-lookbook-banner .product-item {
	display: inline-flex;
	align-items: center;
	padding: 10px;
	background-color: #ffffff;
	position: absolute;
	width: 290px;
	right: -49px;
	top: 22px;
	opacity: 0;
	pointer-events: none;
	transition: .3s;
	box-shadow: 0px 0px 20px rgba(0, 0, 0, 0.06);
}

.razzi-lookbook-banner .product-item .product-image {
	margin-left: 24px;
}

.razzi-lookbook-banner .product-item .product-image img {
	display: block;
	max-width: 100px;
}

.razzi-lookbook-banner .product-item .product-name {
	margin: 0 0 5px;
}

.razzi-lookbook-banner .product-item .product-price {
	font-size: 15px;
	font-weight: 600;
	color: #767676;
}

.razzi-lookbook-banner .product-item .product-price ins {
	background-color: transparent;
	color: var(--rz-color-primary);
	padding-right: 5px;
}

.razzi-lookbook-banner .product-item .razzi-slide-button {
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
}

.razzi-lookbook-banner .razzi-lookbook-item {
	position: absolute;
	top: 40%;
	right: 40%;
	cursor: pointer;
	z-index: 2;
	--rz-lookbook-color-primary: #ffffff;
}

.razzi-lookbook-banner .razzi-lookbook-item:after {
	content: '';
	display: block;
	width: 16.8px;
	height: 16.8px;
	background-color: var(--rz-lookbook-color-primary);
	border-radius: 50%;
}

.razzi-lookbook-banner .razzi-lookbook-item:before {
	content: '';
	display: block;
	width: 42px;
	height: 42px;
	background-color: var(--rz-lookbook-color-primary);
	opacity: .15;
	border-radius: 50%;
	position: absolute;
	right: calc(-50% - 4.4px);
	top: calc(-50% - 4.4px);
	animation: anim-ripple 1.5s linear 0s infinite;
}

.razzi-lookbook-banner .razzi-lookbook-item.active .product-item {
	opacity: 1;
	z-index: 1;
	pointer-events: all;
}

.razzi-featured-content {
	overflow: hidden;
}

.razzi-featured-content .box-thumbnail img {
	display: inline-block;
}

.razzi-featured-content .featured-title {
	margin: 0 0 16px;
}

.razzi-featured-content .featured-box {
	position: relative;
}

.razzi-featured-content .featured-control {
	position: absolute;
	top: 15px;
	display: block;
	width: 100px;
	height: 1px;
	background-color: var(--rz-background-color-primary);
}

.razzi-featured-content .featured-control:after {
	content: '';
	display: inline-block;
	transform: translateY(-11px);
	height: 11px;
	width: 11px;
	background-color: var(--rz-background-color-primary);
	border-radius: 50%;
}

.razzi-featured-content .featured-wrapper__left .featured-control {
	right: calc(100% + 30px);
}

.razzi-featured-content .featured-wrapper__right .featured-control {
	left: calc(100% + 30px);
}

.razzi-featured-content .featured-img-wrapper {
	width: 100%;
}

.razzi-before-after-images {
	padding: 0 100px;
	opacity: 0;
}

.razzi-before-after-images .imageslide-handle {
	display: flex;
	align-items: center;
	justify-content: center;
	z-index: 999999;
}

.razzi-before-after-images .razzi-icon {
	font-size: 21px;
}

.razzi-before-after-images .rz-swiper-button {
	font-size: 24px;
	color: #cdcdcd;
	background-color: transparent;
}

.razzi-pricing-table {
	background-color: #f5f5f5;
	margin: auto;
	box-shadow: 0px 4px 4px rgba(0, 0, 0, 0.02);
}

.razzi-pricing-table__header {
	text-align: center;
	padding: 29px 30px 31px;
	border-bottom: 1px solid #e2e2e2;
	position: relative;
}

.razzi-pricing-table__header .pricing-title {
	font-size: 28px;
	margin: 0 0 15px;
}

.razzi-pricing-table__header .pricing-badges {
	font-size: 11px;
	font-weight: 500;
	letter-spacing: 0.2px;
	text-transform: uppercase;
	padding: 3px 11px;
	background-color: var(--rz-background-color-primary);
	color: #fff;
	position: absolute;
	top: 20px;
	right: 0;
}

.razzi-pricing-table__header .pricing-price {
	font-size: 36px;
	font-weight: 600;
	line-height: 1;
}

.razzi-pricing-table__header .pricing-afprice {
	font-size: 18px;
	font-weight: 500;
}

.razzi-pricing-table__header .pricing-header__price {
	display: inline-flex;
	align-items: flex-end;
	color: #111111;
}

.razzi-pricing-table__content {
	padding: 36px 43px 51px;
}

.razzi-pricing-table__content .pricing-desc {
	margin-bottom: 43px;
}

.razzi-pricing-table__content .pricing-desc p {
	margin-top: 0;
}

.razzi-pricing-table__content .pricing-desc > *:not(:last-child) {
	margin-bottom: 24px;
}

.razzi-pricing-table__content .button-link {
	display: block;
	text-align: center;
}

.razzi-pricing-table__content .button-text {
	line-height: 1.5;
	padding: 11px 34px;
	font-size: 15px;
}

.razzi-pricing-table__content .button-text:hover {
	background-color: var(--rz-background-color-primary);
	color: #ffffff;
}

.razzi-testimonials-grid .heading-title {
	font-size: 36px;
	line-height: 1.33333;
	margin: 0 0 76px;
	text-align: center;
}

.razzi-testimonials-grid .testimonials-wrapper {
	margin: 0 -15px;
}

.razzi-testimonials-grid .testimonial-item {
	padding: 0 15px 30px;
}

.razzi-testimonials-grid .testimonial-item__inner {
	margin-top: 50px;
	padding: 84px 37px 34px;
	position: relative;
	background-color: #f5f5f5;
	text-align: center;
}

.razzi-testimonials-grid .testimonial-item__inner .testi-image {
	position: absolute;
	top: -50px;
	right: 0;
	left: 0;
	max-width: 100px;
	margin: auto;
}

.razzi-testimonials-grid .testimonial-item__inner .testi-desc {
	font-size: 18px;
	color: #111111;
	margin-bottom: 27px;
}

.razzi-testimonials-grid .testimonial-item__inner .testi-rate {
	margin-bottom: 2px;
}

.razzi-testimonials-grid .testimonial-item__inner .testi-meta {
	font-size: 14px;
}

.razzi-testimonials-grid .razzi-svg-icon {
	font-size: 14px;
	color: #cdcdcd;
}

.razzi-testimonials-grid .razzi-svg-icon.rate-active {
	color: #F8B86D;
}

.razzi-testimonials-grid .testi-button {
	display: flex;
	justify-content: center;
	padding-top: 46px;
	text-decoration: none;
	clear: both;
}

.razzi-icons-box-carousel__wrapper {
	border-style: solid;
	border-width: 0 1px 0 0;
	border-color: var(--rz-icons-box-border-color);
}

.razzi-icons-box-carousel__wrapper:not(.swiper-container-initialized) .icon-box {
	width: 14.2%;
}

.razzi-icons-box-carousel {
	--rz-icons-box-border-color: #303030;
}

.razzi-icons-box-carousel .razzi-icon {
	font-size: 48px;
	margin-bottom: 8px;
}

.razzi-icons-box-carousel .razzi-img-icon {
	margin-bottom: 8px;
	display: inline-flex;
	width: 45px;
	height: 45px;
}

.razzi-icons-box-carousel .razzi-img-icon img {
	display: block;
}

.razzi-icons-box-carousel .icon-box {
	position: relative;
	text-align: center;
	border-style: solid;
	border-width: 0 0 0 1px;
	border-color: var(--rz-icons-box-border-color);
	padding: 25px 20px 24px;
	height: auto;
	transition: 0.3s;
}

.razzi-icons-box-carousel .icon-box__btn {
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
}

.razzi-icons-box-carousel .icon-box__title {
	margin: 0;
}

.razzi-icons-box-carousel .rz-swiper-button {
	background-color: transparent;
	color: #767676;
	width: 50px;
	height: 50px;
	line-height: 50px;
	font-size: 28px;
}

.razzi-icons-box-carousel .rz-swiper-button-prev {
	right: -80px;
}

.razzi-icons-box-carousel .rz-swiper-button-next {
	left: -80px;
}

.razzi-icons-box-carousel .swiper-pagination {
	position: absolute;
	width: 100%;
	margin-top: 0;
	bottom: -40px;
}

.elementor-widget-razzi-images-box-carousel-2.hover-image-on .image-item:hover .content-img img {
	transform: translateY(-6px);
}

.razzi-images-box-carousel-2 {
	margin-right: -15px;
	margin-left: -15px;
}

.razzi-images-box-carousel-2 .swiper-container {
	padding-top: 50px;
	margin-top: -50px;
}

.razzi-images-box-carousel-2 .content-summary {
	color: #111;
	padding: 103px 56px 44px 56px;
	border: 1px solid #E2E2E2;
	height: 100%;
}

.razzi-images-box-carousel-2 .content-img {
	position: absolute;
	right: 50%;
	top: 0;
	transform: translateX(50%);
}

.razzi-images-box-carousel-2 .content-img img {
	display: block;
	transition: transform 0.3s;
}

.razzi-images-box-carousel-2 .content-title {
	font-size: 20px;
}

.razzi-images-box-carousel-2 .content-desc {
	color: #555;
	font-size: 16px;
	padding-top: 16px;
}

.razzi-images-box-carousel-2 .content-text {
	background-color: var(--rz-background-color-primary);
	align-items: center;
	justify-content: center;
	width: 100px;
	height: 100px;
	max-width: 100%;
	color: #111;
	display: inline-flex;
	border-radius: 50%;
}

.razzi-images-box-carousel-2 .image-item {
	text-align: center;
	height: auto;
	padding: 70px 15px 0;
}

.razzi-images-box-carousel-2 .full-box-button {
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
}

/*! elementor - v3.4.5 - 12-10-2021 */
@media (min-width: 768px) {
	.elementor-widget-razzi-icon-box.elementor-position-left .razzi-icon-box,
	.elementor-widget-razzi-icon-box.elementor-position-right .razzi-icon-box {
		display: -webkit-box;
		display: -ms-flexbox;
		display: flex;
	}
	.elementor-widget-razzi-icon-box.elementor-position-left .razzi-icon-box__icon,
	.elementor-widget-razzi-icon-box.elementor-position-right .razzi-icon-box__icon {
		display: -webkit-inline-box;
		display: -ms-inline-flexbox;
		display: inline-flex;
		-webkit-box-flex: 0;
		-ms-flex: 0 0 auto;
		flex: 0 0 auto;
	}
	.elementor-widget-razzi-icon-box.elementor-position-right .razzi-icon-box {
		text-align: left;
		-webkit-box-orient: horizontal;
		-webkit-box-direction: reverse;
		-ms-flex-direction: row-reverse;
		flex-direction: row-reverse;
	}
	.elementor-widget-razzi-icon-box.elementor-position-left .razzi-icon-box {
		text-align: right;
		-webkit-box-orient: horizontal;
		-webkit-box-direction: normal;
		-ms-flex-direction: row;
		flex-direction: row;
	}
	.elementor-widget-razzi-icon-box.elementor-vertical-align-top .razzi-icon-box {
		-webkit-box-align: start;
		-ms-flex-align: start;
		align-items: flex-start;
	}
	.elementor-widget-razzi-icon-box.elementor-vertical-align-middle .razzi-icon-box {
		-webkit-box-align: center;
		-ms-flex-align: center;
		align-items: center;
	}
	.elementor-widget-razzi-icon-box.elementor-vertical-align-bottom .razzi-icon-box {
		-webkit-box-align: end;
		-ms-flex-align: end;
		align-items: flex-end;
	}
}

@media (max-width: 767px) {
	.elementor-widget-razzi-icon-box .razzi-icon-box__icon {
		margin-right: auto !important;
		margin-left: auto !important;
		margin-bottom: 15px;
	}
}

.razzi-icon-box {
	text-align: center;
}

.razzi-icon-box .razzi-img-icon {
	display: inline-flex;
}

.razzi-icon-box .razzi-img-icon img {
	display: block;
}

.razzi-icon-box__title a {
	color: inherit;
}

.razzi-icon-box__content {
	-webkit-box-flex: 1;
	-ms-flex-positive: 1;
	flex-grow: 1;
}

.razzi-icon-box__description {
	margin: 0;
}

.razzi-category-box {
	background-color: #fff;
	display: flex;
	box-shadow: 0px 4px 4px rgba(0, 0, 0, 0.02);
}

.razzi-category-box__img {
	max-width: 47%;
}

.razzi-category-box__img img {
	display: block;
}

.razzi-category-box__content {
	padding: 44px 50px 30px;
}

.razzi-category-box__content a {
	color: inherit;
}

.razzi-category-box__content .category-title {
	margin: 0 0 21px;
}

.razzi-category-box__content .sub-cats {
	list-style: none;
	padding: 0;
	margin: 0;
	line-height: 1.48;
}

.razzi-category-box__content .sub-cats li:not(:last-child) {
	margin-bottom: 10px;
}

.razzi-category-box__content .sub-cats .razzi-icon {
	font-size: 11px;
	opacity: 0;
	padding-right: 0;
	transition: .3s;
}

.razzi-category-box__content .sub-cats li:hover .razzi-icon {
	padding-right: 8px;
	opacity: 1;
}

.razzi-position-next-image .razzi-category-box {
	align-items: center;
}

.elementor-widget-razzi-products-recently-viewed-carousel.elementor-widget-empty {
	background-color: transparent;
}

.elementor-widget-razzi-products-recently-viewed-carousel.elementor-widget-empty .elementor-widget-empty-icon {
	display: none;
}

.razzi-products-recently-viewed-carousel {
	margin: 0 -15px 0;
}

.razzi-products-recently-viewed-carousel .swiper-container {
	padding: 0 15px;
}

.razzi-products-recently-viewed-carousel.no-ajax {
	opacity: 0;
}

.razzi-products-recently-viewed-carousel .products-content {
	min-height: 40px;
	z-index: 100;
}

.razzi-products-recently-viewed-carousel .products-content.swiper-container-initialized {
	z-index: 1;
}

.razzi-products-recently-viewed-carousel.has-ajax .swiper-scrollbar {
	opacity: 0;
}

.razzi-products-recently-viewed-carousel.has-ajax.loaded .swiper-scrollbar {
	opacity: 1;
}

.razzi-products-recently-viewed-carousel .rz-swiper-button-next {
	left: 15px;
}

.razzi-products-recently-viewed-carousel .rz-swiper-button-prev {
	right: 15px;
}

.razzi-products-recently-viewed-grid .product-list .product-thumbnail {
	font-size: 0;
}

.razzi-products-recently-viewed-grid .products-tool {
	display: flex;
	justify-content: space-between;
	align-items: center;
	margin-bottom: 35px;
}

.razzi-products-recently-viewed-grid .products-tool .posts-found {
	padding-left: 25px;
}

.razzi-products-recently-viewed-grid .products-tool .count {
	color: var(--rz-color-primary);
}

.razzi-products-recently-viewed-grid .products-tool .reset-button {
	font-weight: 500;
}

.razzi-products-recently-viewed-grid .products-tool .reset-button:before {
	display: inline-block;
	line-height: 1;
	vertical-align: middle;
	margin-left: 7px;
	margin-top: -3px;
	width: 16px;
	height: 16px;
	content: '';
	background-image: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB3aWR0aD0iMTZwdCIgaGVpZ2h0PSIxNnB0IiB2aWV3Qm94PSIwIDAgMTYgMTYiIHZlcnNpb249IjEuMSI+CjxnIGlkPSJzdXJmYWNlMSI+CjxwYXRoIHN0eWxlPSIgc3Ryb2tlOm5vbmU7ZmlsbC1ydWxlOm5vbnplcm87ZmlsbDpyZ2IoMCUsMCUsMCUpO2ZpbGwtb3BhY2l0eToxOyIgZD0iTSA4IDAuMTYwMTU2IEwgOCA2LjQzMzU5NCBMIDExLjEzNjcxOSAzLjI5Njg3NSBaIE0gOCAwLjE2MDE1NiAiLz4KPHBhdGggc3R5bGU9IiBzdHJva2U6bm9uZTtmaWxsLXJ1bGU6bm9uemVybztmaWxsOnJnYigwJSwwJSwwJSk7ZmlsbC1vcGFjaXR5OjE7IiBkPSJNIDggMTUuODM5ODQ0IEMgNC4zMzk4NDQgMTUuODM5ODQ0IDEuMzYzMjgxIDEyLjg1OTM3NSAxLjM2MzI4MSA5LjIwMzEyNSBDIDEuMzYzMjgxIDUuNTQyOTY5IDQuMzM5ODQ0IDIuNTYyNSA4IDIuNTYyNSBMIDggNC4wMjczNDQgQyA1LjE3NTc4MSA0LjAyNzM0NCAyLjgyNDIxOSA2LjMyODEyNSAyLjgyNDIxOSA5LjIwMzEyNSBDIDIuODI0MjE5IDEyLjA3ODEyNSA1LjEyNSAxNC4zNzUgOCAxNC4zNzUgQyAxMC44NzUgMTQuMzc1IDEzLjE3NTc4MSAxMi4wNzgxMjUgMTMuMTc1NzgxIDkuMjAzMTI1IEwgMTQuNjM2NzE5IDkuMjAzMTI1IEMgMTQuNjM2NzE5IDEyLjg1OTM3NSAxMS42NjAxNTYgMTUuODM5ODQ0IDggMTUuODM5ODQ0IFogTSA4IDE1LjgzOTg0NCAiLz4KPC9nPgo8L3N2Zz4K);
	background-size: cover;
}

.razzi-products-recently-viewed-grid .woocommerce-pagination {
	text-align: center;
	margin-top: 40px;
}

.razzi-products-recently-viewed-grid.has-products .no-products {
	display: none;
}

.elementor-widget-razzi-images-carousel.hover-image-on .image-item:hover .content-img {
	transform: translateY(-6px);
}

.elementor-widget-razzi-images-carousel.hover-image-on .content-img {
	padding-top: 6px;
}

.elementor-widget-razzi-images-carousel.hover-image-on .razzi-products-slider__icon {
	top: 21px;
}

.razzi-images-carousel {
	margin-right: -15px;
	margin-left: -15px;
}

.razzi-images-carousel .content-summary {
	font-size: 1.1rem;
	text-overflow: ellipsis;
	white-space: nowrap;
	margin-top: 12px;
	color: #111;
}

.razzi-images-carousel .content-img {
	transition: transform 0.3s;
}

.razzi-images-carousel .content-img img {
	border-radius: 50%;
	display: block;
}

.razzi-images-carousel .content-subtitle {
	color: #555;
}

.razzi-images-carousel .content-text {
	background-color: var(--rz-background-color-primary);
	align-items: center;
	justify-content: center;
	width: 100px;
	height: 100px;
	max-width: 100%;
	color: #111;
	display: inline-flex;
	border-radius: 50%;
}

.razzi-images-carousel .image-item {
	text-align: center;
	padding: 0 15px;
}

.razzi-images-carousel .full-box-button {
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
}

.razzi-images-carousel .razzi-products-slider__icon {
	font-size: 18px;
	min-width: 40px;
	min-height: 40px;
	line-height: 40px;
	position: absolute;
	top: 15px;
	left: 30px;
	display: flex;
	justify-content: center;
	align-items: center;
	border-radius: 50%;
	background-color: #FF6F61;
	color: var(--rz-color-lighter);
	padding: 5px;
}

.razzi-images-carousel .swiper-scrollbar {
	max-width: 570px;
	background-color: #E2E2E2;
	cursor: pointer;
	height: 4px;
	border-radius: 0;
	position: static;
	width: 100%;
	margin: 69px auto 40px;
}

.razzi-images-carousel .swiper-scrollbar-drag {
	background-color: var(--rz-background-color-dark);
	cursor: pointer;
}

.razzi-images-carousel__skew--yes .razzi-images-carousel {
	transform: skewX(10deg);
}

.razzi-images-carousel__skew--yes .razzi-images-carousel .content-img {
	background-color: #f2f2f2;
	overflow: hidden;
}

.razzi-images-carousel__skew--yes .razzi-images-carousel .content-img img {
	transform: skewX(-10deg);
}

.razzi-images-carousel__skew--yes .razzi-images-carousel .content-title {
	transform: skewX(-10deg);
}

.razzi-images-carousel__skew--yes .razzi-images-carousel .swiper-scrollbar {
	margin-right: 25px;
}

.razzi-images-carousel__heading {
	padding-right: 15px;
}

.razzi--v-position-top .razzi-images-carousel__group--arrows {
	position: absolute;
	left: 0;
	top: 0;
	display: flex;
	justify-content: space-between;
	align-items: center;
	padding-left: 15px;
}

.razzi--v-position-top .razzi-images-carousel__group--arrows .rz-swiper-button {
	position: static;
	transform: none;
	width: auto;
	height: auto;
	line-height: normal;
}

.razzi-heading-title {
	padding: 0;
	margin: 0;
	line-height: 1;
}

.razzi-heading-title small {
	font-size: 13px;
	display: block;
	color: #A0A0A0;
	text-transform: uppercase;
	margin-bottom: 15px;
}

h2.razzi-heading-title {
	font-size: 36px;
}

.razzi-button .razzi-align-icon-left {
}

.razzi-button.button-underline {
	line-height: 1;
	background-color: transparent;
	color: var(--rz-color-dark);
	padding: 0 15px 5px;
	position: relative;
}

.razzi-button.button-underline:after {
	content: '';
	position: absolute;
	right: 0;
	bottom: 0;
	left: 0;
	border-bottom: 1px solid;
	transform-origin: right center;
	transition: all .2s ease-in-out;
	transition-property: transform;
}

.razzi-button.button-underline:hover {
	color: var(--rz-color-dark);
}

.razzi-button.button-underline:hover:after {
	transform-origin: left center;
	transform: scaleX(0);
}

.elementor-align-justify .razzi-button {
	width: 100%;
}

.elementor-motion-parallax {
	position: relative;
}

.elementor-motion-parallax .elementor-motion-effects-container {
	position: absolute;
	right: 0;
	left: 0;
	top: 0;
	bottom: 0;
	overflow: hidden;
}

.elementor-motion-parallax .elementor-motion-effects-layer {
	position: absolute;
	width: 100%;
	height: 150%;
	top: -25%;
	right: 0;
	background-size: cover;
	background-attachment: scroll;
	background-repeat: no-repeat;
	background-position: 50% 50%;
}

@-moz-document url-prefix() {
	.elementor-motion-parallax .elementor-motion-effects-layer {
		top: 0;
	}
}

.razzi-sale-box {
	display: flex;
	justify-content: center;
	align-items: center;
}

.razzi-sale-box__content {
	min-width: 120px;
	min-height: 120px;
	line-height: 1;
	text-align: center;
	border-radius: 50%;
	padding: 15px;
	background-color: var(--rz-background-color-primary);
	color: var(--rz-color-lighter);
	display: flex;
	flex-direction: column;
	align-items: center;
	justify-content: center;
}

.razzi-sale-box__count {
	display: flex;
	align-items: center;
	justify-content: center;
	font-size: 36px;
	font-weight: 600;
}

.razzi-sale-box__text {
	font-size: 18px;
	font-weight: 500;
	margin-bottom: 7px;
}

.razzi-advanced-tabs {
	padding: 0 100px;
}

.razzi-advanced-tabs.razzi-swiper-carousel-elementor .swiper-container {
	position: static;
}

.razzi-advanced-tabs.razzi-swiper-carousel-elementor .rz-swiper-button {
	font-size: 24px;
	width: auto;
	height: auto;
	line-height: 1;
	color: #CDCDCD;
}

.razzi-advanced-tabs.razzi-swiper-carousel-elementor .rz-swiper-button:hover {
	color: #A0A0A0;
}

.razzi-advanced-tabs.razzi-swiper-carousel-elementor .rz-swiper-button-prev {
	right: -105px;
}

.razzi-advanced-tabs.razzi-swiper-carousel-elementor .rz-swiper-button-next {
	left: -105px;
}

.razzi-advanced-tabs.razzi-swiper-carousel-elementor .swiper-button-lock + .swiper-wrapper {
	justify-content: center;
}

.razzi-advanced-tabs__nav {
	display: flex;
	justify-content: center;
	list-style: none;
	margin: 0 -10px 75px;
	padding: 0;
}

.razzi-advanced-tabs__nav li {
	padding-right: 10px;
	padding-left: 10px;
}

.razzi-advanced-tabs__title {
	position: relative;
	font-size: 16px;
	font-weight: 500;
	line-height: 1;
	color: var(--rz-color-dark);
	padding: 0 5px;
}

.razzi-advanced-tabs__title::after {
	content: "";
	position: absolute;
	left: 0;
	bottom: -3px;
	width: 0;
	border-bottom: 1px solid transparent;
	transition: .4s;
}

.razzi-advanced-tabs__title:hover, .razzi-advanced-tabs__title.active {
	color: var(--rz-color-primary);
}

.razzi-advanced-tabs__title:hover::after, .razzi-advanced-tabs__title.active::after {
	width: 100%;
	right: 0;
	left: auto;
	border-color: var(--rz-color-primary);
}

.razzi-advanced-tabs__content {
	position: relative;
}

.razzi-advanced-tabs__panel {
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	z-index: -1;
	opacity: 0;
	transition: opacity 0.4s ease;
	transform: translateY(10px);
}

.razzi-advanced-tabs__panel.active {
	position: relative;
	z-index: 2;
	opacity: 1;
	top: 0;
	transform: translateY(0);
	transition: all 0.4s ease;
	transition-delay: 0.1s;
}

.razzi-advanced-tabs__item {
	display: inline-flex;
	flex-direction: column;
	align-items: center;
	justify-content: center;
	margin-top: 6px;
	margin-left: 30px;
	padding: 15px;
	width: 170px;
	min-height: 170px;
	border: 1px solid #E2E2E2;
}

.razzi-advanced-tabs__item:hover {
	transform: translateY(-6px);
	box-shadow: 0 2px 4px 0 rgba(0, 0, 0, 0.15);
}

.razzi-advanced-tabs__item:last-child {
	margin-left: 0 !important;
}

.razzi-advanced-tabs__icon {
	font-size: 51px;
	color: var(--rz-color-primary);
	margin-bottom: 14px;
}

.razzi-advanced-tabs__content-title {
	font-size: 20px;
	font-weight: 500;
	color: var(--rz-color-dark);
}

.razzi-products-carousel-with-thumbnails:not(.show-quickview) .quick-view-button {
	display: none !important;
}

.razzi-products-carousel-with-thumbnails:not(.show-addtocart) .rz-loop_atc_button {
	display: none !important;
}

.razzi-products-carousel-with-thumbnails:not(.show-wishlist) .yith-wcwl-add-to-wishlist {
	display: none !important;
}

.razzi-products-carousel-with-thumbnails.btn-hidden .product-loop__buttons {
	display: none !important;
}

.razzi-products-carousel-with-thumbnails ul.products.product-loop-layout-8 {
	margin: 0;
	flex-wrap: nowrap;
}

.razzi-products-carousel-with-thumbnails ul.products.product-loop-layout-8:not(.swiper-wrapper) {
	overflow: hidden;
}

.razzi-products-carousel-with-thumbnails ul.products.product-loop-layout-8 li.product {
	padding: 0;
	flex-shrink: 0;
	margin-left: 30px;
}

.razzi-products-carousel-with-thumbnails ul.products.product-loop-layout-8 li.product .product-thumbnail .woocommerce-loop-product__link {
	display: flex;
	width: 100%;
}

.razzi-products-carousel-with-thumbnails ul.products.product-loop-layout-8 li.product .product-thumbnail .woocommerce-loop-product__link .product-thumbnail__image {
	margin-left: 6px;
}

.razzi-products-carousel-with-thumbnails ul.products.product-loop-layout-8 li.product .product-thumbnail .woocommerce-loop-product__link .product-thumbnail__gallery img {
	margin-bottom: 6px;
}

.razzi-products-carousel-with-thumbnails ul.products.product-loop-layout-8 li.product .product-thumbnail .woocommerce-loop-product__link .product-thumbnail__gallery img:last-child {
	margin-bottom: 0;
}

.razzi-products-carousel-with-thumbnails ul.products.product-loop-layout-8 li.product .product-thumbnail .product-loop-inner__buttons {
	right: 15px;
	left: auto;
}

.razzi-products-carousel-with-thumbnails ul.products.product-loop-layout-8 li.product .product-thumbnail .product-loop-inner__buttons .rz-loop_button:hover {
	color: var(--rz-color-primary);
}

.razzi-products-carousel-with-thumbnails ul.products.product-loop-layout-8 li.product .product-thumbnail .product-loop-inner__buttons .rz-loop_button:before {
	right: 25px;
	left: auto;
}

.razzi-products-carousel-with-thumbnails ul.products.product-loop-layout-8 li.product .product-thumbnail .product-loop-inner__buttons .rz-loop_button::after {
	right: 20px;
	left: auto;
	transform: translateY(-50%) rotate(-90deg);
}

.razzi-products-carousel-with-thumbnails .swiper-pagination {
	margin-top: 12px;
}

.products-carousel-with-thumbnails__image-box {
	display: flex;
}

.products-carousel-with-thumbnails__image-box .product-thumbnail__image {
	flex: 1 1 75.7%;
}

.products-carousel-with-thumbnails__image-box .product-thumbnail__gallery {
	flex: 1 1 24.3%;
}

.razzi-products-with-banner:not(.show-category) .meta-cat {
	display: none !important;
}

.razzi-products-with-banner:not(.show-rating) .star-rating {
	display: none !important;
}

.razzi-products-with-banner:not(.show-quickview) .quick-view-button {
	display: none !important;
}

.razzi-products-with-banner:not(.show-addtocart) .rz-loop_atc_button {
	display: none !important;
}

.razzi-products-with-banner:not(.show-wishlist) .yith-wcwl-add-to-wishlist {
	display: none !important;
}

.razzi-products-with-banner:not(.show-badges) .woocommerce-badges {
	display: none !important;
}

.razzi-products-with-banner.btn-hidden .product-loop__buttons {
	display: none !important;
}

.razzi-products-with-banner .masonry-banner-content .banner-image {
	position: relative;
	display: flex;
	line-height: 1;
}

.razzi-products-with-banner .masonry-banner-content .banner-image:before {
	content: '';
	position: absolute;
	right: 0;
	top: 0;
	width: 100%;
	height: 100%;
}

.razzi-products-with-banner .masonry-banner-content .banner-content {
	position: absolute;
	top: 0;
	right: 0;
	display: flex;
	flex-direction: column;
	justify-content: center;
	color: var(--rz-color-dark);
	text-align: center;
	height: 100%;
	width: 100%;
	padding: 30px 45px;
}

.razzi-products-with-banner .razzi-banner__title {
	font-weight: 500;
	font-size: 36px;
	line-height: 48px;
	margin-bottom: 25px;
}

.razzi-products-with-banner .razzi-banner__description {
	font-weight: 400;
	font-size: 18px;
}

.razzi-products-with-banner .razzi-banner__button {
	margin-top: 12px;
}

.razzi-products-with-banner ul.products {
	margin: 0;
}

.razzi-products-with-banner ul.products.layout-masonry li.product {
	margin-bottom: 0;
	padding: 0;
}

.razzi-products-with-banner ul.products.layout-masonry li.product.has-banner {
	grid-column: span 2;
	grid-row: span 2;
	width: 100%;
}

.razzi-products-with-banner ul.products.layout-masonry li.product .star-rating {
	margin-bottom: 5px;
}

.razzi-products-with-banner ul.products.layout-masonry li.product .razzi-banner__masonry,
.razzi-products-with-banner ul.products.layout-masonry li.product .masonry-banner-content,
.razzi-products-with-banner ul.products.layout-masonry li.product .banner-image {
	height: 100%;
}

.razzi-products-with-banner ul.products.layout-masonry li.product .banner-image img {
	object-fit: cover;
}

.razzi-products-with-banner ul.products.layout-masonry li.product .product-thumbnail img {
	object-fit: contain;
}

.razzi-products-with-banner .product-summary > * {
	position: relative;
	z-index: 2;
}

.razzi-products-with-banner .link-product-all {
	display: none;
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	bottom: 0;
	z-index: 1;
}

.razzi-products-with-banner.product-link-type-all .link-product-all {
	display: block;
}

.razzi-images-carousel-2:hover .razzi-icon {
	transform: translateX(-3px);
}

.razzi-images-carousel-2 .razzi-swiper-button-container {
	display: flex;
	align-items: center;
	text-align: center;
	transition: .5s;
	z-index: 99;
	position: absolute;
	left: 0%;
	bottom: 0%;
}

.razzi-images-carousel-2 .content-img {
	transition: transform 0.3s;
	position: relative;
}

.razzi-images-carousel-2 .content-img img {
	display: block;
}

.razzi-images-carousel-2 .image-item {
	text-align: center;
}

.razzi-images-carousel-2 .full-box-button {
	position: absolute;
	top: 0;
	right: 0;
	width: 100%;
	height: 100%;
}

.razzi-images-carousel-2 .razzi-swiper-button {
	width: 42px;
	height: 42px;
	font-size: 24px;
	justify-content: center;
	align-items: center;
	cursor: pointer;
}

.razzi-images-carousel-2 .razzi-images-carousel-content {
	display: flex;
	flex-direction: column;
	justify-content: center;
	align-items: flex-start;
	text-align: right;
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	bottom: 0;
	padding: 30px 75px;
}

.razzi-images-carousel-2 .razzi-images-carousel__title {
	font-size: 36px;
	color: var(--rz-color-dark);
	padding: 0;
}

.razzi-images-carousel-2 .razzi-images-carousel-content__sale {
	position: absolute;
	top: 20px;
	left: 20px;
	width: 96px;
	height: 96px;
	border-radius: 50%;
	background-color: var(--rz-background-color-primary);
	display: flex;
	flex-direction: column;
	align-items: center;
	justify-content: center;
	color: #ffffff;
	font-weight: 500;
	font-size: 28px;
}

.razzi-images-carousel-2 .razzi-images-carousel-content__sale--sale-betext {
	font-size: 16px;
	margin-bottom: 6px;
	line-height: 1;
}

.razzi-images-carousel-2 .razzi-images-carousel-content__sale--sale-text {
	margin-right: 3px;
}

.razzi-posts-listing .entry-header {
	margin-left: 30px;
	margin-bottom: 0;
	flex: 1 0 170px;
}

.razzi-posts-listing .blog-wrapper {
	display: flex;
	align-items: center;
	margin-bottom: 20px;
}

.razzi-posts-listing .blog-wrapper:last-child {
	margin-bottom: 0;
}

.razzi-posts-listing a.post-thumbnail {
	display: flex;
}

.razzi-category-links {
	text-align: center;
}

.razzi-category-links ul {
	list-style: none;
	white-space: nowrap;
	padding: 0;
	margin: 0;
	overflow-x: auto;
	overflow-y: hidden;
	display: flex;
	flex-wrap: nowrap;
}

.razzi-category-links ul li {
	display: inline-block;
	padding: 13px 50px;
	position: relative;
}

.razzi-category-links ul li a {
	font-weight: 500;
}

.razzi-category-links ul li:first-child {
	padding-right: 0;
}

.razzi-category-links ul li:last-child {
	padding-left: 0;
}

.razzi-category-links ul li:not(:last-child):after {
	content: '';
	display: block;
	position: absolute;
	left: 0;
	top: 50%;
	transform: translateY(-50%);
	width: 1px;
	height: 12px;
	background-color: #cdcdcd;
}

.razzi-category-links ul::-webkit-scrollbar {
	display: none;
}

.razzi-product-category-box .razzi-product-category-box__items {
	display: flex;
	flex-wrap: wrap;
	margin: -15px;
}

.razzi-product-category-box .razzi-product-category-box__item-box {
	display: flex;
	justify-content: space-between;
	align-items: center;
	width: 370px;
	background-color: #FFFFFF;
	position: relative;
}

.razzi-product-category-box .razzi-product-category-box__item-box:hover .razzi-icon {
	transform: translateX(-3px);
}

.razzi-product-category-box .razzi-product-category-box__item {
	position: relative;
	padding: 15px;
}

.razzi-product-category-box .razzi-product-category-box__content {
	padding: 23px 30px 10px 0;
}

.razzi-product-category-box .razzi-product-category-box__content .razzi-button {
	margin-top: 23px;
	padding: 0;
	color: var(--rz-color-dark);
	background-color: var(--rz-color-lighter);
}

.razzi-product-category-box .razzi-product-category-box__cat-name {
	font-size: 18px;
	font-weight: 500;
	margin-bottom: 5px;
}

.razzi-product-category-box .razzi-product-category-box__cat-count {
	font-size: 14px;
	margin-top: 5px;
}

.razzi-product-category-box .razzi-product-category-box__image {
	padding: 0 18px;
}

.razzi-product-category-box .razzi-product-category-box__link {
	position: absolute;
	top: 0;
	height: 100%;
	width: 100%;
}

.razzi-product-category-box__button-link {
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	bottom: 0;
	z-index: 2;
}

.razzi-products-listing ul.swiper-wrapper {
	margin: 0;
	box-sizing: border-box;
}

.razzi-products-listing ul.swiper-wrapper li {
	clear: none;
	padding-right: 0;
	padding-left: 0;
	margin-bottom: 0;
}

.razzi-products-listing ul.products {
	flex-wrap: nowrap;
	list-style: none;
}

.razzi-products-listing ul.products:not(.swiper-wrapper) {
	overflow: hidden;
}

.razzi-products-listing ul.products li.product {
	padding-right: 0;
	padding-left: 0;
	margin-bottom: 0;
}

.razzi-products-listing ul.products li.product:not(.swiper-slide) {
	flex-shrink: 0;
	margin-left: 30px;
}

.razzi-products-listing ul.products li.product .price {
	color: var(--rz-color-dark);
}

.razzi-products-listing .swiper-container-multirow ul.products {
	flex-wrap: wrap;
}

.razzi-products-listing .razzi-products-listing__image {
	margin-left: 30px;
	max-width: 90px;
}

.razzi-products-listing .razzi-products-listing__item-box {
	display: flex;
	margin: 1px;
	box-shadow: 0px 0px 1px rgba(0, 0, 0, 0.4);
	padding: 19px 20px 19px 20px;
}

.razzi-products-listing__heading {
	font-size: 28px;
	font-weight: 500;
}

.razzi-products-listing__items {
	display: flex;
}

.razzi-products-listing__content {
	margin-top: 4px;
	color: var(--rz-color-dark);
}

.razzi-products-listing__title {
	font-size: 16px;
}

.razzi-products-listing__price {
	margin-top: 10px;
	font-size: 16px;
	font-weight: 500;
}

.razzi-products-listing__heading--arrows {
	display: flex;
	justify-content: space-between;
	align-items: center;
	margin-bottom: 47px;
}

.razzi-products-listing__heading--arrows .razzi-products-listing__arrows {
	margin-left: 97px;
}

.razzi-products-listing__heading--arrows .rz-swiper-button {
	position: static;
	transform: none;
	width: auto;
	height: auto;
	line-height: normal;
	font-size: 16px;
	width: 30px;
	height: 30px;
	line-height: 30px;
	color: #111;
	background-color: #f5f5f5;
}

.razzi-team-member-carousel {
	margin: 0 -20px;
}

.razzi-team-member {
	padding: 0 20px;
	width: 33.33%;
}

.razzi-team-member__info {
	padding: 12px 20px 12px 20px;
}

.razzi-team-member__name {
	margin: 0;
	font-size: 18px;
}

.razzi-team-member__job {
	font-size: 14px;
}

.razzi-team-member__socials {
	float: left;
}

.razzi-team-member__socials a {
	font-size: 12px;
	margin-right: 20px;
	color: #838889;
}

.razzi-team-member__socials a:hover {
	color: #111;
}

.razzi-team-member__socials a:first-child {
	margin-right: 0;
}

.razzi-team-member-carousel .rz-swiper-button-prev {
	right: 20px;
}

.razzi-team-member-carousel .rz-swiper-button-next {
	left: 20px;
}

.razzi-team-member-carousel .rz-swiper-button {
	line-height: 44px;
	background-color: rgba(255, 255, 255, 0.9);
}

.razzi-team-member-carousel .rz-swiper-button:hover {
	background-color: white;
}

@media (max-width: 767px) {
	.razzi-team-member-carousel {
		margin: 0 -15px;
	}
	.razzi-team-member {
		padding: 0 15px;
		width: 100%;
	}
	.razzi-team-member-carousel.razzi-swiper-carousel-elementor .rz-swiper-button-prev {
		right: 15px;
	}
	.razzi-team-member-carousel.razzi-swiper-carousel-elementor .rz-swiper-button-next {
		left: 15px;
	}
}

@media (max-width: 1366px) {
	.razzi-icons-box-carousel .rz-swiper-button-prev {
		right: -50px;
	}
	.razzi-icons-box-carousel .rz-swiper-button-next {
		left: -50px;
	}
}

@media (max-width: 1279px) {
	.razzi-icons-box-carousel .rz-swiper-button-prev {
		right: 0;
	}
	.razzi-icons-box-carousel .rz-swiper-button-next {
		left: 0;
	}
}

@media (max-width: 1199px) {
	.razzi-product-shortcode.single-product div.product .entry-summary {
		padding-left: 0;
	}
	.razzi-products-carousel__slidesperviewauto-yes .razzi-products-carousel {
		margin-left: 0 !important;
	}
	.razzi-products-carousel__slidesperviewauto-yes .razzi-products-carousel ul.products li.swiper-item-empty {
		display: none;
	}
	.razzi-products-carousel__centeredslides-yes .swiper-slide {
		max-width: 100%;
	}
	.razzi-images-carousel__slidesperviewauto-yes .razzi-images-carousel .swiper-item-empty {
		display: none;
	}
	.razzi-images-carousel__slidesperviewauto-yes .razzi-images-carousel .swiper-slide {
		max-width: 100%;
		flex: none;
	}
}

@media (max-width: 1350px) and (min-width: 1024px) {
	.razzi-products-carousel .rz-swiper-button-prev {
		right: 3px !important;
	}
	.razzi-products-carousel .rz-swiper-button-next {
		left: 3px !important;
	}
	.razzi-products-carousel .rz-swiper-button {
		font-size: 24px !important;
		border-radius: 50%;
		box-shadow: 0 0 5px rgba(0, 0, 0, 0.5);
	}
	.razzi-products-carousel.razzi-product-of-category .razzi-products-carousel__heading--arrows .rz-swiper-button {
		border-radius: inherit;
		box-shadow: none;
	}
}

@media (max-width: 1024px) {
	.razzi-products-showcase {
		padding: 0 30px;
	}
	.razzi-products-showcase .showcase-box {
		padding-right: 25px;
	}
	.razzi-products-showcase ul.swiper-wrapper li {
		display: flex;
		align-items: center;
	}
	.razzi-image-box-2 {
		margin-bottom: 0;
		height: 865px;
	}
	.razzi-image-box-2__block {
		display: flex;
		flex-wrap: initial;
		flex-direction: column;
	}
	.razzi-image-box-2__bg {
		flex-basis: 50%;
		max-width: 100%;
		transform: none;
	}
	.razzi-image-box-2__blank {
		flex-basis: 50%;
	}
	.razzi-image-box-2__inner {
		align-items: end;
	}
	.razzi-image-box-2__content {
		padding-top: 70px;
		padding-left: 0;
		width: 100%;
	}
	.razzi-image-box-2--align-left {
		height: 930px;
	}
	.razzi-image-box-2--align-left .razzi-image-box-2__inner {
		align-items: flex-end;
	}
	.razzi-image-box-2--align-left .razzi-image-box-2__content {
		padding-bottom: 50px;
		padding-top: 0;
	}
	.razzi-category-box__img {
		max-width: 100%;
	}
	.razzi-category-box__content {
		padding: 30px;
	}
	.razzi-product-of-category.has-categories .razzi-product-of-category__categories {
		width: 17.6%;
	}
	.razzi-product-of-category.has-categories .razzi-product-of-category__product {
		width: calc(82.4% - 20px);
	}
	.razzi-testimonials-carousel-2 .testimonials-item {
		flex: 0 0 auto !important;
		max-width: 100% !important;
	}
	.razzi-testimonials-carousel-2 .testimonials-item-empty {
		display: none;
	}
	.razzi-testimonials-carousel-2 .author-group {
		padding-left: 30px;
	}
	.razzi-testimonials-carousel-2 .author-group + .razzi-testimonials-carousel-2__gr {
		padding-right: 30px;
	}
	.razzi-advanced-tabs {
		padding: 0;
	}
	.razzi-advanced-tabs.razzi-swiper-carousel-elementor .rz-swiper-button-prev {
		right: -5px;
	}
	.razzi-advanced-tabs.razzi-swiper-carousel-elementor .rz-swiper-button-next {
		left: -5px;
	}
	.razzi-posts-listing .entry-header {
		flex: 1 0 120px;
	}
	.razzi-banner .razzi-banner__button-2 {
		margin-top: 20px;
	}
	.razzi-product-category-box .razzi-product-category-box__items {
		margin: 0 -15px;
	}
	.razzi-product-category-box .razzi-product-category-box__item {
		width: 50%;
	}
	.razzi-product-category-box .razzi-product-category-box__item-box {
		width: 100%;
	}
}

@media (min-width: 1025px) {
	.columns-1 .razzi-element-columns .elmentor-column-item {
		width: 100%;
	}
	.columns-1 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/1 * 100%), 1fr));
	}
	.columns-2 .razzi-element-columns .elmentor-column-item {
		width: 50%;
	}
	.columns-2 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/2 * 100%), 1fr));
	}
	.columns-3 .razzi-element-columns .elmentor-column-item {
		width: 33.33%;
	}
	.columns-3 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/3 * 100%), 1fr));
	}
	.columns-4 .razzi-element-columns .elmentor-column-item {
		width: 25%;
	}
	.columns-4 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/4 * 100%), 1fr));
	}
	.columns-5 .razzi-element-columns .elmentor-column-item {
		width: 20%;
	}
	.columns-5 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/5 * 100%), 1fr));
	}
	.columns-6 .razzi-element-columns .elmentor-column-item {
		width: 16.66%;
	}
	.columns-6 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/6 * 100%), 1fr));
	}
	.columns-7 .razzi-element-columns .elmentor-column-item {
		width: 14.28%;
	}
	.columns-7 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/7 * 100%), 1fr));
	}
	.columns-8 .razzi-element-columns .elmentor-column-item {
		width: 12.5%;
	}
	.columns-8 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/8 * 100%), 1fr));
	}
	.columns-9 .razzi-element-columns .elmentor-column-item {
		width: 11.11%;
	}
	.columns-9 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/9 * 100%), 1fr));
	}
	.columns-10 .razzi-element-columns .elmentor-column-item {
		width: 10%;
	}
	.columns-10 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/10 * 100%), 1fr));
	}
	.razzi-swiper-carousel-elementor.navigation-dots .rz-swiper-button, .razzi-swiper-carousel-elementor.navigation-dots .razzi-swiper-button, .razzi-swiper-carousel-elementor.navigation-none .rz-swiper-button, .razzi-swiper-carousel-elementor.navigation-none .razzi-swiper-button {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.navigation-dots .swiper-scrollbar, .razzi-swiper-carousel-elementor.navigation-none .swiper-scrollbar {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.navigation-arrows .swiper-pagination, .razzi-swiper-carousel-elementor.navigation-none .swiper-pagination {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.navigation-arrows .swiper-scrollbar, .razzi-swiper-carousel-elementor.navigation-none .swiper-scrollbar {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.navigation-scrollbar .rz-swiper-button, .razzi-swiper-carousel-elementor.navigation-scrollbar .razzi-swiper-button, .razzi-swiper-carousel-elementor.navigation-none .rz-swiper-button, .razzi-swiper-carousel-elementor.navigation-none .razzi-swiper-button {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.navigation-scrollbar .swiper-pagination, .razzi-swiper-carousel-elementor.navigation-none .swiper-pagination {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.navigation-dots-arrows .swiper-scrollbar, .razzi-swiper-carousel-elementor.navigation-none .swiper-scrollbar {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.dots-position-bottom .swiper-pagination {
		left: auto;
		width: 100%;
		bottom: 0;
		top: auto;
		flex-direction: row;
		justify-content: center;
	}
	.razzi-swiper-carousel-elementor.dots-position-bottom.dots-position-tablet-right .swiper-pagination, .razzi-swiper-carousel-elementor.dots-position-bottom.dots-position-mobile-right .swiper-pagination {
		left: auto !important;
	}
	.razzi-swiper-carousel-elementor.dots-position-right.dots-position-tablet-bottom .swiper-pagination, .razzi-swiper-carousel-elementor.dots-position-right.dots-position-mobile-bottom .swiper-pagination {
		bottom: auto !important;
	}
	.razzi-position-under-image .razzi-category-box {
		flex-direction: column;
	}
	.razzi-position-under-image .razzi-category-box > * {
		max-width: 100%;
	}
}

@media (max-width: 1024px) and (min-width: 768px) {
	.columns--tablet1 .razzi-element-columns .elmentor-column-item {
		width: 100%;
	}
	.columns--tablet1 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/1 * 100%), 1fr));
	}
	.columns--tablet2 .razzi-element-columns .elmentor-column-item {
		width: 50%;
	}
	.columns--tablet2 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/2 * 100%), 1fr));
	}
	.columns--tablet3 .razzi-element-columns .elmentor-column-item {
		width: 33.33%;
	}
	.columns--tablet3 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/3 * 100%), 1fr));
	}
	.columns--tablet4 .razzi-element-columns .elmentor-column-item {
		width: 25%;
	}
	.columns--tablet4 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/4 * 100%), 1fr));
	}
	.columns--tablet5 .razzi-element-columns .elmentor-column-item {
		width: 20%;
	}
	.columns--tablet5 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/5 * 100%), 1fr));
	}
	.columns--tablet6 .razzi-element-columns .elmentor-column-item {
		width: 16.66%;
	}
	.columns--tablet6 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/6 * 100%), 1fr));
	}
	.columns--tablet7 .razzi-element-columns .elmentor-column-item {
		width: 14.28%;
	}
	.columns--tablet7 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/7 * 100%), 1fr));
	}
	.columns--tablet8 .razzi-element-columns .elmentor-column-item {
		width: 12.5%;
	}
	.columns--tablet8 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/8 * 100%), 1fr));
	}
	.columns--tablet9 .razzi-element-columns .elmentor-column-item {
		width: 11.11%;
	}
	.columns--tablet9 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/9 * 100%), 1fr));
	}
	.columns--tablet10 .razzi-element-columns .elmentor-column-item {
		width: 10%;
	}
	.columns--tablet10 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/10 * 100%), 1fr));
	}
	.razzi-swiper-carousel-elementor.navigation-tablet-dots .rz-swiper-button, .razzi-swiper-carousel-elementor.navigation-tablet-none .rz-swiper-button {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.navigation-tablet-dots .swiper-scrollbar, .razzi-swiper-carousel-elementor.navigation-tablet-none .swiper-scrollbar {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.navigation-tablet-arrows .swiper-pagination, .razzi-swiper-carousel-elementor.navigation-tablet-none .swiper-pagination {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.navigation-tablet-arrows .swiper-scrollbar, .razzi-swiper-carousel-elementor.navigation-tablet-none .swiper-scrollbar {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.navigation-tablet-scrollbar .rz-swiper-button, .razzi-swiper-carousel-elementor.navigation-tablet-none .rz-swiper-button {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.navigation-tablet-scrollbar .swiper-pagination, .razzi-swiper-carousel-elementor.navigation-tablet-none .swiper-pagination {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.navigation-tablet-dots-arrows .swiper-scrollbar, .razzi-swiper-carousel-elementor.navigation-tablet-none .swiper-scrollbar {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.dots-position-tablet-bottom .swiper-pagination {
		left: auto;
		width: 100%;
		bottom: 0;
		top: auto;
		flex-direction: row;
		justify-content: center;
	}
	.razzi-swiper-carousel-elementor.dots-position-tablet-bottom.dots-position-right .swiper-pagination, .razzi-swiper-carousel-elementor.dots-position-tablet-bottom.dots-position-mobile-right .swiper-pagination {
		left: auto !important;
	}
	.razzi-swiper-carousel-elementor.dots-position-tablet-right.dots-position-bottom .swiper-pagination, .razzi-swiper-carousel-elementor.dots-position-tablet-right.dots-position-mobile-bottom .swiper-pagination {
		bottom: auto !important;
	}
	.btn-position-tablet-bottom .razzi-image-button:before {
		bottom: 54px;
		height: auto;
	}
	.btn-position-tablet-bottom .razzi-image-button__button {
		position: static;
		transform: none;
	}
	.content-position-tablet-bottom .razzi-product-banner {
		display: block;
	}
	.content-position-tablet-bottom .razzi-product-banner .banner-content {
		margin-top: 20px;
		transform: none;
	}
	.razzi-position-tablet-under-image .razzi-category-box {
		flex-direction: column;
	}
	.razzi-position-tablet-under-image .razzi-category-box > * {
		max-width: 100%;
	}
	.razzi-icon-box-list.columns-even {
		flex-wrap: wrap;
	}
	.razzi-icon-box-list.columns-even .razzi-icon-box-list__item {
		flex-basis: auto;
		flex: 50%;
		padding: 15px;
	}
	.razzi-icon-box-list.columns-even .razzi-icon-box-list__item:nth-child(2n+1) {
		padding-right: 0;
	}
	.razzi-icon-box-list.columns-even .razzi-icon-box-list__item:nth-child(2n) {
		padding-left: 0;
	}
}

@media (max-width: 991px) {
	.razzi-deals-carousel .countdown-slider {
		justify-content: center;
		text-align: center;
	}
	.razzi-products-showcase.razzi-swiper-carousel-elementor .rz-swiper-button {
		display: none;
	}
	.razzi-products-showcase.show-featured ul.products li.product .product-inner .product-thumbnail .rz-loop_button {
		opacity: 1;
		transform: translateY(0);
	}
	.razzi-products-showcase .razzi-shortcode-title {
		margin-bottom: 25px;
		font-size: 24px;
	}
	.razzi-products-showcase .swiper-pagination {
		margin-top: 10px;
	}
	.razzi-products-showcase ul.products li.product .product-inner .product-loop__buttons {
		top: 60px;
		left: 25px;
	}
	.razzi-products-showcase ul.products li.product .product-inner .product-loop__buttons .rz-loop_button {
		width: 40px;
		height: 40px;
		background-color: #fff;
	}
	.razzi-products-showcase ul.products li.product .product-inner .product-loop__buttons .rz-loop_button:hover {
		background-color: #fff;
	}
	.razzi-products-showcase ul.products li.product .product-inner .product-loop__buttons .rz-loop_button:before {
		left: 54px;
	}
	.razzi-products-showcase ul.products li.product .product-inner .product-loop__buttons .rz-loop_button:after {
		left: 44px;
	}
	.razzi-product-shortcode .rz-product-wrapper {
		display: block;
	}
	.razzi-product-shortcode.single-product div.product .woocommerce-product-gallery,
	.razzi-product-shortcode.single-product div.product .entry-summary {
		width: 100%;
		float: none;
	}
	.razzi-product-shortcode.single-product div.product .woocommerce-product-gallery .woocommerce-product-gallery__image a, .razzi-product-shortcode.single-product div.product .woocommerce-product-gallery .woocommerce-product-gallery__image img {
		margin: 0 auto;
	}
	.razzi-product-shortcode.single-product div.product .entry-summary {
		padding: 0;
	}
	.razzi-products-deal ul.products li.product .product-summary {
		padding: 0;
		top: 0;
		margin-top: 20px;
	}
	.razzi-products-deal ul.products li.product .product-summary-deal {
		padding: 0;
	}
	.razzi-products-deal ul.products li.product .woocommerce-loop-product__title {
		font-size: 16px;
		line-height: 24px;
	}
	.razzi-products-deal .swiper-pagination {
		margin-top: 30px;
	}
	.razzi-lookbook-slider-elementor .slick-slide-block__blank {
		width: 25%;
	}
	.razzi-lookbook-slider-elementor .slick-slide-block__img {
		width: 75%;
	}
	.razzi-pricing-table__content {
		padding-right: 30px;
		padding-left: 30px;
	}
	.razzi-product-of-category.has-categories {
		display: block;
	}
	.razzi-product-of-category.has-categories .razzi-product-of-category__categories,
	.razzi-product-of-category.has-categories .razzi-product-of-category__product {
		width: 100%;
	}
	.razzi-product-of-category.has-categories .razzi-products-carousel__heading--arrows {
		margin-bottom: 0;
	}
	.razzi-product-of-category__categories {
		background: none !important;
		padding-right: 0 !important;
		padding-top: 5px;
	}
	.razzi-product-of-category__categories ul {
		display: flex;
		overflow-x: auto;
		scrollbar-color: #1f1f1f #e2e2e278;
		scrollbar-width: thin;
		margin-bottom: 20px;
	}
	.razzi-product-of-category__categories ul::-webkit-scrollbar {
		height: 2px;
	}
	.razzi-product-of-category__categories ul::-webkit-scrollbar-track {
		background-color: #e2e2e2;
	}
	.razzi-product-of-category__categories ul::-webkit-scrollbar-thumb {
		background-color: #1f1f1f;
	}
	.razzi-product-of-category__categories ul li {
		margin-bottom: 5px;
		display: flex;
	}
	.razzi-product-of-category__categories ul li a {
		padding-left: 15px;
		font-weight: 400;
	}
	.razzi-product-of-category__categories ul li a::after {
		display: none;
	}
	.razzi-isolate-slides__wrapper {
		flex: 1 1 65%;
	}
	.razzi-isolate-slides__image {
		flex: 1 1 35%;
	}
	.razzi-products-with-banner {
		overflow: hidden;
	}
	.razzi-products-with-banner ul.products.layout-masonry {
		margin: 0 -10px;
	}
	.razzi-products-with-banner ul.products.layout-masonry li.product {
		padding: 0 10px;
		margin-bottom: 30px;
		order: 2;
	}
	.razzi-products-with-banner ul.products.layout-masonry li.product.has-banner {
		order: 1;
		grid-column: span 3 !important;
	}
	.razzi-products-with-banner ul.products.layout-masonry.mobile-show-atc .product-loop__buttons .rz-loop_atc_button {
		display: none !important;
	}
	.razzi-products-with-banner ul.products.layout-masonry.mobile-show-atc .rz-loop_atc_button {
		display: flex !important;
	}
	.razzi-products-with-banner .masonry-banner-content .banner-content {
		position: static;
	}
	.razzi-products-with-banner.product-link-type-all .link-product-all {
		display: none;
	}
	.razzi-products-carousel-with-thumbnails ul.products.product-loop-layout-8 li.product .product-summary .product-loop__buttons a.rz-loop_atc_button {
		display: none;
	}
	.razzi-products-carousel-with-thumbnails ul.products.product-loop-layout-8.mobile-show-atc li.product .product-summary .product-loop__buttons a.rz-loop_atc_button {
		display: flex;
	}
	.razzi-products-listing .razzi-products-listing__item-box {
		padding: 10px;
	}
	.razzi-products-listing .razzi-products-listing__image {
		margin-left: 10px;
	}
}

@media (min-width: 992px) {
	.razzi-deals-carousel .countdown-item {
		width: 50%;
		margin-right: 50%;
	}
	.razzi-products-with-banner ul.products.product-loop-layout-7 li.product .product-summary {
		background-color: rgba(0, 0, 0, 0.9);
	}
	.razzi-products-with-banner ul.products.product-loop-layout-7 li.product .meta-cat,
	.razzi-products-with-banner ul.products.product-loop-layout-7 li.product .woocommerce-loop-product__title,
	.razzi-products-with-banner ul.products.product-loop-layout-7 li.product .price,
	.razzi-products-with-banner ul.products.product-loop-layout-7 li.product .star-rating .user-rating .razzi-svg-icon,
	.razzi-products-with-banner ul.products.product-loop-layout-7 li.product .product-loop__buttons .rz-loop_button {
		color: #ffffff;
	}
	.razzi-products-with-banner ul.products.product-loop-layout-7 li.product .star-rating .max-rating .razzi-svg-icon {
		color: #a6a6a6;
	}
	.razzi-products-with-banner ul.products.product-loop-layout-7 li.product .rz-loop_button:not(.loading):before {
		color: #111111;
		background-color: #ffffff;
	}
	.razzi-products-with-banner ul.products.product-loop-layout-7 li.product .rz-loop_button:not(.loading):after {
		border-color: #fff transparent transparent transparent;
	}
	.razzi-products-with-banner ul.products.layout-masonry:not(.razzi-products-masonry__content) li.product:nth-child(14n+11), .razzi-products-with-banner ul.products.layout-masonry:not(.razzi-products-masonry__content) li.product:nth-child(14n+1) {
		grid-column: span 1;
		grid-row: span 1;
	}
	.razzi-products-with-banner ul.products.layout-masonry:not(.razzi-products-masonry__content) li.product:nth-child(2) {
		grid-column: span 2;
		grid-row: span 1;
	}
}

@media (max-width: 767px) {
	.razzi-shortcode-title {
		font-size: 24px;
	}
	.razzi-products-tabs .razzi-box-title,
	.razzi-product-category-tabs .razzi-box-title {
		margin-bottom: 10px;
	}
	.razzi-products-tabs ul.tabs,
	.razzi-product-category-tabs ul.tabs {
		white-space: nowrap;
		overflow: hidden;
		overflow-x: auto;
	}
	.razzi-products-tabs ul.tabs li,
	.razzi-product-category-tabs ul.tabs li {
		padding: 0 10px;
	}
	.razzi-product-category-tabs {
		padding: 0;
	}
	.razzi-banner-clt__content {
		position: relative;
		bottom: 0;
		transform: translateY(0);
	}
	.razzi-products-showcase {
		flex-direction: column;
		padding: 0;
	}
	.razzi-products-showcase.hide-image-large .showcase-image {
		display: none !important;
	}
	.razzi-products-showcase .showcase-image,
	.razzi-products-showcase .showcase-box {
		width: 100%;
	}
	.razzi-products-showcase .showcase-image {
		order: 2;
		margin-top: 40px;
	}
	.razzi-products-showcase .showcase-box {
		order: 1;
		padding-right: 0;
	}
	.razzi-products-showcase .razzi-shortcode-title {
		margin-bottom: 30px;
	}
	.razzi-products-showcase ul.products li.product {
		padding: 0;
	}
	.razzi-products-showcase ul.swiper-wrapper li {
		justify-content: center;
	}
	.razzi-product-shortcode .rz-product-wrapper {
		padding: 30px 15px;
	}
	.razzi-banner-carousel .banner-item .banner-img:after {
		background-color: rgba(0, 0, 0, 0.3);
	}
	.columns--mobile1 .razzi-element-columns .elmentor-column-item {
		width: 100%;
	}
	.columns--mobile1 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/1 * 100%), 1fr));
	}
	.columns--mobile2 .razzi-element-columns .elmentor-column-item {
		width: 50%;
	}
	.columns--mobile2 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/2 * 100%), 1fr));
	}
	.columns--mobile3 .razzi-element-columns .elmentor-column-item {
		width: 33.33%;
	}
	.columns--mobile3 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/3 * 100%), 1fr));
	}
	.columns--mobile4 .razzi-element-columns .elmentor-column-item {
		width: 25%;
	}
	.columns--mobile4 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/4 * 100%), 1fr));
	}
	.columns--mobile5 .razzi-element-columns .elmentor-column-item {
		width: 20%;
	}
	.columns--mobile5 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/5 * 100%), 1fr));
	}
	.columns--mobile6 .razzi-element-columns .elmentor-column-item {
		width: 16.66%;
	}
	.columns--mobile6 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/6 * 100%), 1fr));
	}
	.columns--mobile7 .razzi-element-columns .elmentor-column-item {
		width: 14.28%;
	}
	.columns--mobile7 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/7 * 100%), 1fr));
	}
	.columns--mobile8 .razzi-element-columns .elmentor-column-item {
		width: 12.5%;
	}
	.columns--mobile8 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/8 * 100%), 1fr));
	}
	.columns--mobile9 .razzi-element-columns .elmentor-column-item {
		width: 11.11%;
	}
	.columns--mobile9 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/9 * 100%), 1fr));
	}
	.columns--mobile10 .razzi-element-columns .elmentor-column-item {
		width: 10%;
	}
	.columns--mobile10 .razzi-element-columns .instagram-wrapper {
		grid-template-columns: repeat(auto-fill, minmax(calc(1/10 * 100%), 1fr));
	}
	.razzi-swiper-carousel-elementor.navigation-mobile-dots .rz-swiper-button, .razzi-swiper-carousel-elementor.navigation-mobile-dots .razzi-swiper-button, .razzi-swiper-carousel-elementor.navigation-mobile-none .rz-swiper-button, .razzi-swiper-carousel-elementor.navigation-mobile-none .razzi-swiper-button {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.navigation-mobile-dots .swiper-scrollbar, .razzi-swiper-carousel-elementor.navigation-mobile-none .swiper-scrollbar {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.navigation-mobile-arrows .swiper-pagination, .razzi-swiper-carousel-elementor.navigation-mobile-none .swiper-pagination {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.navigation-mobile-arrows .swiper-scrollbar, .razzi-swiper-carousel-elementor.navigation-mobile-none .swiper-scrollbar {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.navigation-mobile-scrollbar .rz-swiper-button, .razzi-swiper-carousel-elementor.navigation-mobile-scrollbar .razzi-swiper-button, .razzi-swiper-carousel-elementor.navigation-mobile-none .rz-swiper-button, .razzi-swiper-carousel-elementor.navigation-mobile-none .razzi-swiper-button {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.navigation-mobile-scrollbar .swiper-pagination, .razzi-swiper-carousel-elementor.navigation-mobile-none .swiper-pagination {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.navigation-mobile-dots-arrows .swiper-scrollbar, .razzi-swiper-carousel-elementor.navigation-mobile-none .swiper-scrollbar {
		display: none !important;
	}
	.razzi-swiper-carousel-elementor.dots-position-mobile-bottom .swiper-pagination {
		left: auto;
		width: 100%;
		bottom: 0;
		top: auto;
		flex-direction: row;
		justify-content: center;
	}
	.razzi-swiper-carousel-elementor.dots-position-mobile-bottom.dots-position-right .swiper-pagination, .razzi-swiper-carousel-elementor.dots-position-mobile-bottom.dots-position-tablet-right .swiper-pagination {
		left: auto !important;
	}
	.razzi-swiper-carousel-elementor.dots-position-mobile-right.dots-position-bottom .swiper-pagination, .razzi-swiper-carousel-elementor.dots-position-mobile-right.dots-position-tablet-bottom .swiper-pagination {
		bottom: auto !important;
	}
	.razzi-swiper-carousel-elementor .rz-swiper-button-next {
		left: 0;
	}
	.razzi-swiper-carousel-elementor .rz-swiper-button-prev {
		right: 0;
	}
	.razzi-slides-elementor--arrow-style-3 .rz-swiper-button-prev {
		right: auto;
	}
	.razzi-position-mobile-under-image .razzi-category-box {
		flex-direction: column;
	}
	.razzi-position-mobile-under-image .razzi-category-box > * {
		max-width: 100%;
	}
	.razzi-category-box__content .sub-cats .razzi-icon {
		display: none;
	}
	.razzi-featured-content .line-control {
		display: none;
	}
	.razzi-promo-box__content {
		padding: 20px;
	}
	.razzi-promo-box__content-position--left .razzi-promo-box__content {
		top: 20px;
		bottom: 20px;
		right: -75px;
	}
	.razzi-promo-box__content-position--left .razzi-promo-box {
		margin-right: 75px;
	}
	.razzi-promo-box__content-position--right .razzi-promo-box__content {
		top: 20px;
		bottom: 20px;
		left: -75px;
	}
	.razzi-promo-box__content-position--right .razzi-promo-box {
		margin-left: 75px;
	}
	.razzi-promo-box__content-position--bottom .razzi-promo-box__content {
		right: 20px;
		left: 20px;
	}
	.razzi-promo-box__title {
		font-size: 24px;
	}
	.razzi-image-content-box__right {
		padding: 0;
	}
	.razzi-image-content-box__bg {
		height: 300px;
	}
	.btn-position-mobile-bottom .razzi-image-button:before {
		bottom: 54px;
		height: auto;
	}
	.btn-position-mobile-bottom .razzi-image-button__button {
		position: static;
		transform: none;
	}
	.content-position-mobile-bottom .razzi-product-banner {
		display: block;
	}
	.content-position-mobile-bottom .razzi-product-banner .banner-content {
		margin-top: 20px;
		transform: none;
	}
	.razzi-lookbook-slider-elementor .swiper-pagination {
		position: absolute;
		bottom: 20px;
		z-index: 10;
		margin-top: 0;
	}
	.razzi-products-masonry ul.products.layout-masonry li.product.has-banner {
		display: none;
	}
	.razzi-icon-box-list {
		flex-wrap: wrap;
	}
	.razzi-icon-box-list .razzi-icon-box-list__item {
		flex-basis: auto;
		flex: 50%;
		padding: 15px;
		display: block;
		text-align: center;
	}
	.razzi-icon-box-list .razzi-icon-box-list__item:nth-child(2n+1) {
		padding-right: 0;
	}
	.razzi-icon-box-list .razzi-icon-box-list__item:nth-child(2n) {
		padding-left: 0;
	}
	.razzi-icon-box-list .razzi-icon-box-list__icon {
		margin-left: 0;
	}
	.razzi-icon-box-list.columns-odd .razzi-icon-box-list__item {
		flex: 100%;
		padding: 15px 0;
	}
	.razzi-isolate-slides__wrapper {
		flex: 1 1 100%;
	}
	.razzi-isolate-slides__image {
		display: none;
	}
	.razzi-images-carousel {
		margin-right: -7.5px;
		margin-left: -7.5px;
	}
	.razzi-images-carousel .image-item {
		padding: 0 7.5px;
	}
	.razzi-images-carousel .razzi-products-slider__icon {
		top: 10px;
		left: 17.5px;
	}
	.razzi-images-carousel__heading {
		padding-right: 7.5px;
	}
	.razzi-images-carousel__skew--yes .razzi-images-carousel {
		transform: none;
	}
	.razzi-images-carousel__skew--yes .razzi-images-carousel .content-img img {
		transform: none;
	}
	.razzi-images-carousel__skew--yes .razzi-images-carousel .content-title {
		transform: none;
	}
	.razzi-images-carousel__skew--yes .razzi-images-carousel .swiper-scrollbar {
		margin-right: 0;
	}
	.razzi--v-position-top .razzi-images-carousel__group--arrows {
		padding-left: 7.5px;
	}
	.elementor-widget-razzi-images-carousel.hover-image-on .razzi-products-slider__icon {
		top: 16px;
	}
	.razzi-products-with-banner ul.products.layout-masonry {
		margin: 0 -7.5px;
	}
	.razzi-products-with-banner ul.products.layout-masonry li.product {
		padding: 0 7.5px;
		margin-bottom: 25px;
	}
	.razzi-products-slider .razzi-products-slider__content {
		right: 15px;
		left: 15px;
		max-width: 100%;
		padding: 30px 20px 20px;
	}
	.razzi-products-slider .razzi-products-slider__sale {
		left: -10px;
	}
	.razzi-products-slider .swiper-pagination {
		top: auto;
		right: 0;
		left: 0;
		bottom: 20px;
		transform: none;
		flex-direction: row;
		justify-content: center;
	}
	.razzi-products-slider__title {
		margin-bottom: 25px;
	}
	.razzi-testimonials-carousel-2__rating_position-right .header-content {
		flex-direction: column;
	}
	.razzi-testimonials-carousel-2 .testimonials-item.testimonials-item__author-box {
		flex-direction: column;
	}
	.razzi-testimonials-carousel-2 .author-group {
		padding-left: 0px;
		padding-bottom: 20px;
	}
	.razzi-testimonials-carousel-2 .author-group + .razzi-testimonials-carousel-2__gr {
		padding-top: 20px;
		padding-right: 0px;
	}
	.razzi-testimonials-carousel-2 .author-group:before {
		content: '';
		display: block;
		position: absolute;
		bottom: 0;
		left: calc(0px - 16px);
		width: calc(100% + 32px);
		height: 1px;
		background-color: #E2E2E2;
	}
	.razzi-testimonials-carousel-2 .author-group:after {
		display: none;
	}
	.razzi-product-category-box .razzi-product-category-box__item {
		height: auto;
		padding-bottom: 10px;
		padding-top: 10px;
	}
	.razzi-product-category-box .razzi-product-category-box__item:nth-child(2n+1) {
		padding-left: 10px;
	}
	.razzi-product-category-box .razzi-product-category-box__item:nth-child(2n) {
		padding-right: 10px;
	}
	.razzi-product-category-box .razzi-product-category-box__item-box {
		flex-direction: column;
		padding: 23px 15px 10px;
		height: 100%;
	}
	.razzi-product-category-box .razzi-product-category-box__content {
		order: 2;
		padding: 0;
	}
	.razzi-product-category-box .razzi-product-category-box__content .razzi-button {
		margin-top: 10px;
	}
	.razzi-product-category-box .razzi-product-category-box__image {
		order: 1;
		padding-bottom: 15px;
	}
	.razzi-products-deal-2 ul.products li.product .product-summary {
		padding: 0 15px;
	}
}

@media (max-width: 784px) {
	.razzi-testimonials-grid .testimonial-item {
		width: 50%;
	}
	.razzi-testimonials-grid .testimonials-wrapper {
		flex-wrap: wrap;
	}
}

@media (max-width: 480px) {
	.razzi-products-tabs .swiper-scrollbar,
	.razzi-products-carousel .swiper-scrollbar,
	.razzi-products-deal .swiper-scrollbar {
		max-width: 250px;
	}
	.razzi-icons-box-carousel .rz-swiper-button {
		width: auto;
		height: auto;
	}
	.razzi-lookbook-slider-elementor .product-item {
		width: 165px;
	}
	.razzi-pricing-table__content {
		padding: 27px 20px 40px;
	}
	.razzi-pricing-table__content .pricing-desc {
		margin-bottom: 30px;
	}
	.razzi-testimonials-grid .testimonial-item {
		width: 100%;
	}
	.razzi-countdown .timer {
		padding: 0 15px;
	}
	.razzi-countdown .timer .divider {
		left: -6px;
		font-size: 25px;
	}
	.razzi-products-with-banner ul.products.layout-masonry li.product.has-banner {
		grid-column: span 2 !important;
	}
	.razzi-products-carousel-with-thumbnails ul.products.product-loop-layout-8 li.product .product-thumbnail .product-loop-inner__buttons {
		right: 5px;
	}
	.razzi-deals-carousel-2 .razzi-countdown {
		margin-left: 20px;
	}
	.razzi-deals-carousel-2 .razzi-countdown .timer {
		padding: 10px 0;
	}
	.razzi-products-slider .razzi-products-slider__content {
		width: auto;
	}
}

.razzi-map .mapboxgl-ctrl-top-right {
	top: 10px;
	transform: none;
}

.razzi-map__has-tab {
	flex-wrap: wrap;
	margin-top: 0;
}

.razzi-map__has-tab .razzi-map__table {
	max-width: 100%;
	flex-basis: 100%;
	overflow-x: auto;
	margin-left: 0;
}

.razzi-map .box-item {
	padding: 30px 15px;
}

.razzi-map .box-item:first-child {
	padding-top: 0;
}

.razzi-map .map-title {
	margin-bottom: 10px;
}

.swiper-pagination {
	margin-top: 20px;
}

ul.products li.product .woocommerce-loop-product__title {
	font-size: 14px;
}

input[type="text"] {
	-webkit-appearance: none;
	appearance: none;
	border-radius: 0;
}

.razzi-icons-box-carousel__wrapper:not(.swiper-container-initialized) .icon-box {
	width: 50%;
}